import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ConfigService } from './config.service';
import { DominioModel } from '../models/dominio.model';
/**
 * Serviço responsável por trazer os dominios
 * de `/dominio/`, `/dominio/itens` ou `/dominio/{nome-do-dominio}`
 */
export declare class DominioService {
    private httpClient;
    private configService;
    /**
     * Cache dos dominios
     */
    private domainsCache;
    private domainsItensCache;
    private domainCache;
    /**
     * Inicializador da classe
     * @param httpClient Cliente para as requisiçõe HTTP
     * @param configService Serviço responsável por trazer as configurações do sistema
     */
    constructor(httpClient: HttpClient, configService: ConfigService);
    /**
     * Retorna um `Observable`. Se assinado vai
     * trazer todas os dominios em
     * um objeto só
     */
    getAll(): Observable<DominioModel[]>;
    /**
     * Retorna um `Observable`. Se assinado vai
     * trazer o dominio selecionada
     * @param domainName Nome do dominio a ser retornado no `Observable`
     */
    get(domainName: string): Observable<DominioModel>;
    /**
     * Retorna um `Observable`. Se assinado vai
     * trazer os dominios selecionadas
     * em uma lista
     * @param domainNames Lista de nome dos dominios a serem retornados no `Observable`
     */
    getList(domainNames: string[]): Observable<DominioModel[]>;
    /**
     * Retorna um `Observable`. Se assinado vai
     * trazer os nomes de todos os dominios
     * em uma lista
     */
    getItemNames(): Observable<string[]>;
}
