import { MatSnackBar } from '@angular/material/snack-bar';
import { MAT_BOTTOM_SHEET_DATA, MatBottomSheetRef, MatBottomSheet, MatBottomSheetModule } from '@angular/material/bottom-sheet';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatExpansionModule } from '@angular/material/expansion';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatInput, MatInputModule } from '@angular/material/input';
import { MatListModule } from '@angular/material/list';
import { MatMenuModule } from '@angular/material/menu';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatTooltipModule } from '@angular/material/tooltip';
import { DomSanitizer } from '@angular/platform-browser';
import { __spread, __assign } from 'tslib';
import { BreakpointObserver, Breakpoints, LayoutModule } from '@angular/cdk/layout';
import { Router, NavigationStart, NavigationEnd, NavigationCancel, NavigationError, RouterModule } from '@angular/router';
import { MediaObserver, FlexLayoutModule } from '@angular/flex-layout';
import { DatePipe, CommonModule } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { BehaviorSubject, of } from 'rxjs';
import { MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { MatSidenavModule } from '@angular/material/sidenav';
import { startWith, delay, map, switchMap, tap, take, finalize, pluck } from 'rxjs/operators';
import { SecurityService, ConfigService, AuthService, redirectTo, NotificacaoService, DATASUS_ROUTE_HOME, DATASUS_ROUTE_RELEASE_NOTES, compareObjects } from '@datasus/core';
import { Injectable, Directive, ElementRef, Input, Component, Pipe, Inject, ViewChild, ChangeDetectorRef, NgModule, defineInjectable, inject, EventEmitter, Output } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LayoutService = /** @class */ (function () {
    function LayoutService(breakpointObserver) {
        this.breakpointObserver = breakpointObserver;
        this.title$ = new BehaviorSubject('');
        this.enabled$ = new BehaviorSubject(true);
        this.loading$ = new BehaviorSubject(false);
        this.menuSidenavOpen$ = new BehaviorSubject(true);
        this.onMobile$ = this.breakpointObserver.observe(Breakpoints.Handset).pipe(map((/**
         * @param {?} breakpointState
         * @return {?}
         */
        function (breakpointState) { return breakpointState.matches; })));
    }
    /**
     * Ajusta o título da funcionalidade
     * @param title Título da funcionalidade
     */
    /**
     * Ajusta o título da funcionalidade
     * @param {?} title Título da funcionalidade
     * @return {?}
     */
    LayoutService.prototype.setTitle = /**
     * Ajusta o título da funcionalidade
     * @param {?} title Título da funcionalidade
     * @return {?}
     */
    function (title) {
        if (title) {
            this.on();
        }
        this.title$.next(title);
    };
    /**
     * Recupera o título da funcionidade
     */
    /**
     * Recupera o título da funcionidade
     * @return {?}
     */
    LayoutService.prototype.getTitle = /**
     * Recupera o título da funcionidade
     * @return {?}
     */
    function () {
        return this.title$.asObservable();
    };
    /**
     * Liga o layout
     */
    /**
     * Liga o layout
     * @return {?}
     */
    LayoutService.prototype.on = /**
     * Liga o layout
     * @return {?}
     */
    function () {
        this.enabled$.next(true);
    };
    /**
     * Desliga o layout
     */
    /**
     * Desliga o layout
     * @return {?}
     */
    LayoutService.prototype.off = /**
     * Desliga o layout
     * @return {?}
     */
    function () {
        this.setTitle('');
        this.enabled$.next(false);
    };
    /**
     * Recupera se o layout está ligado ou não
     */
    /**
     * Recupera se o layout está ligado ou não
     * @return {?}
     */
    LayoutService.prototype.isEnabled = /**
     * Recupera se o layout está ligado ou não
     * @return {?}
     */
    function () {
        return this.enabled$.asObservable().pipe(startWith(true), delay(0));
    };
    /**
     * Exibe o carregando...
     */
    /**
     * Exibe o carregando...
     * @return {?}
     */
    LayoutService.prototype.loading = /**
     * Exibe o carregando...
     * @return {?}
     */
    function () {
        this.loading$.next(true);
    };
    /**
     * Esconde o carregando...
     */
    /**
     * Esconde o carregando...
     * @return {?}
     */
    LayoutService.prototype.loaded = /**
     * Esconde o carregando...
     * @return {?}
     */
    function () {
        this.loading$.next(false);
    };
    /**
     * Recupera se está carregando ou não
     */
    /**
     * Recupera se está carregando ou não
     * @return {?}
     */
    LayoutService.prototype.isLoading = /**
     * Recupera se está carregando ou não
     * @return {?}
     */
    function () {
        return this.loading$.asObservable().pipe(startWith(false), delay(0));
    };
    /**
     * Recupera se está em uma tela pequena
     */
    /**
     * Recupera se está em uma tela pequena
     * @return {?}
     */
    LayoutService.prototype.onMobile = /**
     * Recupera se está em uma tela pequena
     * @return {?}
     */
    function () {
        return this.onMobile$;
    };
    /**
     * Recupera o estado do menu
     */
    /**
     * Recupera o estado do menu
     * @return {?}
     */
    LayoutService.prototype.menuSidenavOpen = /**
     * Recupera o estado do menu
     * @return {?}
     */
    function () {
        return this.menuSidenavOpen$.asObservable();
    };
    /**
     * Expande o menu
     */
    /**
     * Expande o menu
     * @return {?}
     */
    LayoutService.prototype.menuSidenavExpanded = /**
     * Expande o menu
     * @return {?}
     */
    function () {
        this.menuSidenavOpen$.next(true);
    };
    /**
     * Recolhe o menu
     */
    /**
     * Recolhe o menu
     * @return {?}
     */
    LayoutService.prototype.menuSidenavCollapsed = /**
     * Recolhe o menu
     * @return {?}
     */
    function () {
        this.menuSidenavOpen$.next(false);
    };
    LayoutService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    LayoutService.ctorParameters = function () { return [
        { type: BreakpointObserver }
    ]; };
    /** @nocollapse */ LayoutService.ngInjectableDef = defineInjectable({ factory: function LayoutService_Factory() { return new LayoutService(inject(BreakpointObserver)); }, token: LayoutService, providedIn: "root" });
    return LayoutService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogAlertComponent = /** @class */ (function () {
    function DialogAlertComponent(bottomSheetRef, data) {
        this.bottomSheetRef = bottomSheetRef;
        this.config = (/** @type {?} */ (data));
    }
    /**
     * @return {?}
     */
    DialogAlertComponent.prototype.closeMe = /**
     * @return {?}
     */
    function () {
        this.bottomSheetRef.dismiss(true);
    };
    DialogAlertComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-dialog-alert',
                    template: "<h2 mat-dialog-title>{{ config.title }}</h2>\n<span [ngClass]=\"config.type\" aria-hidden=\"true\"></span>\n<mat-dialog-content>\n  <p *ngIf=\"config.message\">{{ config.message }}</p>\n  <p *ngFor=\"let message of config.messages\">{{ message }}</p>\n</mat-dialog-content>\n<mat-dialog-actions>\n  <button mat-raised-button (click)=\"closeMe()\" [color]=\"config.type\">FECHAR</button>\n</mat-dialog-actions>",
                    styles: [".accent::before,.primary::before,.warn::before{float:left;font-family:'Material Icons';font-size:2em;display:block;-webkit-animation-name:datasus-bounce;animation-name:datasus-bounce;-webkit-animation-duration:1s;animation-duration:1s;-webkit-animation-fill-mode:both;animation-fill-mode:both;-webkit-animation-direction:center bottom;animation-direction:center bottom}.warn::before{content:'warning';color:#c2185b}.accent::before{content:'announcement';color:#ff8f00}.primary::before{content:'info';color:#1565c0}@-webkit-keyframes datasus-bounce{20%,53%,80%,from,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1);transform:translate3d(0,0,0)}40%,43%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);transform:translate3d(0,-30px,0)}70%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);transform:translate3d(0,-15px,0)}90%{transform:translate3d(0,-4px,0)}}@keyframes datasus-bounce{20%,53%,80%,from,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1);transform:translate3d(0,0,0)}40%,43%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);transform:translate3d(0,-30px,0)}70%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);transform:translate3d(0,-15px,0)}90%{transform:translate3d(0,-4px,0)}}"]
                }] }
    ];
    /** @nocollapse */
    DialogAlertComponent.ctorParameters = function () { return [
        { type: MatBottomSheetRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_BOTTOM_SHEET_DATA,] }] }
    ]; };
    return DialogAlertComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogConfirmationComponent = /** @class */ (function () {
    function DialogConfirmationComponent(bottomSheetRef, data) {
        this.bottomSheetRef = bottomSheetRef;
        this.config = (/** @type {?} */ (data));
    }
    /**
     * @param {?} option
     * @return {?}
     */
    DialogConfirmationComponent.prototype.closeMe = /**
     * @param {?} option
     * @return {?}
     */
    function (option) {
        this.bottomSheetRef.dismiss(option);
    };
    DialogConfirmationComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-dialog-confirmation',
                    template: "<h2 mat-dialog-title>{{ config.title }}</h2>\n<mat-dialog-content>\n  <p>{{ config.question }}</p>\n</mat-dialog-content>\n<mat-dialog-actions>\n  <span *ngFor=\"let option of config.options; first as isFirst\">\n    <button *ngIf=\"isFirst\" mat-raised-button [color]=\"config.type\" (click)=\"closeMe(option)\">\n      {{ option | uppercase }}\n    </button>\n    <button *ngIf=\"!isFirst\" mat-button (click)=\"closeMe(option)\">\n      {{ option | uppercase }}\n    </button>\n  </span>\n</mat-dialog-actions>",
                    styles: [""]
                }] }
    ];
    /** @nocollapse */
    DialogConfirmationComponent.ctorParameters = function () { return [
        { type: MatBottomSheetRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_BOTTOM_SHEET_DATA,] }] }
    ]; };
    return DialogConfirmationComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogPromptComponent = /** @class */ (function () {
    function DialogPromptComponent(bottomSheetRef, data) {
        this.bottomSheetRef = bottomSheetRef;
        this.config = (/** @type {?} */ (data));
    }
    /**
     * @return {?}
     */
    DialogPromptComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.bottomSheetRef.afterOpened().subscribe((/**
         * @return {?}
         */
        function () { return _this.input.focus(); }));
    };
    /**
     * @param {?} input
     * @return {?}
     */
    DialogPromptComponent.prototype.closeMe = /**
     * @param {?} input
     * @return {?}
     */
    function (input) {
        if (this.config.required && !input) {
            this.requiredError = true;
            this.input.focus();
            return;
        }
        this.requiredError = false;
        this.bottomSheetRef.dismiss(input);
    };
    DialogPromptComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-dialog-prompt',
                    template: "<h2 mat-dialog-title>{{ config.title }}</h2>\n<mat-dialog-content>\n  <mat-form-field class=\"input\" appearance=\"outline\" [color]=\"requiredError ? 'warn' : 'primary'\">\n    <mat-label>{{ config.label }}</mat-label>\n    <input\n        #input\n        type=\"text\"\n        matInput\n        [maxLength]=\"config.maxLength || -1\"\n        (keydown.enter)=\"closeMe(input.value)\"\n    />\n    <button\n        *ngIf=\"input.value\"\n        class=\"clear\"\n        aria-label=\"Limpar\"\n        matSuffix\n        mat-icon-button\n        [color]=\"requiredError ? 'warn' : ''\"\n        (click)=\"input.value=''\"\n    >\n      <mat-icon>close</mat-icon>\n    </button>\n    <mat-hint *ngIf=\"config?.maxLength > 0\" align=\"end\">{{ input.value?.length || 0 }} / {{ config.maxLength }}</mat-hint>\n    <mat-hint *ngIf=\"requiredError\" align=\"start\">Campo obrigat\u00F3rio</mat-hint>\n  </mat-form-field>\n</mat-dialog-content>\n<mat-dialog-actions>\n  <button mat-raised-button (click)=\"closeMe(input.value)\" [color]=\"config.type\">{{ config.button | uppercase }}</button>\n</mat-dialog-actions>\n",
                    styles: [".input{width:100%}.clear{transform:translateY(-10px)}"]
                }] }
    ];
    /** @nocollapse */
    DialogPromptComponent.ctorParameters = function () { return [
        { type: MatBottomSheetRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_BOTTOM_SHEET_DATA,] }] }
    ]; };
    DialogPromptComponent.propDecorators = {
        input: [{ type: ViewChild, args: [MatInput,] }]
    };
    return DialogPromptComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DialogService = /** @class */ (function () {
    function DialogService(bottomSheet, snackBar) {
        this.bottomSheet = bottomSheet;
        this.snackBar = snackBar;
    }
    /**
     * @param {?} configOrMessage
     * @return {?}
     */
    DialogService.prototype.showAlert = /**
     * @param {?} configOrMessage
     * @return {?}
     */
    function (configOrMessage) {
        /** @type {?} */
        var config = (typeof configOrMessage === 'string')
            ? { message: configOrMessage } : configOrMessage;
        /** @type {?} */
        var configDefault = {
            message: '',
            messages: [],
            title: 'Alerta!',
            type: 'warn',
        };
        /** @type {?} */
        var dialog = this.bottomSheet.open(DialogAlertComponent, {
            ariaLabel: 'Diálogo com uma mensagem',
            data: __assign({}, configDefault, config)
        });
        dialog.afterDismissed().subscribe((/**
         * @param {?=} result
         * @return {?}
         */
        function (result) {
            if (config.callback) {
                config.callback(result || false);
            }
        }));
    };
    /**
     * @param {?} config
     * @return {?}
     */
    DialogService.prototype.showConfirmation = /**
     * @param {?} config
     * @return {?}
     */
    function (config) {
        /** @type {?} */
        var options = [];
        config.anwsers.forEach((/**
         * @param {?} value
         * @param {?} key
         * @return {?}
         */
        function (value, key) {
            options.push(key);
        }));
        /** @type {?} */
        var configDefault = {
            title: 'Confirmação…',
            type: 'primary',
            options: options,
        };
        /** @type {?} */
        var configToRemove = { anwsers: null };
        /** @type {?} */
        var dialog = this.bottomSheet.open(DialogConfirmationComponent, {
            disableClose: true,
            ariaLabel: "Di\u00E1logo com a pergunta: " + config.question,
            data: __assign({}, configDefault, config, configToRemove)
        });
        dialog.afterDismissed().subscribe((/**
         * @param {?} button
         * @return {?}
         */
        function (button) {
            if (config.anwsers.get(button)) {
                config.anwsers.get(button)();
            }
        }));
    };
    /**
     * @param {?} config
     * @return {?}
     */
    DialogService.prototype.showPrompt = /**
     * @param {?} config
     * @return {?}
     */
    function (config) {
        /** @type {?} */
        var configDefault = {
            label: 'Informe aqui',
            button: 'Aplicar',
            title: 'Pergunta',
            required: false,
            type: 'primary',
        };
        /** @type {?} */
        var dialog = this.bottomSheet.open(DialogPromptComponent, {
            disableClose: !!config.required,
            ariaLabel: 'Diálogo com uma mensagem e um campo para resposta',
            data: __assign({}, configDefault, config)
        });
        dialog.afterDismissed().subscribe((/**
         * @param {?=} result
         * @return {?}
         */
        function (result) {
            if (config.callback) {
                config.callback(result || '');
            }
        }));
    };
    /**
     * @param {?} configOrMessage
     * @return {?}
     */
    DialogService.prototype.showNotification = /**
     * @param {?} configOrMessage
     * @return {?}
     */
    function (configOrMessage) {
        var _this = this;
        setTimeout((/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            var config = (typeof configOrMessage === 'string')
                ? { message: configOrMessage } : configOrMessage;
            /** @type {?} */
            var secondsToClose = config.secondsToClose || 5;
            /** @type {?} */
            var message = config.message;
            /** @type {?} */
            var action = (config.action ? Object.keys(config.action)[0].toUpperCase() : '');
            /** @type {?} */
            var snackBarRef = _this.snackBar.open(message, action, {
                duration: secondsToClose * 1000,
                horizontalPosition: 'right',
                verticalPosition: 'top',
            });
            if (config.dismiss) {
                snackBarRef.afterDismissed().subscribe(config.dismiss);
            }
            if (config.action) {
                /** @type {?} */
                var actionCallback = Object.values(config.action);
                if (actionCallback.length) {
                    snackBarRef.onAction().subscribe(actionCallback[0]);
                }
            }
        }), 50);
    };
    DialogService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    DialogService.ctorParameters = function () { return [
        { type: MatBottomSheet },
        { type: MatSnackBar }
    ]; };
    /** @nocollapse */ DialogService.ngInjectableDef = defineInjectable({ factory: function DialogService_Factory() { return new DialogService(inject(MatBottomSheet), inject(MatSnackBar)); }, token: DialogService, providedIn: "root" });
    return DialogService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var MenuService = /** @class */ (function () {
    function MenuService(httpClient, configService, securityService) {
        this.httpClient = httpClient;
        this.configService = configService;
        this.securityService = securityService;
        this.cache = new Map();
    }
    /**
     * @return {?}
     */
    MenuService.prototype.reset = /**
     * @return {?}
     */
    function () {
        this.cache.clear();
    };
    /**
     * @return {?}
     */
    MenuService.prototype.get = /**
     * @return {?}
     */
    function () {
        var _this = this;
        return this.securityService.getPerfilSelecionado().pipe(switchMap((/**
         * @param {?} perfil
         * @return {?}
         */
        function (perfil) {
            _this.perfilSelecionado = perfil;
            return _this.securityService.getEsferaSelecionada();
        })), switchMap(this.perfilSwitchToMenu.bind(this)), delay(0));
    };
    /**
     * @private
     * @param {?=} esfera
     * @return {?}
     */
    MenuService.prototype.perfilSwitchToMenu = /**
     * @private
     * @param {?=} esfera
     * @return {?}
     */
    function (esfera) {
        var _this = this;
        /** @type {?} */
        var perfil = this.perfilSelecionado;
        if (!perfil) {
            return of([]);
        }
        /** @type {?} */
        var key = perfil.sigla
            + (!!esfera ? (esfera.id || '').toString() + (esfera.esferaAtuacao || '') : '');
        if (this.cache.has(key)) {
            console.log('Menu do cache:', key);
            return of(this.cache.get(key));
        }
        return this.configService.getList([
            'backendUrl',
            'clientId',
        ]).pipe(switchMap((/**
         * @param {?} configs
         * @return {?}
         */
        function (configs) {
            /** @type {?} */
            var backendUrl = configs[0];
            /** @type {?} */
            var clientId = configs[1];
            console.log('Menu: ', key, backendUrl, clientId);
            return _this.httpClient.get(backendUrl + "/acesso/sistema/" + clientId + "/perfil/" + perfil.sigla + "/menu");
        })), map((/**
         * @param {?} menu
         * @return {?}
         */
        function (menu) { return menu.filter((/**
         * @param {?} menuItem
         * @return {?}
         */
        function (menuItem) {
            if (typeof _this.filterItem === 'function') {
                /** @type {?} */
                var filtered = _this.filterItem(menuItem);
                console.log('Filter Menu: ', menuItem, filtered);
                return filtered;
            }
            return true;
        })); })), tap((/**
         * @param {?} menu
         * @return {?}
         */
        function (menu) { return _this.cache.set(key, menu); })));
    };
    MenuService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    MenuService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: ConfigService },
        { type: SecurityService }
    ]; };
    /** @nocollapse */ MenuService.ngInjectableDef = defineInjectable({ factory: function MenuService_Factory() { return new MenuService(inject(HttpClient), inject(ConfigService), inject(SecurityService)); }, token: MenuService, providedIn: "root" });
    return MenuService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var DatasusColors = {
    /* Grey 800 */
    dusky: '#424242',
    duskyLight: '#6d6d6d',
    duskyDark: '#1b1b1b',
    /* Grey 50 */
    bright: '#fafafa',
    brightLight: '#ffffff',
    brightDark: '#c7c7c7',
    /* Blue 800 */
    primary: '#1565c0',
    primaryLight: '#5e92f3',
    primaryDark: '#003c8f',
    /* Amber 800 */
    accent: '#ff8f00',
    accentLight: '#ffc046',
    accentDark: '#c56000',
    /* Pink 700 */
    warn: '#c2185b',
    warnLight: '#fa5788',
    warnDark: '#8c0032',
    /* Green 800 */
    success: '#2e7d32',
    successLight: '#60ad5e',
    successDark: '#005005',
    /* Red A700 */
    error: '#d50000',
    errorLight: '#ff5131',
    errorDark: '#9b0000',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var FirstWordPipe = /** @class */ (function () {
    function FirstWordPipe() {
    }
    /**
     * @param {?=} value
     * @return {?}
     */
    FirstWordPipe.prototype.transform = /**
     * @param {?=} value
     * @return {?}
     */
    function (value) {
        if (value === void 0) { value = ''; }
        /** @type {?} */
        var text = !value ? '' : value.toString();
        /** @type {?} */
        var onlyOneSpace = text.replace(/\s+/gmi, ' ');
        /** @type {?} */
        var onlyFisrtWord = onlyOneSpace.replace(/(^[A-Za-zÀ-ÖØ-öø-ÿ]*)(\s+.*$)/gmi, '$1');
        return onlyFisrtWord;
    };
    FirstWordPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'datasusFirstWord',
                    pure: true,
                },] }
    ];
    return FirstWordPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SwitchSlashToDashPipe = /** @class */ (function () {
    function SwitchSlashToDashPipe() {
    }
    /**
     * @param {?} value
     * @return {?}
     */
    SwitchSlashToDashPipe.prototype.transform = /**
     * @param {?} value
     * @return {?}
     */
    function (value) {
        /** @type {?} */
        var text = !value ? '' : value.toString();
        /** @type {?} */
        var textWithoutLastSlash = text.replace(/\/$/, '');
        /** @type {?} */
        var slashsSwitchedToDash = textWithoutLastSlash.replace(/\//g, ' - ');
        return slashsSwitchedToDash;
    };
    SwitchSlashToDashPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'datasusSwitchSlashToDashPipe',
                },] }
    ];
    return SwitchSlashToDashPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SafeHtmlPipe = /** @class */ (function () {
    function SafeHtmlPipe(sanitizer) {
        this.sanitizer = sanitizer;
    }
    /**
     * @param {?} url
     * @return {?}
     */
    SafeHtmlPipe.prototype.transform = /**
     * @param {?} url
     * @return {?}
     */
    function (url) {
        return this.sanitizer.bypassSecurityTrustHtml(url);
    };
    SafeHtmlPipe.decorators = [
        { type: Pipe, args: [{ name: 'safeHtml' },] }
    ];
    /** @nocollapse */
    SafeHtmlPipe.ctorParameters = function () { return [
        { type: DomSanitizer }
    ]; };
    return SafeHtmlPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ListAfterIndexPipe = /** @class */ (function () {
    function ListAfterIndexPipe() {
    }
    /**
     * @param {?} list
     * @param {?} index
     * @return {?}
     */
    ListAfterIndexPipe.prototype.transform = /**
     * @param {?} list
     * @param {?} index
     * @return {?}
     */
    function (list, index) {
        if (!this.isArray(list)) {
            throw Error('Informe uma lista válida');
        }
        if (!list.length) {
            return [];
        }
        if (index < 0) {
            return __spread(list);
        }
        return __spread(list).splice(index);
    };
    /**
     * @private
     * @param {?} list
     * @return {?}
     */
    ListAfterIndexPipe.prototype.isArray = /**
     * @private
     * @param {?} list
     * @return {?}
     */
    function (list) {
        return list instanceof Array;
    };
    ListAfterIndexPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'datasusListAfterIndex'
                },] }
    ];
    return ListAfterIndexPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ListUntilIndexPipe = /** @class */ (function () {
    function ListUntilIndexPipe() {
    }
    /**
     * @param {?} list
     * @param {?} index
     * @return {?}
     */
    ListUntilIndexPipe.prototype.transform = /**
     * @param {?} list
     * @param {?} index
     * @return {?}
     */
    function (list, index) {
        if (!this.isArray(list)) {
            throw Error('Informe uma lista válida');
        }
        if (!list) {
            return [];
        }
        if (index < 0) {
            return [];
        }
        if (list.length <= index) {
            return __spread(list);
        }
        return __spread(list).filter((/**
         * @param {?} _
         * @param {?} i
         * @return {?}
         */
        function (_, i) { return i < index; }));
    };
    /**
     * @private
     * @param {?} list
     * @return {?}
     */
    ListUntilIndexPipe.prototype.isArray = /**
     * @private
     * @param {?} list
     * @return {?}
     */
    function (list) {
        return list instanceof Array;
    };
    ListUntilIndexPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'datasusListUntilIndex'
                },] }
    ];
    return ListUntilIndexPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RelativeDatePipe = /** @class */ (function () {
    function RelativeDatePipe() {
        this.MILLISECOND = 1;
        this.SECOND = this.MILLISECOND * 1000;
        this.MINUTE = this.SECOND * 60;
        this.HOUR = this.MINUTE * 60;
        this.DAY = this.HOUR * 24;
        this.WEEK = this.DAY * 7;
    }
    /**
     * Retorna um texto com a data relativa
     *
     * Quando passado o parametro {lowAccuracy} os possíveis retornos são:
     *   Hoje,
     *   Ontem,
     *   Essa semana,
     *   Semana passada,
     *   Mês passado,
     *   Mais antigas
     * No contrário:
     *   Agora pouco,
     *   Minutos atrás,
     *   Horas atrás,
     *   Dias atrás,
     *   Semanas atrás,
     *   Meses atrás
     *   Anos atrás
     */
    /**
     * Retorna um texto com a data relativa
     *
     * Quando passado o parametro {lowAccuracy} os possíveis retornos são:
     *   Hoje,
     *   Ontem,
     *   Essa semana,
     *   Semana passada,
     *   Mês passado,
     *   Mais antigas
     * No contrário:
     *   Agora pouco,
     *   Minutos atrás,
     *   Horas atrás,
     *   Dias atrás,
     *   Semanas atrás,
     *   Meses atrás
     *   Anos atrás
     * @param {?} value
     * @param {?} valueToCompare
     * @param {?=} lowAccuracy
     * @return {?}
     */
    RelativeDatePipe.prototype.transform = /**
     * Retorna um texto com a data relativa
     *
     * Quando passado o parametro {lowAccuracy} os possíveis retornos são:
     *   Hoje,
     *   Ontem,
     *   Essa semana,
     *   Semana passada,
     *   Mês passado,
     *   Mais antigas
     * No contrário:
     *   Agora pouco,
     *   Minutos atrás,
     *   Horas atrás,
     *   Dias atrás,
     *   Semanas atrás,
     *   Meses atrás
     *   Anos atrás
     * @param {?} value
     * @param {?} valueToCompare
     * @param {?=} lowAccuracy
     * @return {?}
     */
    function (value, valueToCompare, lowAccuracy) {
        if (lowAccuracy === void 0) { lowAccuracy = false; }
        /** @type {?} */
        var dateToCompare = new Date(valueToCompare || Date.now());
        /** @type {?} */
        var date = new Date(value);
        /** @type {?} */
        var diff = (+dateToCompare - +date);
        /** @type {?} */
        var diffMonth = this.getFullYearMonth(dateToCompare) - this.getFullYearMonth(date);
        if (0 > diff) {
            return 'Data futura';
        }
        if (lowAccuracy === true) {
            return this.lowAccurancyCalc(date, dateToCompare, diff, diffMonth);
        }
        return this.highAccurancyCalc(date, dateToCompare, diff, diffMonth);
    };
    /**
     * @private
     * @param {?} date
     * @return {?}
     */
    RelativeDatePipe.prototype.getFullYearMonth = /**
     * @private
     * @param {?} date
     * @return {?}
     */
    function (date) {
        return +(date.getFullYear()
            .toString()
            .concat((date.getMonth() < 9 ? '0' : ''))
            .concat((date.getMonth() + 1).toString()));
    };
    /**
     * @private
     * @param {?} date
     * @param {?} dateToCompare
     * @param {?} diff
     * @param {?} diffMonth
     * @return {?}
     */
    RelativeDatePipe.prototype.highAccurancyCalc = /**
     * @private
     * @param {?} date
     * @param {?} dateToCompare
     * @param {?} diff
     * @param {?} diffMonth
     * @return {?}
     */
    function (date, dateToCompare, diff, diffMonth) {
        if (diff <= this.MINUTE) {
            return 'Agora pouco';
        }
        if (diff <= this.HOUR) {
            return 'Minutos atrás';
        }
        if (diff <= this.DAY) {
            return 'Horas atrás';
        }
        if (diff <= this.WEEK) {
            return 'Dias atrás';
        }
        if (diff > this.WEEK && diffMonth <= 1) {
            return 'Semanas atrás';
        }
        if (diffMonth <= 12 || diffMonth <= 100) {
            return 'Meses atrás';
        }
        return 'Anos atrás';
    };
    /**
     * @private
     * @param {?} date
     * @param {?} dateToCompare
     * @param {?} diff
     * @param {?} diffMonth
     * @return {?}
     */
    RelativeDatePipe.prototype.lowAccurancyCalc = /**
     * @private
     * @param {?} date
     * @param {?} dateToCompare
     * @param {?} diff
     * @param {?} diffMonth
     * @return {?}
     */
    function (date, dateToCompare, diff, diffMonth) {
        if (diff < this.DAY && date.getDate() === dateToCompare.getDate()) {
            return 'Hoje';
        }
        if (diff < (this.DAY * 2) && (date.getDate() + 1) === dateToCompare.getDate()) {
            return 'Ontem';
        }
        /** @type {?} */
        var dayOfWeek = date.getDay();
        /** @type {?} */
        var dateToCompareOfWeek = dateToCompare.getDay();
        if (diff < this.WEEK && dayOfWeek <= (dateToCompareOfWeek - 2)) {
            return 'Essa semana';
        }
        if ((diff - (dateToCompareOfWeek * this.DAY)) <= this.WEEK) {
            return 'Semana passada';
        }
        if (diffMonth === 1) {
            return 'Mês passado';
        }
        return 'Mais antiga';
    };
    RelativeDatePipe.decorators = [
        { type: Pipe, args: [{
                    name: 'datasusRelativeDate'
                },] }
    ];
    return RelativeDatePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var OnMobileDirective = /** @class */ (function () {
    function OnMobileDirective(elementRef, breakpointObserver, layoutService) {
        this.elementRef = elementRef;
        this.breakpointObserver = breakpointObserver;
        this.layoutService = layoutService;
    }
    /**
     * @return {?}
     */
    OnMobileDirective.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.showOrHide(this.breakpointObserver.isMatched(Breakpoints.Handset));
        this.breakpointSubscription = this.layoutService.onMobile().subscribe((/**
         * @param {?} onMobile
         * @return {?}
         */
        function (onMobile) { return _this.showOrHide(onMobile); }));
    };
    /**
     * @return {?}
     */
    OnMobileDirective.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.breakpointSubscription.unsubscribe();
    };
    /**
     * @private
     * @param {?} onMobile
     * @return {?}
     */
    OnMobileDirective.prototype.showOrHide = /**
     * @private
     * @param {?} onMobile
     * @return {?}
     */
    function (onMobile) {
        if (!this.datasusOnMobile) {
            return;
        }
        /** @type {?} */
        var isShow = 'show' === this.datasusOnMobile;
        /** @type {?} */
        var isHide = 'hide' === this.datasusOnMobile;
        /** @type {?} */
        var block = ((onMobile && isShow) || (!onMobile && isHide));
        /** @type {?} */
        var none = ((onMobile && isHide) || (!onMobile && isShow));
        /** @type {?} */
        var display = block ? 'block' : none ? 'none' : null;
        if (display) {
            this.elementRef.nativeElement.style.display = display;
        }
    };
    OnMobileDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[datasusOnMobile]'
                },] }
    ];
    /** @nocollapse */
    OnMobileDirective.ctorParameters = function () { return [
        { type: ElementRef },
        { type: BreakpointObserver },
        { type: LayoutService }
    ]; };
    OnMobileDirective.propDecorators = {
        datasusOnMobile: [{ type: Input }]
    };
    return OnMobileDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ContainerComponent = /** @class */ (function () {
    function ContainerComponent() {
    }
    ContainerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-container',
                    template: "<mat-card class=\"container\">\n  <ng-content></ng-content>\n</mat-card>\n",
                    styles: [".container{width:90%;min-height:calc(100vh - 210px);margin:auto}@media all and (max-width:959px){.container{width:85%}}"]
                }] }
    ];
    return ContainerComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ContainerTransparentComponent = /** @class */ (function () {
    function ContainerTransparentComponent() {
    }
    ContainerTransparentComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-container-transparent',
                    template: "<section class=\"container-transparent\">\n  <ng-content></ng-content>\n</section>\n",
                    styles: [".container-transparent{position:relative;width:95%;margin:auto}"]
                }] }
    ];
    return ContainerTransparentComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var FooterComponent = /** @class */ (function () {
    function FooterComponent() {
        this.supportList = [];
    }
    /**
     * @return {?}
     */
    FooterComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.supportList.push({
            label: 'E-mail',
            linkHref: 'mailto:suporte.sistemas@datasus.gov.br',
            linkText: 'suporte.sistemas@datasus.gov.br',
        });
        this.supportList.push({
            label: 'Fale Conosco',
            linkHref: 'http://datasus.saude.gov.br/fale-conosco',
            linkText: 'http://datasus.saude.gov.br/fale-conosco',
        });
    };
    FooterComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-footer',
                    template: "<mat-toolbar class=\"mat-elevation-z2-upside-down\">\n    <mat-toolbar-row>\n\n        <mat-menu #supportListMenu=\"matMenu\">\n            <a *ngFor=\"let supportItem of supportList\" mat-menu-item [href]=\"supportItem.linkHref\" target=\"blank\">\n                <span>{{ supportItem.label }}</span>\n            </a>\n        </mat-menu>\n\n        <button mat-icon-button [matMenuTriggerFor]=\"supportListMenu\" matTooltip=\"Duvidas?\">\n            <mat-icon>perm_phone_msg</mat-icon>\n        </button>\n\n        <span>\n            <p *ngFor=\"let supportItem of supportList\">\n                {{ supportItem.label }}:\n                <a [href]=\"supportItem.linkHref\" target=\"blank\">{{ supportItem.linkText }}</a>\n            </p>\n        </span>\n\n        <span fxFlex></span>\n\n        <img alt=\"DATASUS - Minist\u00E9rio da Sa\u00FAde\" src=\"https://estatico.saude.gov.br/logos-colorido.png\" />\n    </mat-toolbar-row>\n</mat-toolbar>\n",
                    styles: ["mat-toolbar{z-index:5;position:relative;overflow:hidden}mat-toolbar,mat-toolbar button,mat-toolbar img,mat-toolbar span{transition:.4s}mat-toolbar button{display:none}mat-toolbar span p{font-size:.6em;line-height:1em;margin:0}mat-toolbar img{max-width:392px;max-height:50px;-webkit-filter:grayscale(1);filter:grayscale(1)}mat-toolbar:hover img{-webkit-filter:grayscale(0);filter:grayscale(0)}@media all and (max-width:959px){mat-toolbar button{display:block}mat-toolbar span:not(:empty){display:none}mat-toolbar img{max-width:284px;max-height:42px}}"]
                }] }
    ];
    return FooterComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LayoutComponent = /** @class */ (function () {
    function LayoutComponent(mediaObserver, layoutService, dialogService, changeDetectorRef, router) {
        var _this = this;
        this.mediaObserver = mediaObserver;
        this.layoutService = layoutService;
        this.dialogService = dialogService;
        this.changeDetectorRef = changeDetectorRef;
        /** @type {?} */
        var finish = (/**
         * @return {?}
         */
        function () {
            _this.layoutService.loaded();
            _this.colorizeAndAnimate(true);
        });
        this.routerEventSubscription = router.events.subscribe((/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            // Events:
            // ★ NavigationStart
            // ☆ RouteConfigLoadStart
            // ☆ RouteConfigLoadEnd
            // ☆ RoutesRecognized
            // ☆ GuardsCheckStart
            // ☆ ChildActivationStart
            // ☆ ActivationStart
            // ☆ GuardsCheckEnd
            // ☆ ResolveStart
            // ☆ ResolveEnd
            // ☆ ChildActivationEnd
            // ☆ ActivationEnd
            // ★ NavigationEnd
            // ★ NavigationCancel
            // ★ NavigationError
            // ☆ Scroll
            if (event instanceof NavigationStart) {
                _this.animatedClass$ = of('');
                _this.layoutService.loading();
            }
            if (event instanceof NavigationError) {
                /** @type {?} */
                var message_1;
                if (typeof event.error === 'string') {
                    message_1 = event.error;
                }
                else if (typeof event.error.message === 'string') {
                    message_1 = event.error.message;
                }
                console.log('%cRouter.event (NavigationError):', 'background-color: #444; color: #fa6', event.error);
                finish();
                if (message_1) {
                    router.navigate(["/" + DATASUS_ROUTE_HOME])
                        .then((/**
                     * @return {?}
                     */
                    function () { return _this.dialogService.showAlert(message_1); }));
                }
            }
            if (event instanceof NavigationEnd) {
                finish();
            }
            if (event instanceof NavigationCancel) {
                finish();
            }
        }));
    }
    /**
     * @return {?}
     */
    LayoutComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.isLoading$ = this.layoutService.isLoading();
        this.menuSidenavOpen$ = this.layoutService.menuSidenavOpen();
        this.mediaSubscription = this.mediaObserver.asObservable().subscribe((/**
         * @param {?} changes
         * @return {?}
         */
        function (changes) { return _this.calculateSidenavStatus(); }));
    };
    /**
     * @return {?}
     */
    LayoutComponent.prototype.ngAfterViewInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.changeDetectorRef.detectChanges();
        this.enabled$ = this.layoutService.isEnabled().pipe(tap((/**
         * @param {?} enabled
         * @return {?}
         */
        function (enabled) {
            if (enabled) {
                _this.calculateSidenavStatus();
            }
            _this.colorizeAndAnimate(false);
        })));
    };
    /**
     * @return {?}
     */
    LayoutComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.mediaSubscription.unsubscribe();
        this.routerEventSubscription.unsubscribe();
    };
    /**
     * @return {?}
     */
    LayoutComponent.prototype.menuSidenavClosed = /**
     * @return {?}
     */
    function () {
        this.layoutService.menuSidenavCollapsed();
    };
    /**
     * @return {?}
     */
    LayoutComponent.prototype.menuSidebarSwipeRight = /**
     * @return {?}
     */
    function () {
        this.layoutService.menuSidenavExpanded();
    };
    /**
     * @private
     * @param {?} withDelay
     * @return {?}
     */
    LayoutComponent.prototype.colorizeAndAnimate = /**
     * @private
     * @param {?} withDelay
     * @return {?}
     */
    function (withDelay) {
        /** @type {?} */
        var layoutAnimation;
        /** @type {?} */
        var layoutColor;
        try {
            layoutAnimation = this.routerOutlet.activatedRouteData.layoutAnimation;
        }
        catch (e) {
            layoutAnimation = false;
        }
        try {
            layoutColor = this.routerOutlet.activatedRouteData.layoutColor;
        }
        catch (e) {
            layoutColor = 'none';
        }
        if (withDelay) {
            this.animatedClass$ = of(layoutAnimation ? 'animated' : '').pipe(delay(1));
            this.layoutColorClass$ = of('with-layout-color-' + layoutColor).pipe(delay(1));
        }
        else {
            this.animatedClass$ = of(layoutAnimation ? 'animated' : '');
            this.layoutColorClass$ = of('with-layout-color-' + layoutColor);
        }
    };
    /**
     * @private
     * @return {?}
     */
    LayoutComponent.prototype.calculateSidenavStatus = /**
     * @private
     * @return {?}
     */
    function () {
        /** @type {?} */
        var isMobile = this.mediaObserver.isActive('lt-md');
        this.menuSidenavMode = isMobile ? 'over' : 'side';
        if (isMobile) {
            this.layoutService.menuSidenavCollapsed();
        }
        else {
            this.layoutService.menuSidenavExpanded();
        }
    };
    LayoutComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-layout',
                    template: "<ng-template #mainContent>\n    <section class=\"main-content-wrapper\" [ngClass]=\"layoutColorClass$ | async\" fxLayout=\"column\" fxFlex=\"nogrow noshrink\">\n        <div class=\"dot-wrapper\" [ngClass]=\"animatedClass$ | async\">\n            <div class=\"dot\" [ngClass]=\"animatedClass$ | async\"></div>\n        </div>\n        <div class=\"main-content\" [ngClass]=\"animatedClass$ | async\" [class.with-loading]=\"isLoading$ | async\">\n            <span class=\"router-content\" [class.blured]=\"isLoading$ | async\">\n                <router-outlet #routerOutlet=\"outlet\"></router-outlet>\n            </span>\n            <datasus-loader *ngIf=\"isLoading$ | async\"></datasus-loader>\n        </div>\n    </section>\n</ng-template>\n\n<ng-template #withoutLayout>\n    <div class=\"without-layout\" fxFlexFill>\n        <ng-container *ngTemplateOutlet=\"mainContent\"></ng-container>\n    </div>\n</ng-template>\n\n<mat-sidenav-container class=\"with-layout\" *ngIf=\"enabled$ | async; else withoutLayout\" fxFlexFill>\n    <span class=\"ghost-area-menu-sidenav\" (swiperight)=\"menuSidebarSwipeRight()\"></span>\n    <mat-sidenav\n        class=\"menu-sidenav\"\n        position=\"start\"\n        [mode]=\"menuSidenavMode\"\n        [opened]=\"menuSidenavOpen$ | async\"\n        (closed)=\"menuSidenavClosed()\"\n    >\n        <datasus-menu-sidenav></datasus-menu-sidenav>\n    </mat-sidenav>\n    <mat-sidenav\n        #notificationSidenav\n        class=\"notification-sidenav\"\n        mode=\"over\"\n        opened=\"false\"\n        position=\"end\"\n    >\n        <datasus-notification-sidenav [sidenav]=\"notificationSidenav\"></datasus-notification-sidenav>\n    </mat-sidenav>\n    <div fxLayout=\"column\" fxFlexFill>\n        <datasus-toolbar [notificationSidenav]=\"notificationSidenav\"></datasus-toolbar>\n        <ng-container *ngTemplateOutlet=\"mainContent\"></ng-container>\n        <datasus-footer></datasus-footer>\n    </div>\n</mat-sidenav-container>\n\n\n\n",
                    styles: [".animated.dot-wrapper,.animated.main-content{opacity:0;-webkit-animation:1s ease-in-out forwards show-up;animation:1s ease-in-out forwards show-up}.animated.dot-wrapper{transform:translateY(100%);-webkit-animation-delay:.5s;animation-delay:.5s}.animated.main-content{transform:translateY(50vh);-webkit-animation-delay:.8s;animation-delay:.8s}.with-layout-color-none .dot-wrapper,.with-layout-color-none .main-content{transform:translateY(0);opacity:1;-webkit-animation:none;animation:none}@-webkit-keyframes show-up{from{opacity:0}to{transform:translateY(0);opacity:1}}@keyframes show-up{from{opacity:0}to{transform:translateY(0);opacity:1}}.with-layout-color-dusky.main-content-wrapper{background:rgba(109,109,109,.1)}.with-layout-color-dusky.main-content-wrapper .dot.animated{background:rgba(109,109,109,.4);box-shadow:0 0 0 5vw rgba(109,109,109,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-dusky;animation:1s ease-in-out 1.2s forwards dot-dusky}@-webkit-keyframes dot-dusky{from{box-shadow:0 0 0 5vw rgba(109,109,109,.4)}to{box-shadow:0 0 0 15vw rgba(109,109,109,.4),0 0 0 45vw rgba(109,109,109,.2),0 0 0 85vw rgba(109,109,109,.3)}}@keyframes dot-dusky{from{box-shadow:0 0 0 5vw rgba(109,109,109,.4)}to{box-shadow:0 0 0 15vw rgba(109,109,109,.4),0 0 0 45vw rgba(109,109,109,.2),0 0 0 85vw rgba(109,109,109,.3)}}.with-layout-color-bright.main-content-wrapper{background:rgba(255,255,255,.1)}.with-layout-color-bright.main-content-wrapper .dot.animated{background:rgba(255,255,255,.4);box-shadow:0 0 0 5vw rgba(255,255,255,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-bright;animation:1s ease-in-out 1.2s forwards dot-bright}@-webkit-keyframes dot-bright{from{box-shadow:0 0 0 5vw rgba(255,255,255,.4)}to{box-shadow:0 0 0 15vw rgba(255,255,255,.4),0 0 0 45vw rgba(255,255,255,.2),0 0 0 85vw rgba(255,255,255,.3)}}@keyframes dot-bright{from{box-shadow:0 0 0 5vw rgba(255,255,255,.4)}to{box-shadow:0 0 0 15vw rgba(255,255,255,.4),0 0 0 45vw rgba(255,255,255,.2),0 0 0 85vw rgba(255,255,255,.3)}}.with-layout-color-primary.main-content-wrapper{background:rgba(94,146,243,.1)}.with-layout-color-primary.main-content-wrapper .dot.animated{background:rgba(94,146,243,.4);box-shadow:0 0 0 5vw rgba(94,146,243,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-primary;animation:1s ease-in-out 1.2s forwards dot-primary}@-webkit-keyframes dot-primary{from{box-shadow:0 0 0 5vw rgba(94,146,243,.4)}to{box-shadow:0 0 0 15vw rgba(94,146,243,.4),0 0 0 45vw rgba(94,146,243,.2),0 0 0 85vw rgba(94,146,243,.3)}}@keyframes dot-primary{from{box-shadow:0 0 0 5vw rgba(94,146,243,.4)}to{box-shadow:0 0 0 15vw rgba(94,146,243,.4),0 0 0 45vw rgba(94,146,243,.2),0 0 0 85vw rgba(94,146,243,.3)}}.with-layout-color-accent.main-content-wrapper{background:rgba(255,192,70,.1)}.with-layout-color-accent.main-content-wrapper .dot.animated{background:rgba(255,192,70,.4);box-shadow:0 0 0 5vw rgba(255,192,70,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-accent;animation:1s ease-in-out 1.2s forwards dot-accent}@-webkit-keyframes dot-accent{from{box-shadow:0 0 0 5vw rgba(255,192,70,.4)}to{box-shadow:0 0 0 15vw rgba(255,192,70,.4),0 0 0 45vw rgba(255,192,70,.2),0 0 0 85vw rgba(255,192,70,.3)}}@keyframes dot-accent{from{box-shadow:0 0 0 5vw rgba(255,192,70,.4)}to{box-shadow:0 0 0 15vw rgba(255,192,70,.4),0 0 0 45vw rgba(255,192,70,.2),0 0 0 85vw rgba(255,192,70,.3)}}.with-layout-color-warn.main-content-wrapper{background:rgba(250,87,136,.1)}.with-layout-color-warn.main-content-wrapper .dot.animated{background:rgba(250,87,136,.4);box-shadow:0 0 0 5vw rgba(250,87,136,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-warn;animation:1s ease-in-out 1.2s forwards dot-warn}@-webkit-keyframes dot-warn{from{box-shadow:0 0 0 5vw rgba(250,87,136,.4)}to{box-shadow:0 0 0 15vw rgba(250,87,136,.4),0 0 0 45vw rgba(250,87,136,.2),0 0 0 85vw rgba(250,87,136,.3)}}@keyframes dot-warn{from{box-shadow:0 0 0 5vw rgba(250,87,136,.4)}to{box-shadow:0 0 0 15vw rgba(250,87,136,.4),0 0 0 45vw rgba(250,87,136,.2),0 0 0 85vw rgba(250,87,136,.3)}}.with-layout-color-success.main-content-wrapper{background:rgba(96,173,94,.1)}.with-layout-color-success.main-content-wrapper .dot.animated{background:rgba(96,173,94,.4);box-shadow:0 0 0 5vw rgba(96,173,94,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-success;animation:1s ease-in-out 1.2s forwards dot-success}@-webkit-keyframes dot-success{from{box-shadow:0 0 0 5vw rgba(96,173,94,.4)}to{box-shadow:0 0 0 15vw rgba(96,173,94,.4),0 0 0 45vw rgba(96,173,94,.2),0 0 0 85vw rgba(96,173,94,.3)}}@keyframes dot-success{from{box-shadow:0 0 0 5vw rgba(96,173,94,.4)}to{box-shadow:0 0 0 15vw rgba(96,173,94,.4),0 0 0 45vw rgba(96,173,94,.2),0 0 0 85vw rgba(96,173,94,.3)}}.with-layout-color-error.main-content-wrapper{background:rgba(255,81,49,.1)}.with-layout-color-error.main-content-wrapper .dot.animated{background:rgba(255,81,49,.4);box-shadow:0 0 0 5vw rgba(255,81,49,.4);-webkit-animation:1s ease-in-out 1.2s forwards dot-error;animation:1s ease-in-out 1.2s forwards dot-error}@-webkit-keyframes dot-error{from{box-shadow:0 0 0 5vw rgba(255,81,49,.4)}to{box-shadow:0 0 0 15vw rgba(255,81,49,.4),0 0 0 45vw rgba(255,81,49,.2),0 0 0 85vw rgba(255,81,49,.3)}}@keyframes dot-error{from{box-shadow:0 0 0 5vw rgba(255,81,49,.4)}to{box-shadow:0 0 0 15vw rgba(255,81,49,.4),0 0 0 45vw rgba(255,81,49,.2),0 0 0 85vw rgba(255,81,49,.3)}}.dot-wrapper{padding:20px}.dot-wrapper .dot{width:1px;height:1px;border-radius:50%}.main-content-wrapper{position:relative;overflow-y:auto}.with-layout{position:absolute;top:0;bottom:0;left:0;right:0}.with-layout .ghost-area-menu-sidenav{display:block;z-index:1000;background:0 0;opacity:0;height:100vh;width:24px;position:fixed;top:0;border:0;left:0}.with-layout .menu-sidenav{box-shadow:4px 0 16px rgba(0,0,0,.2),-4px 0 16px rgba(0,0,0,.2);width:256px}.with-layout .notification-sidenav{width:320px}.with-layout .dot-wrapper{padding:0 20px}.with-layout .main-content-wrapper .main-content{padding:24px 0}.without-layout{position:absolute;top:0;bottom:0;left:0;right:0}.without-layout .main-content-wrapper .main-content{padding:30px 0}.router-content{transition:.4s}.router-content.blured{-webkit-filter:blur(8px);filter:blur(8px);display:block}datasus-loader{position:absolute;top:0;bottom:0;left:0;right:0}.main-content.with-loading{position:relative;height:100vh;overflow:hidden}"]
                }] }
    ];
    /** @nocollapse */
    LayoutComponent.ctorParameters = function () { return [
        { type: MediaObserver },
        { type: LayoutService },
        { type: DialogService },
        { type: ChangeDetectorRef },
        { type: Router }
    ]; };
    LayoutComponent.propDecorators = {
        routerOutlet: [{ type: ViewChild, args: ['routerOutlet',] }]
    };
    return LayoutComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LoaderComponent = /** @class */ (function () {
    function LoaderComponent(layoutService, authService) {
        var _this = this;
        this.layoutService = layoutService;
        this.authService = authService;
        this.authService.gettingOutEvent().pipe(take(1)).subscribe((/**
         * @return {?}
         */
        function () { return _this.layoutService.loading(); }));
    }
    LoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-loader',
                    template: "<section fxLayout=\"column\" fxLayoutAlign=\"center center\">\n  <div class=\"loader\">\n    <div class=\"circles\">\n      <div class=\"circle circle-bottom\"></div>\n      <div class=\"circle circle-top\"></div>\n      <div class=\"circle circle-left\"></div>\n      <div class=\"circle circle-right\"></div>\n    </div>\n    <div class=\"image image-negative\"></div>\n    <div class=\"image image-positive\"></div>\n  </div>\n  <span>\n    Carregando\u2026\n  </span>\n</section>\n",
                    styles: ["section{z-index:1001;position:-webkit-sticky;position:sticky;top:0;left:0;right:0;bottom:0;text-transform:uppercase;text-align:center;color:#1b1b1b;background:0 0;height:100%}section span{display:block;font-size:.875em;margin-top:12px}section .loader{display:inline-block;margin-top:24px;width:72px;height:72px;-webkit-animation:.4s .4s both loader-fade-in;animation:.4s .4s both loader-fade-in}section .loader .circles{width:72px;height:72px;position:relative;-webkit-animation:6s infinite circles;animation:6s infinite circles;border-radius:50%;-webkit-backface-visibility:hidden;backface-visibility:hidden}section .loader .circles:before{content:\"\";width:47.52px;height:47.52px;position:absolute;border-radius:50%;top:12.24px;left:12.24px;z-index:1}section .loader .circles .circle{width:61.2px;height:61.2px;position:absolute;border-radius:100%;z-index:1002;-webkit-backface-visibility:hidden;backface-visibility:hidden}section .loader .circles .circle.circle-bottom{bottom:0;left:6px;background:linear-gradient(to left,#424242 0,transparent 75%)}section .loader .circles .circle.circle-top{left:6px;background:linear-gradient(to right,#424242 0,transparent 75%)}section .loader .circles .circle.circle-left{top:6px;background:linear-gradient(to top,#424242 0,transparent 75%)}section .loader .circles .circle.circle-right{top:6px;right:0;background:linear-gradient(to bottom,#424242 0,transparent 75%)}section .loader .image{width:50.4px;height:50.4px;background-color:transparent;background-position:0 0;background-repeat:no-repeat;background-size:cover;position:absolute;top:50%;left:50%;transform:translate3d(-50%,-50%,0);z-index:1004}section .loader .image.image-positive{-webkit-animation:6s infinite image;animation:6s infinite image;background-image:url(/assets/datasus/layout/loader/logo-datasus_colorida.png)}section .loader .image.image-negative{background-image:url(/assets/datasus/layout/loader/logo-datasus_escala-de-cinza.png)}@-webkit-keyframes loader-fade-in{from{transform:translateY(80px);opacity:0}to{transform:translateY(0);opacity:1}}@keyframes loader-fade-in{from{transform:translateY(80px);opacity:0}to{transform:translateY(0);opacity:1}}@-webkit-keyframes circles{0%,100%{transform:rotate(0)}50%{transform:rotate(360deg)}}@keyframes circles{0%,100%{transform:rotate(0)}50%{transform:rotate(360deg)}}@-webkit-keyframes image{0%,100%{opacity:1}50%{opacity:0}}@keyframes image{0%,100%{opacity:1}50%{opacity:0}}"]
                }] }
    ];
    /** @nocollapse */
    LoaderComponent.ctorParameters = function () { return [
        { type: LayoutService },
        { type: AuthService }
    ]; };
    return LoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var MenuSidenavComponent = /** @class */ (function () {
    function MenuSidenavComponent(layoutConfig, configService, layoutService, menuService) {
        this.layoutConfig = layoutConfig;
        this.configService = configService;
        this.layoutService = layoutService;
        this.menuService = menuService;
        this.homeRoute = "/" + DATASUS_ROUTE_HOME;
        this.versionRoute = "/" + DATASUS_ROUTE_RELEASE_NOTES;
    }
    /**
     * @return {?}
     */
    MenuSidenavComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.appName = this.layoutConfig.appName;
        this.appVersion = this.layoutConfig.appVersion;
        this.menu$ = this.menuService.get();
        this.appVersionSuffix$ = this.configService.getList([
            'ENV',
            'BUILD_NUMBER'
        ]).pipe(map((/**
         * @param {?} configs
         * @return {?}
         */
        function (configs) { return ((configs[0] || '')
            +
                (configs[1] ? "#" + configs[1] : '')); })));
    };
    /**
     * @return {?}
     */
    MenuSidenavComponent.prototype.closeMenu = /**
     * @return {?}
     */
    function () {
        this.layoutService.menuSidenavCollapsed();
    };
    /**
     * @param {?} path
     * @return {?}
     */
    MenuSidenavComponent.prototype.isInternalLink = /**
     * @param {?} path
     * @return {?}
     */
    function (path) {
        path = path || '';
        path = String(path);
        /** @type {?} */
        var regex = /^https?:\/\/[^\/].*/;
        return !regex.test(path);
    };
    MenuSidenavComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-menu-sidenav',
                    template: "<ng-template #menuTemplate let-itens=\"itens\" let-descricao=\"descricao\" let-path=\"path\">\n    <ng-template #externalLinkTemplate>\n        <a mat-list-item [attr.href]=\"path\">\n            <span matLine>{{ descricao }}</span>\n        </a>\n    </ng-template>\n    <ng-container *ngIf=\"path\">\n        <a *ngIf=\"isInternalLink(path) else externalLinkTemplate\" mat-list-item [routerLink]=\"path\">\n            <span matLine>{{ descricao }}</span>\n        </a>\n    </ng-container>\n    <mat-expansion-panel *ngIf=\"!path\">\n        <mat-expansion-panel-header>\n            <mat-panel-title>\n                <span>{{ descricao }}</span>\n            </mat-panel-title>\n        </mat-expansion-panel-header>\n        <mat-nav-list *ngIf=\"itens?.length\">\n            <ng-container *ngFor=\"let item of itens\">\n                <ng-container *ngTemplateOutlet=\"menuTemplate;context:item\"></ng-container>\n            </ng-container>\n        </mat-nav-list>\n    </mat-expansion-panel>\n</ng-template>\n\n<ng-template #loading>\n    <mat-progress-bar class=\"loading\" mode=\"query\" color=\"accent\"></mat-progress-bar>\n</ng-template>\n\n<aside fxLayout=\"column\" fxFlexFill (swipeleft)=\"closeMenu()\">\n    <mat-toolbar class=\"mat-elevation-z2\">\n        <mat-toolbar-row class=\"clickable\" fxLayout=\"row\" [routerLink]=\"homeRoute\">\n            {{ appName }}\n        </mat-toolbar-row>\n    </mat-toolbar>\n\n    <div class=\"menu hide-scrollbars\" fxFlex=\"nogrow noshrink\">\n        <ng-container *ngIf=\"(menu$ | async) as menu else loading\">\n            <mat-nav-list *ngIf=\"menu?.length\">\n                <ng-container *ngFor=\"let item of menu\">\n                    <ng-container *ngTemplateOutlet=\"menuTemplate;context:item\"></ng-container>\n                </ng-container>\n            </mat-nav-list>\n        </ng-container>\n    </div>\n\n    <mat-toolbar class=\"mat-elevation-z1-upside-down\">\n        <mat-toolbar-row fxLayout=\"row\">\n            <span class=\"clickable\" [routerLink]=\"versionRoute\">\n                {{ appVersion }}\n                <span class=\"version-suffix\">{{ appVersionSuffix$ | async }}</span>\n            </span>\n            <span fxFlex></span>\n            <a mat-icon-button aria-label=\"Fechar painel\" (click)=\"closeMenu()\">\n                <mat-icon aria-hidden>chevron_left</mat-icon>\n            </a>\n        </mat-toolbar-row>\n    </mat-toolbar>\n</aside>\n",
                    styles: ["aside{background:#424242;overflow:hidden}aside,aside mat-toolbar,aside span{color:#fff}aside .menu,aside mat-expansion-panel,aside mat-nav-list,aside mat-toolbar{background:0 0}aside .menu .loading{height:1px}aside .menu span{padding:0 16px;margin:0}aside .menu mat-expansion-panel{box-shadow:none;border:none;border-radius:0}aside .menu mat-expansion-panel mat-expansion-panel-header{padding:0 24px 0 0}aside .menu /deep/ .mat-expansion-indicator::after{color:#c7c7c7}aside .menu /deep/ .mat-expansion-panel-body,aside .menu /deep/ .mat-list-item-content{padding:0}aside .menu /deep/ .mat-list-item-content{background:rgba(109,109,109,.15)}aside .menu /deep/ .mat-expansion-panel-body{background:rgba(27,27,27,.5)}aside .menu /deep/ .mat-expansion-panel-body .mat-list-item-content{background:0 0}aside .menu /deep/ .mat-expansion-panel-body .mat-list-item{opacity:0;text-indent:20px;transition-property:opacity,text-indent;transition-timing-function:cubic-bezier(.18,.89,.32,1.28);transition-duration:.4s}aside .menu /deep/ .mat-expanded .mat-list-item{opacity:1;text-indent:0}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(1){transition-delay:0s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(2){transition-delay:.12s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(3){transition-delay:.24s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(4){transition-delay:.36s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(5){transition-delay:.48s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(6){transition-delay:.6s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(7){transition-delay:.72s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(8){transition-delay:.84s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(9){transition-delay:.96s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(10){transition-delay:1.08s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(11){transition-delay:1.2s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(12){transition-delay:1.32s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(13){transition-delay:1.44s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(14){transition-delay:1.56s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(15){transition-delay:1.68s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(16){transition-delay:1.8s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(17){transition-delay:1.92s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(18){transition-delay:2.04s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(19){transition-delay:2.16s}aside .menu /deep/ .mat-expanded .mat-list-item:nth-child(20){transition-delay:2.28s}.version-suffix{background:#6d6d6d;border-radius:8px;padding:4px;opacity:.5;font-family:monospace;transition:opacity 350ms}.version-suffix:empty{padding:0;opacity:0}.clickable,.clickable:focus,.clickable:hover,.clickable:visited{cursor:pointer;outline:0;transition:color 350ms;color:#fafafa}.clickable:focus,.clickable:hover{color:#ffc046}.clickable:focus .version-suffix,.clickable:hover .version-suffix{opacity:.25}"]
                }] }
    ];
    /** @nocollapse */
    MenuSidenavComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: ['LayoutConfig',] }] },
        { type: ConfigService },
        { type: LayoutService },
        { type: MenuService }
    ]; };
    return MenuSidenavComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var INTERVAL_SECONDS = 10;
var NotificationButtonComponent = /** @class */ (function () {
    function NotificationButtonComponent(notificacaoService) {
        this.notificacaoService = notificacaoService;
        this.nonReceivedCounter = 0;
    }
    /**
     * @return {?}
     */
    NotificationButtonComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.intervalNonReceivedCounterSubscription = this.notificacaoService.getIntervalNonReceivedCounter(INTERVAL_SECONDS, (/**
         * @return {?}
         */
        function () { return !_this.sidenav.opened; })).subscribe((/**
         * @param {?} counter
         * @return {?}
         */
        function (counter) { return _this.nonReceivedCounter = counter; }));
    };
    /**
     * @return {?}
     */
    NotificationButtonComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.intervalNonReceivedCounterSubscription.unsubscribe();
        this.nonReceivedCounter = 0;
    };
    /**
     * @param {?} counter
     * @return {?}
     */
    NotificationButtonComponent.prototype.hasNonReceivedMessages = /**
     * @param {?} counter
     * @return {?}
     */
    function (counter) {
        return !!counter && counter > 0;
    };
    /**
     * @param {?} counter
     * @return {?}
     */
    NotificationButtonComponent.prototype.nonReceivedText = /**
     * @param {?} counter
     * @return {?}
     */
    function (counter) {
        if (!counter) {
            return '';
        }
        /** @type {?} */
        var counterMax = 9;
        return counter > counterMax ? counterMax + "+" : counter.toString();
    };
    /**
     * @return {?}
     */
    NotificationButtonComponent.prototype.showMessages = /**
     * @return {?}
     */
    function () {
        this.sidenav.open();
        this.nonReceivedCounter = 0;
    };
    NotificationButtonComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-notification-button',
                    template: "<button\n    type=\"button\"\n    mat-icon-button\n    [class.has-non-received-notification]=\"hasNonReceivedMessages(nonReceivedCounter)\"\n    (click)=\"showMessages()\"\n>\n    <mat-icon class=\"icon\">notifications</mat-icon>\n    <span class=\"badge\" *ngIf=\"hasNonReceivedMessages(nonReceivedCounter)\">\n        {{ nonReceivedText(nonReceivedCounter) }}\n    </span>\n</button>\n\n<audio *ngIf=\"hasNonReceivedMessages(nonReceivedCounter)\" autoplay>\n    <source src=\"/assets/datasus/layout/notification-button/appointed.ogg\" type=\"audio/ogg\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.m4r\" type=\"audio/x-m4r\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.mp3\" type=\"audio/mpeg\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.ac3\" type=\"audio/ac3\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.aac\" type=\"audio/aac\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.m4a\" type=\"audio/m4a\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.wma\" type=\"audio/wma\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.flac\" type=\"audio/flac\" />\n    <source src=\"/assets/datasus/layout/notification-button/appointed.wav\" type=\"audio/wav\" />\n</audio>\n",
                    styles: ["button{position:relative}button.has-non-received-notification .icon{transform-origin:50% 0;-webkit-animation-name:has-non-received-notification;animation-name:has-non-received-notification;-webkit-animation-duration:8s;animation-duration:8s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite}button .badge{position:absolute;display:block;width:20px;height:20px;line-height:20px;border-radius:50%;top:0;right:0;font-size:.75em;background:#ff8f00;color:#424242}@-webkit-keyframes has-non-received-notification{0%,12%,20%{transform:rotate(0)}1%{transform:rotate(25deg)}3%{transform:rotate(-20deg)}5%{transform:rotate(10deg)}7%{transform:rotate(-5deg)}9%{transform:rotate(2deg)}11%{transform:rotate(-2deg)}}@keyframes has-non-received-notification{0%,12%,20%{transform:rotate(0)}1%{transform:rotate(25deg)}3%{transform:rotate(-20deg)}5%{transform:rotate(10deg)}7%{transform:rotate(-5deg)}9%{transform:rotate(2deg)}11%{transform:rotate(-2deg)}}"]
                }] }
    ];
    /** @nocollapse */
    NotificationButtonComponent.ctorParameters = function () { return [
        { type: NotificacaoService }
    ]; };
    NotificationButtonComponent.propDecorators = {
        sidenav: [{ type: Input }]
    };
    return NotificationButtonComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var NotificationCardComponent = /** @class */ (function () {
    function NotificationCardComponent(notificacaoService) {
        this.notificacaoService = notificacaoService;
        this.removed = new EventEmitter(true);
    }
    /**
     * @return {?}
     */
    NotificationCardComponent.prototype.getAndShowDetails = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.showDetails = true;
        if (this.notification.temTextoDetalhado && !this.notification.textoDetalhado) {
            this.loadingDetails = true;
            this.notificacaoService.getDetails(this.notification.id).pipe(delay(2000), // TODO Remover
            finalize((/**
             * @return {?}
             */
            function () { return _this.loadingDetails = false; }))).subscribe((/**
             * @param {?} details
             * @return {?}
             */
            function (details) { return _this.notification.textoDetalhado = details; }), (/**
             * @param {?} error
             * @return {?}
             */
            function (error) { return console.error('Erro ao buscar os detalhes da notificação', error); }));
        }
    };
    /**
     * @return {?}
     */
    NotificationCardComponent.prototype.hideDetails = /**
     * @return {?}
     */
    function () {
        this.showDetails = false;
    };
    /**
     * @param {?=} actionId
     * @return {?}
     */
    NotificationCardComponent.prototype.removeMe = /**
     * @param {?=} actionId
     * @return {?}
     */
    function (actionId) {
        this.removed.emit({
            notification: this.notification,
            actionId: actionId
        });
    };
    /**
     * @param {?=} dataAtual
     * @return {?}
     */
    NotificationCardComponent.prototype.getDate = /**
     * @param {?=} dataAtual
     * @return {?}
     */
    function (dataAtual) {
        return new Date(dataAtual || Date.now());
    };
    /**
     * @param {?} relativeDate
     * @param {?} absoluteDate
     * @return {?}
     */
    NotificationCardComponent.prototype.resolveDate = /**
     * @param {?} relativeDate
     * @param {?} absoluteDate
     * @return {?}
     */
    function (relativeDate, absoluteDate) {
        /** @type {?} */
        var datePipe = new DatePipe('pt');
        /** @type {?} */
        var formats = {
            'Dias atrás': (/**
             * @return {?}
             */
            function () { return datePipe.transform(absoluteDate, 'dd/MM/yyyy HH:mm'); }),
            'Semanas atrás': (/**
             * @return {?}
             */
            function () { return datePipe.transform(absoluteDate, 'dd/MM/yyyy'); }),
            'Meses atrás': (/**
             * @return {?}
             */
            function () { return datePipe.transform(absoluteDate, 'MMMM/yyyy'); }),
            'Anos atrás': (/**
             * @return {?}
             */
            function () { return datePipe.transform(absoluteDate, 'MMMM/yyyy'); }),
        };
        if (typeof formats[relativeDate] === 'function') {
            return formats[relativeDate]();
        }
        return relativeDate;
    };
    NotificationCardComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-notification-card',
                    template: "<ng-template #loadingTemplate>\n    <div\n        aria-label=\"Carregando notifica\u00E7\u00F5es\"\n        fxLayout=\"column\"\n        fxLayoutAlign=\"center center\"\n        style=\"padding-top: 20px\"\n    >\n        <mat-spinner aria-hidden color=\"accent\" diameter=\"42\" strokeWidth=\"2\"></mat-spinner>\n    </div>\n</ng-template>\n\n<ng-template #actionTemplate let-action>\n    <button\n        type=\"button\"\n        mat-button\n        [attr.aria-label]=\"'Executar a\u00E7\u00E3o: ' + action.rotulo\"\n        (click)=\"removeMe(action.id)\"\n    >\n        {{ action.rotulo }}\n    </button>\n</ng-template>\n\n<ng-template #actionsTemplate let-actions>\n    <ng-container *ngFor=\"let action of actions | datasusListUntilIndex : 2\">\n        <ng-container *ngTemplateOutlet=\"actionTemplate; context: {$implicit: action}\"></ng-container>\n    </ng-container>\n    <ng-container *ngIf=\"actions.length > 2\">\n        <button mat-icon-button aria-label=\"Abrir outras a\u00E7\u00F5es\" [matMenuTriggerFor]=\"menu\">\n            <mat-icon aria-hidden>more_vert</mat-icon>\n        </button>\n        <mat-menu #menu=\"matMenu\">\n            <ng-container *ngFor=\"let action of actions | datasusListAfterIndex : 2\">\n                <ng-container *ngTemplateOutlet=\"actionTemplate; context: {$implicit: action}\"></ng-container>\n            </ng-container>\n        </mat-menu>\n    </ng-container>\n</ng-template>\n\n<mat-card\n    class=\"notification\"\n    [class.notification-new]=\"notification.nova\"\n    [class.notification-removing]=\"notification.removendo\"\n>\n    <mat-card-header [matTooltip]=\"notification.dataEnvio | date: 'medium'\" matTooltipPosition=\"above\">\n        <mat-card-title>{{ notification.siglaSistemaOrigem }}</mat-card-title>\n        <h5 class=\"mat-caption\" [class.has-focus]=\"hasFocusOnRemoveIcon\">\n            {{ resolveDate(notification.dataEnvio | datasusRelativeDate : getDate(notification.dataAtual), notification.dataEnvio) }}\n            <button\n                type=\"button\"\n                aria-label=\"Descartar notifica\u00E7\u00E3o\"\n                mat-icon-button\n                matTooltip=\"Descartar notifica\u00E7\u00E3o\"\n                (focus)=\"hasFocusOnRemoveIcon = true\"\n                (blur)=\"hasFocusOnRemoveIcon = false\"\n                (click)=\"removeMe()\"\n            >\n                <mat-icon aria-hidden>clear</mat-icon>\n            </button>\n        </h5>\n    </mat-card-header>\n    <mat-card-content>\n        <p class=\"mat-body-2\">{{ notification.titulo }}</p>\n        {{ notification.textoResumido }}\n        <button\n            *ngIf=\"!!notification?.temTextoDetalhado || !!notification?.acoes?.length\"\n            type=\"button\"\n            class=\"details-trigger\"\n            [attr.aria-label]=\"showDetails ? 'Ocutar detalhes' : 'Exibir detalhes'\"\n            mat-icon-button\n            [class.details-displayed]=\"showDetails\"\n            (click)=\"showDetails ? hideDetails() : getAndShowDetails()\"\n        >\n            <mat-icon aria-hidden>expand_more</mat-icon>\n        </button>\n        <span [class.details-displayed]=\"showDetails && !!notification?.temTextoDetalhado\" class=\"details-container\">\n            <span *ngIf=\"showDetails\">\n                <span *ngIf=\"!loadingDetails else loadingTemplate\" [innerHTML]=\"notification.textoDetalhado | safeHtml\"></span>\n            </span>\n        </span>\n    </mat-card-content>\n    <mat-divider *ngIf=\"showDetails && !!notification?.acoes?.length\"></mat-divider>\n    <mat-card-actions *ngIf=\"showDetails && !!notification?.acoes?.length\">\n        <ng-container *ngTemplateOutlet=\"actionsTemplate; context: {$implicit: notification.acoes}\"></ng-container>\n    </mat-card-actions>\n</mat-card>\n",
                    styles: [".notification{box-shadow:0 2px 1px -1px rgba(0,0,0,.2),0 1px 1px 0 rgba(0,0,0,.14),0 1px 3px 0 rgba(0,0,0,.12);z-index:102;background:#fff;padding:0;margin:16px 16px 24px;border-radius:4px;transition:box-shadow .3s;opacity:.9}.notification a,.notification button{z-index:104}.notification a:focus,.notification a:hover,.notification button:focus,.notification button:hover{outline:0}.notification mat-card-content{position:relative;padding:16px;margin:0}.notification mat-card-content .details-trigger{position:absolute;right:0;bottom:0;transition:transform 225ms cubic-bezier(.4,0,.2,1) 225ms;transform:rotate(0)}.notification mat-card-content .details-trigger.details-displayed{transform:rotate(-180deg)}.notification mat-card-content .details-container{display:block;width:100%;overflow:hidden;transition:225ms cubic-bezier(.4,0,.2,1);height:1px;opacity:0}.notification mat-card-content .details-container.details-displayed{overflow:auto;height:100px;opacity:1}.notification mat-card-actions{padding:0 16px;display:flex;justify-content:flex-end}.notification mat-card-header{border-radius:4px;background:#c7c7c7;line-height:48px;padding:0 16px 0 0;align-items:center;overflow:hidden}.notification mat-card-header/deep/ .mat-card-header-text{flex:1 1 0}.notification mat-card-header mat-card-title{margin:0;position:absolute;top:0}.notification mat-card-header .mat-caption{margin:0;line-height:inherit;height:48px;display:flex;flex-direction:column;transition:transform .3s,opacity .3s;align-items:flex-end}.notification mat-card-header .mat-caption.has-focus{transition:transform .1s,opacity .3s}.notification mat-card-header .mat-caption button{opacity:0;margin-top:4px}.notification.notification-new{opacity:1;box-shadow:0 3px 3px -2px rgba(0,0,0,.2),0 3px 4px 0 rgba(0,0,0,.14),0 1px 8px 0 rgba(0,0,0,.12)}.notification.notification-new mat-card-header{background:#ffc046}.notification.notification-removing{transition:225ms cubic-bezier(.46,.03,.52,.96);-webkit-filter:blur(4px);filter:blur(4px);transform:scale(.8) translateX(90%)}.notification:hover{box-shadow:0 3px 5px -1px rgba(0,0,0,.2),0 6px 10px 0 rgba(0,0,0,.14),0 1px 18px 0 rgba(0,0,0,.12)}.notification mat-card-header .mat-caption.has-focus,.notification:hover mat-card-header .mat-caption{transform:translateY(-48px)}.notification mat-card-header .mat-caption.has-focus button,.notification:hover mat-card-header .mat-caption button{opacity:1}"]
                }] }
    ];
    /** @nocollapse */
    NotificationCardComponent.ctorParameters = function () { return [
        { type: NotificacaoService }
    ]; };
    NotificationCardComponent.propDecorators = {
        notification: [{ type: Input }],
        removed: [{ type: Output }]
    };
    return NotificationCardComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var NotificationSidenavComponent = /** @class */ (function () {
    function NotificationSidenavComponent(notificacaoService) {
        this.notificacaoService = notificacaoService;
        this.loading = false;
    }
    /**
     * @return {?}
     */
    NotificationSidenavComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.sidenavOpenedStartSubscription = this.sidenav.openedStart.subscribe((/**
         * @return {?}
         */
        function () {
            _this.loading = true;
            _this.notifications = null;
            _this.notificacaoService.getNotifications().pipe(finalize((/**
             * @return {?}
             */
            function () { return _this.loading = false; })), map((/**
             * @param {?} notifications
             * @return {?}
             */
            function (notifications) { return _this.notificationToMap(notifications); }))).subscribe((/**
             * @param {?} notifications
             * @return {?}
             */
            function (notifications) { return _this.notifications = notifications; }));
        }));
    };
    /**
     * @return {?}
     */
    NotificationSidenavComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.loading = false;
        this.notifications = null;
        this.sidenavOpenedStartSubscription.unsubscribe();
    };
    /**
     * @return {?}
     */
    NotificationSidenavComponent.prototype.removeAll = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.loading = true;
        /** @type {?} */
        var ids = [];
        this.notifications.forEach((/**
         * @param {?} value
         * @param {?} key
         * @return {?}
         */
        function (value, key) {
            value.forEach((/**
             * @param {?} item
             * @return {?}
             */
            function (item) {
                item.removendo = true;
                ids.push(item.id);
            }));
        }));
        this.notifications = null;
        this.notificacaoService.remove(ids).pipe(finalize((/**
         * @return {?}
         */
        function () { return _this.loading = false; }))).subscribe((/**
         * @return {?}
         */
        function () { return console.log('Notificações removidas com sucesso!'); }), (/**
         * @param {?} error
         * @return {?}
         */
        function (error) { return console.error('Não foi possível remover todas as notificações', error); }));
    };
    /**
     * @param {?} payloadToRemove
     * @return {?}
     */
    NotificationSidenavComponent.prototype.removeItem = /**
     * @param {?} payloadToRemove
     * @return {?}
     */
    function (payloadToRemove) {
        var _this = this;
        /** @type {?} */
        var notificationToRemove = payloadToRemove.notification;
        notificationToRemove.removendo = true;
        if (!!payloadToRemove.actionId) {
            this.notificacaoService.performAction(notificationToRemove.id, payloadToRemove.actionId).subscribe((/**
             * @return {?}
             */
            function () { return redirectTo(notificationToRemove.acoes.find((/**
             * @param {?} acao
             * @return {?}
             */
            function (acao) { return acao.id === payloadToRemove.actionId; })).url); }), (/**
             * @param {?} error
             * @return {?}
             */
            function (error) { return console.error('Não foi possível executar a ação da notificação', error); }));
        }
        else {
            this.notificacaoService.remove([notificationToRemove.id]).subscribe((/**
             * @return {?}
             */
            function () {
                _this.notifications.forEach((/**
                 * @param {?} value
                 * @param {?} key
                 * @return {?}
                 */
                function (value, key) {
                    /** @type {?} */
                    var valueFiltered = value.filter((/**
                     * @param {?} notification
                     * @return {?}
                     */
                    function (notification) { return !compareObjects(notification, notificationToRemove); }));
                    if (valueFiltered.length > 0) {
                        _this.notifications.set(key, valueFiltered);
                    }
                    else {
                        _this.notifications.delete(key);
                    }
                }));
            }), (/**
             * @param {?} error
             * @return {?}
             */
            function (error) { return console.error('Não foi possível remover a notificação', error); }));
        }
    };
    /**
     * @param {?} akv
     * @param {?} bkv
     * @return {?}
     */
    NotificationSidenavComponent.prototype.notificationsKeepOrder = /**
     * @param {?} akv
     * @param {?} bkv
     * @return {?}
     */
    function (akv, bkv) {
        return 1;
    };
    /**
     * @private
     * @param {?} notifications
     * @return {?}
     */
    NotificationSidenavComponent.prototype.notificationToMap = /**
     * @private
     * @param {?} notifications
     * @return {?}
     */
    function (notifications) {
        if (!(notifications instanceof Array)) {
            return null;
        }
        if (!notifications.length) {
            return null;
        }
        /** @type {?} */
        var result = new Map();
        /** @type {?} */
        var today = new Date();
        /** @type {?} */
        var relativeDatePipe = new RelativeDatePipe();
        notifications.forEach((/**
         * @param {?} item
         * @return {?}
         */
        function (item) {
            item.removendo = false;
            /** @type {?} */
            var header = relativeDatePipe.transform(item.dataEnvio, (item.dataAtual || today), true);
            if (result.has(header)) {
                /** @type {?} */
                var items = result.get(header);
                items.push(item);
                result.set(header, items);
            }
            else {
                result.set(header, [item]);
            }
        }));
        return result;
    };
    NotificationSidenavComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-notification-sidenav',
                    template: "<ng-template #loadingTemplate>\n    <mat-spinner aria-hidden diameter=\"80\" color=\"accent\"></mat-spinner>\n</ng-template>\n\n<ng-template #noNotificationsTemplate>\n    <mat-toolbar class=\"mat-elevation-z2\">\n        <mat-toolbar-row fxLayout=\"row\">\n            {{ loading ? 'Carregando\u2026' : 'Tudo ok!' }}\n        </mat-toolbar-row>\n    </mat-toolbar>\n    <div fxFlex=\"nogrow noshrink\" fxLayout=\"column\" fxLayoutAlign=\"center center\">\n        <img\n            *ngIf=\"!loading else loadingTemplate\"\n            alt=\"Imagem de um dia ensolarado com poucas nuvens. Indicando que est\u00E1 tudo Ok.\"\n            src=\"/assets/datasus/layout/notification-sidenav/sol.gif\"\n        />\n    </div>\n</ng-template>\n<aside fxLayout=\"column\" fxFlexFill>\n    <ng-container *ngIf=\"!!notifications?.size else noNotificationsTemplate\">\n        <div fxFlex=\"nogrow noshrink\" class=\"notifications\">\n            <ng-container *ngFor=\"let item of notifications | keyvalue : notificationsKeepOrder\">\n                <h2 class=\"header\">{{ item.key }}</h2>\n                <datasus-notification-card\n                    *ngFor=\"let notification of item.value\"\n                    class=\"card\"\n                    [notification]=\"notification\"\n                    (removed)=\"removeItem($event)\"\n                ></datasus-notification-card>\n            </ng-container>\n        </div>\n    </ng-container>\n    <mat-toolbar class=\"footer mat-elevation-z1-upside-down\">\n        <mat-toolbar-row fxLayout=\"row\">\n            <a mat-icon-button aria-label=\"Fechar painel\" (click)=\"sidenav.close()\">\n                <mat-icon aria-hidden>chevron_right</mat-icon>\n            </a>\n            <span fxFlex></span>\n            <a\n                *ngIf=\"!!notifications?.size\"\n                mat-icon-button\n                matTooltip=\"Remover todas as notifica\u00E7\u00F5es\"\n                aria-label=\"Remover todas as notifica\u00E7\u00F5es\"\n                (click)=\"removeAll()\"\n            >\n                <mat-icon aria-hidden>delete_sweep</mat-icon>\n            </a>\n        </mat-toolbar-row>\n    </mat-toolbar>\n</aside>\n",
                    styles: ["aside .footer,aside .notifications{z-index:101}aside .notifications{background:#f5f5f5;overflow-y:auto;overflow-x:hidden}aside .notifications .header{z-index:103;padding:16px;font-weight:lighter;position:-webkit-sticky;position:sticky;margin-bottom:32px;top:0;left:0;background-image:linear-gradient(0,transparent,#f5f5f5,#f5f5f5,#f5f5f5,#f5f5f5)}aside .card{display:block}"]
                }] }
    ];
    /** @nocollapse */
    NotificationSidenavComponent.ctorParameters = function () { return [
        { type: NotificacaoService }
    ]; };
    NotificationSidenavComponent.propDecorators = {
        sidenav: [{ type: Input }]
    };
    return NotificationSidenavComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RootComponent = /** @class */ (function () {
    function RootComponent(layoutConfig, configService) {
        this.layoutConfig = layoutConfig;
        this.configService = configService;
        this.withGovBrBar = false;
    }
    /**
     * @return {?}
     */
    RootComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.configService.registerApp(this.layoutConfig.appName, this.layoutConfig.appVersion);
        this.appendMatTypographyClass();
        this.withGovBrBar = this.layoutConfig.withGovBrBar;
        if (this.withGovBrBar) {
            this.appendGovBrBarInDom();
        }
    };
    /**
     * @private
     * @return {?}
     */
    RootComponent.prototype.appendMatTypographyClass = /**
     * @private
     * @return {?}
     */
    function () {
        /** @type {?} */
        var doc = ((/** @type {?} */ (window))).document;
        /** @type {?} */
        var body = doc.body;
        body.classList.add('mat-typography');
    };
    /**
     * @private
     * @return {?}
     */
    RootComponent.prototype.appendGovBrBarInDom = /**
     * @private
     * @return {?}
     */
    function () {
        try {
            /** @type {?} */
            var doc = ((/** @type {?} */ (window))).document;
            /** @type {?} */
            var head = doc.head;
            /** @type {?} */
            var body = doc.body;
            /** @type {?} */
            var meta = doc.createElement('meta');
            /** @type {?} */
            var script = doc.createElement('script');
            /** @type {?} */
            var URL_ESTRUTURA_ORGANIZACIONAL = 'http://estruturaorganizacional.dados.gov.br/doc/unidade-organizacional/2393';
            /** @type {?} */
            var URL_JS_BARRA_GOV_BR = 'https://barra.brasil.gov.br/barra_2.0.js';
            meta.setAttribute('content', URL_ESTRUTURA_ORGANIZACIONAL);
            meta.setAttribute('property', 'creator.productor');
            script.setAttribute('src', URL_JS_BARRA_GOV_BR);
            script.setAttribute('defer', 'defer');
            script.setAttribute('type', 'text/javascript');
            head.appendChild(meta);
            body.appendChild(script);
        }
        catch (e) {
            console.error('Não foi possível injetar no <head /> e no <body /> as coisas da barra do GOV.BR', e);
        }
    };
    RootComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-root',
                    template: "<section *ngIf=\"withGovBrBar\">\n  <div id=\"barra-brasil\"></div>\n  <svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"66\" height=\"14\">\n    <defs>\n      <path id=\"a\" d=\"M9.367 4.374V.247H.37v4.127h8.997z\" />\n    </defs>\n    <g fill=\"none\" fill-rule=\"evenodd\">\n      <path fill=\"#FFF\"\n            d=\"M7.602 11.174a3.693 3.693 0 0 1-2.45.896c-.644 0-1.26-.114-1.848-.343a4.416\n              4.416 0 0 1-1.54-1.001 4.863 4.863 0 0 1-1.05-1.61C.453 8.481.322 7.758.322\n              6.946a4.851 4.851 0 0 1 1.47-3.521 5.092 5.092 0 0 1 1.617-1.05 5.205 5.205\n              0 0 1 2.009-.385c.448 0 .877.049 1.288.147a4.495 4.495 0 0 1 2.086\n              1.12c.28.266.509.567.686.903l-2.03 1.554a2.289 2.289 0 0 0-.882-.945 2.362 2.362 0 0 0-1.246-.357 2.034\n              2.034 0 0 0-1.596.742c-.196.233-.35.511-.462.833a3.198 3.198 0 0 0-.168 1.057c0\n              .392.056.747.168 1.064.112.317.268.59.469.819.2.229.441.406.721.532.28.126.593.189.938.189.793\n              0 1.493-.327 2.1-.98H5.768v-1.96h4.088V12H7.602v-.826zm8.078.91c-.756 0-1.442-.145-2.058-.434a5.092 5.092\n              0 0 1-2.604-2.758 5.008 5.008 0 0 1-.364-1.876c0-.653.126-1.283.378-1.89a5.018 5.018\n              0 0 1 1.057-1.603c.453-.462.99-.83 1.61-1.106.62-.275 1.3-.413 2.037-.413.756 0\n              1.442.145 2.058.434.616.29 1.143.672 1.582 1.148a5.151 5.151 0 0 1 1.015 1.624c.238.607.357\n              1.227.357 1.862a4.83 4.83 0 0 1-.378 1.883 5.1 5.1 0 0 1-1.05 1.596 5.165 5.165\n              0 0 1-1.603 1.113c-.62.28-1.3.42-2.037.42zm-2.254-5.04c0\n              .336.047.66.14.973.093.313.233.59.42.833.187.243.422.439.707.588.285.15.623.224\n              1.015.224.392 0 .733-.077 1.022-.231a2.07 2.07 0 0 0 .707-.602 2.59 2.59 0 0 0\n              .406-.847c.089-.317.133-.64.133-.966 0-.336-.047-.66-.14-.973a2.397 2.397 0 0 0-.427-.826 2.156\n              2.156 0 0 0-.714-.574 2.182 2.182 0 0 0-1.001-.217c-.392 0-.73.075-1.015.224-.285.15-.52.348-.707.595a2.523\n              2.523 0 0 0-.413.84 3.498 3.498 0 0 0-.133.959zM23.828 2.06l1.946 6.51 1.918-6.51h2.87L26.908\n              12H24.64l-3.696-9.94h2.884zM55.82 9.438c0 .383-.077.733-.231 1.05a2.444 2.444 0 0 1-.63.812 2.887 2.887\n              0 0 1-.924.518c-.35.121-.726.182-1.127.182H48.19V2.06h4.942c.345 0\n              .658.075.938.224.28.15.518.343.714.581.196.238.348.509.455.812.107.303.161.609.161.917\n              0 .495-.124.952-.371 1.372-.247.42-.6.733-1.057.938.57.168 1.02.478\n              1.351.931.331.453.497.987.497 1.603zm-1.274-.224c0-.224-.04-.441-.119-.651a1.852 1.852 0\n              0 0-.322-.553 1.525 1.525 0 0 0-.483-.378 1.358 1.358 0 0\n              0-.616-.14H49.45v3.416h3.458c.233 0 .448-.047.644-.14.196-.093.369-.217.518-.371a1.68\n              1.68 0 0 0 .35-.539c.084-.205.126-.42.126-.644zM49.45 3.152V6.47h3.164c.224 0\n              .43-.044.616-.133.187-.089.348-.208.483-.357.135-.15.243-.324.322-.525.08-.2.119-.413.119-.637a1.91 1.91 0\n              0 0-.112-.658 1.736 1.736 0 0 0-.301-.532 1.37 1.37 0 0 0-1.043-.476H49.45zM57.584 12V2.06h4.256c.439 0\n              .842.091 1.211.273.369.182.686.425.952.728.266.303.474.644.623 1.022.15.378.224.763.224 1.155 0\n              .345-.049.679-.147 1.001a3.098 3.098 0 0 1-.42.875 2.812 2.812 0 0 1-.658.672 2.566 2.566 0 0\n              1-.861.406L65.172 12h-1.428l-2.268-3.57h-2.632V12h-1.26zm1.26-4.69h3.01c.261 0\n              .497-.056.707-.168.21-.112.39-.264.539-.455.15-.191.266-.413.35-.665.084-.252.126-.513.126-.784\n              0-.28-.049-.544-.147-.791a2.322 2.322 0 0 0-.392-.658 1.774 1.774 0 0 0-.574-.448 1.557 1.557 0 0\n              0-.693-.161h-2.926v4.13z\" />\n      <path fill=\"#FFD400\" d=\"M35.145 0L46 6.875 35.145 13.75z\" />\n      <path fill=\"#1675D3\"\n            d=\"M36.233 11.177a4.293 4.293 0 0 0 4.3-4.3 4.293 4.293 0 0 0-4.3-4.302 4.293\n              4.293 0 0 0-4.301 4.301 4.293 4.293 0 0 0 4.3 4.301\" />\n      <g transform=\"matrix(-1 0 0 1 41 4.75)\">\n        <mask id=\"b\" fill=\"#fff\">\n          <use xlink:href=\"#a\" />\n        </mask>\n        <path fill=\"#FFF\" mask=\"url(#b)\"\n              d=\"M8.76.538C4.918-.46 2.19 1.288.533 3c-.267.248-.276.953.5\n                1.375 3.554-3.313 6.797-2.9 8.035-2.185.397 0 .494-1.409-.308-1.65\" />\n      </g>\n    </g>\n  </svg>\n</section>\n<datasus-layout></datasus-layout>",
                    styles: ["section{position:fixed;z-index:1000;left:0;right:0;top:3px;border:none;box-sizing:border-box;transform:translateY(-100%);padding:0 0 3px}section,section>svg{background:#2e7d32;transition:.4s ease-in-out}section>svg{position:absolute;border-radius:0 0 4px 4px;width:66px;height:14px;padding:4px;left:50%;transform:translateX(-50%)}section:hover{transform:translateY(0);padding:0;top:0;box-shadow:0 2px 2px 0 rgba(0,0,0,.15),0 4px 8px 0 rgba(0,0,0,.2)}section:hover>svg{transform:translate(-50%,-500%);opacity:0}"]
                }] }
    ];
    /** @nocollapse */
    RootComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: ['LayoutConfig',] }] },
        { type: ConfigService }
    ]; };
    return RootComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SistemaService = /** @class */ (function () {
    function SistemaService(httpClient, configService) {
        this.httpClient = httpClient;
        this.configService = configService;
        this.cache = [];
    }
    /**
     * @return {?}
     */
    SistemaService.prototype.get = /**
     * @return {?}
     */
    function () {
        var _this = this;
        if (!!this.cache && !!this.cache.length) {
            console.log('%cSistemas do cache', 'color: cyan; background-color: black;');
            return of(this.cache).pipe(delay(0));
        }
        return this.configService.getList([
            'backendUrl',
            'clientId'
        ]).pipe(switchMap((/**
         * @param {?} configs
         * @return {?}
         */
        function (configs) {
            /** @type {?} */
            var backendUrl = configs[0];
            /** @type {?} */
            var clientId = configs[1];
            console.log('%cSistemas do back-end', 'color: cyan; background-color: black;');
            return _this.httpClient.get(backendUrl + "/acesso/sistema").pipe(map((/**
             * @param {?} sistemas
             * @return {?}
             */
            function (sistemas) { return sistemas.filter((/**
             * @param {?} sistema
             * @return {?}
             */
            function (sistema) { return sistema.sigla !== clientId; })); })));
        })), tap((/**
         * @param {?} sistemas
         * @return {?}
         */
        function (sistemas) { return _this.cache = sistemas; })), startWith([]));
    };
    SistemaService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    SistemaService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: ConfigService }
    ]; };
    /** @nocollapse */ SistemaService.ngInjectableDef = defineInjectable({ factory: function SistemaService_Factory() { return new SistemaService(inject(HttpClient), inject(ConfigService)); }, token: SistemaService, providedIn: "root" });
    return SistemaService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SystemMenuDialogComponent = /** @class */ (function () {
    function SystemMenuDialogComponent(matDialogRef, sistemaService) {
        this.matDialogRef = matDialogRef;
        this.sistemaService = sistemaService;
    }
    /**
     * @return {?}
     */
    SystemMenuDialogComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.loading = true;
        this.systems$ = this.sistemaService.get().pipe(finalize((/**
         * @return {?}
         */
        function () { return _this.loading = false; })));
    };
    /**
     * @param {?} system
     * @return {?}
     */
    SystemMenuDialogComponent.prototype.selected = /**
     * @param {?} system
     * @return {?}
     */
    function (system) {
        this.matDialogRef.close(system);
    };
    SystemMenuDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-system-menu-dialog',
                    template: "<ng-container *ngIf=\"(systems$ | async) as systems\">\n    <h3 mat-dialog-title>Selecione uma das op\u00E7\u00F5es abaixo:</h3>\n    <div mat-dialog-content class=\"no-padding \">\n        <ng-template #notLoading>\n            <mat-divider ></mat-divider>\n            <mat-action-list\n                class=\"no-padding-top\"\n                *ngFor=\"let system of systems\"\n                (mousemove)=\"system.hovered = true\"\n                (mouseleave)=\"system.hovered = false\"\n                (pointermove)=\"system.hovered = true\"\n                (pointerleave)=\"system.hovered = false\"\n                [class.mat-elevation-z2]=\"system.hovered\"\n                [class.hovered]=\"system.hovered\"\n            >\n                <button\n                    mat-list-item\n                    class=\"color-duskyLight\"\n                    (click)=\"selected(system)\"\n                    (focus)=\"system.hovered = true\"\n                    (blur)=\"system.hovered = false\"\n                >\n                    <mat-icon matListIcon class=\"avatar mat-elevation-z2\">web</mat-icon>\n                    <span mat-line><strong>{{ system.sigla }}</strong></span>\n                    <span mat-line>{{ system.descricao }}</span>\n                    <mat-icon class=\"forward-icon\">launch</mat-icon>\n                </button>\n                <mat-divider></mat-divider>\n            </mat-action-list>\n        </ng-template>\n        <div\n            *ngIf=\"loading else notLoading\"\n            class=\"size-box\"\n            fxLayout=\"column\"\n            fxLayoutAlign=\"center center\"\n        >\n            <mat-spinner diameter=\"42\"></mat-spinner>\n        </div>\n    </div>\n</ng-container>\n",
                    styles: ["button:focus,button:hover{background:#6d6d6d}.no-padding{padding:0}.no-padding-top{padding-top:0}.custom-dialog-container{padding:24px 24px 0}.size-box{padding-top:30px;margin-bottom:50px}mat-action-list{transition:350ms}mat-action-list .avatar{font-size:24px;width:36px!important;height:36px!important;line-height:36px;text-align:center;padding:0;flex-shrink:0;transition:250ms .1s;background-color:#ff8f00;color:#fafafa;transform:rotateY(180deg)}mat-action-list .forward-icon{font-size:16px;width:24px!important;height:24px!important;line-height:24px;text-align:center;padding:0;flex-shrink:0}mat-action-list.hovered{transform:translateY(-2px)}mat-action-list.hovered .avatar{transition-delay:350ms;transform:rotateY(0)}"]
                }] }
    ];
    /** @nocollapse */
    SystemMenuDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: SistemaService }
    ]; };
    return SystemMenuDialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SystemMenuButtonComponent = /** @class */ (function () {
    function SystemMenuButtonComponent(dialog) {
        this.dialog = dialog;
    }
    /**
     * @return {?}
     */
    SystemMenuButtonComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        if (!!this.dialogSubscription) {
            this.dialogSubscription.unsubscribe();
        }
    };
    /**
     * @return {?}
     */
    SystemMenuButtonComponent.prototype.openDialog = /**
     * @return {?}
     */
    function () {
        var _this = this;
        /** @type {?} */
        var dialog = this.dialog.open(SystemMenuDialogComponent, {
            backdropClass: (this.type === 'menu-item') ? '' : 'backdrop-transparent',
            panelClass: 'custom-dialog-container',
            disableClose: false,
            ariaLabel: 'Troca de sistema',
            maxWidth: '300px',
            position: (this.type === 'menu-item') ? {} : { top: '45px', right: '65px' },
            direction: 'ltr',
        });
        this.dialogSubscription = dialog.afterClosed().subscribe((/**
         * @param {?} system
         * @return {?}
         */
        function (system) { return _this.selected(system); }));
    };
    /**
     * @param {?} system
     * @return {?}
     */
    SystemMenuButtonComponent.prototype.selected = /**
     * @param {?} system
     * @return {?}
     */
    function (system) {
        if (!!system) {
            redirectTo(system.paginaInicial);
        }
    };
    SystemMenuButtonComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-system-menu-button',
                    template: "<ng-template [ngIf]=\"type === 'icon'\" [ngIfElse]=\"menuItem\">\n    <button type=\"button\" mat-icon-button (click)=\"openDialog()\">\n        <mat-icon class=\"icon\" matListIcon>apps</mat-icon>\n    </button>\n</ng-template>\n\n<ng-template #menuItem>\n    <button type=\"button\" mat-menu-item (click)=\"openDialog()\">\n        <mat-icon class=\"icon\" matListIcon>apps</mat-icon>\n        <span>Sistemas</span>\n    </button>\n</ng-template>\n",
                    styles: [""]
                }] }
    ];
    /** @nocollapse */
    SystemMenuButtonComponent.ctorParameters = function () { return [
        { type: MatDialog }
    ]; };
    SystemMenuButtonComponent.propDecorators = {
        type: [{ type: Input }]
    };
    return SystemMenuButtonComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ToolbarComponent = /** @class */ (function () {
    function ToolbarComponent(layoutService) {
        this.layoutService = layoutService;
    }
    /**
     * @return {?}
     */
    ToolbarComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.menuSidenavOpen$ = this.layoutService.menuSidenavOpen();
        this.title$ = this.layoutService.getTitle();
    };
    /**
     * @return {?}
     */
    ToolbarComponent.prototype.openMenu = /**
     * @return {?}
     */
    function () {
        this.layoutService.menuSidenavExpanded();
    };
    ToolbarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-toolbar',
                    template: "<mat-toolbar class=\"mat-elevation-z6\">\n  <button mat-icon-button *ngIf=\"!(menuSidenavOpen$ | async)\" (click)=\"openMenu()\">\n    <mat-icon>menu</mat-icon>\n  </button>\n  <span class=\"title\" *ngIf=\"(title$ | async) as title\" [matTooltip]=\"title\">{{ title }}</span>\n  <span fxFlex></span>\n  <datasus-user-profile-menu-button></datasus-user-profile-menu-button>\n  <datasus-system-menu-button datasusOnMobile=\"hide\" type=\"icon\"></datasus-system-menu-button>\n  <datasus-notification-button [sidenav]=\"notificationSidenav\"></datasus-notification-button>\n</mat-toolbar>\n",
                    styles: ["mat-toolbar{position:relative;z-index:1}mat-toolbar .title{text-overflow:ellipsis;overflow:hidden}@media all and (max-width:959px){mat-toolbar .title{font-size:.7em}}"]
                }] }
    ];
    /** @nocollapse */
    ToolbarComponent.ctorParameters = function () { return [
        { type: LayoutService }
    ]; };
    ToolbarComponent.propDecorators = {
        notificationSidenav: [{ type: Input }]
    };
    return ToolbarComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UserProfileMenuButtonComponent = /** @class */ (function () {
    function UserProfileMenuButtonComponent(authService, securityService) {
        this.authService = authService;
        this.securityService = securityService;
    }
    /**
     * @return {?}
     */
    UserProfileMenuButtonComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.helpLink = ''; // @TODO Ver como vamos mostrar o ajuda
        this.nomeCompleto$ = this.authService.getUser().pipe(pluck('nome'));
        this.countToChoose$ = this.securityService.getPerfis().pipe(map((/**
         * @param {?} perfis
         * @return {?}
         */
        function (perfis) {
            /** @type {?} */
            var counter = 0;
            perfis.forEach((/**
             * @param {?} perfil
             * @return {?}
             */
            function (perfil) { return counter += (perfil.esferas ? perfil.esferas.length : 0); }));
            return counter;
        })));
        this.perfil$ = this.securityService.getPerfilSelecionado();
        this.esfera$ = this.securityService.getEsferaSelecionada();
    };
    /**
     * @return {?}
     */
    UserProfileMenuButtonComponent.prototype.changeProfile = /**
     * @return {?}
     */
    function () {
        this.securityService.navigateToChooseProfile(true);
    };
    /**
     * @return {?}
     */
    UserProfileMenuButtonComponent.prototype.logout = /**
     * @return {?}
     */
    function () {
        this.authService.logout();
    };
    UserProfileMenuButtonComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-user-profile-menu-button',
                    template: "<mat-menu #menu=\"matMenu\" class=\"mat-menu-without-padding\">\n    <div class=\"header\" fxLayout=\"row\" fxLayoutAlign=\"center\">\n        <mat-icon class=\"avatar\" matListIcon fxFlexAlign=\"center\">account_circle</mat-icon>\n        <div class=\"details\" fxLayout=\"column\" fxLayoutAlign=\"center start\">\n            <h2>{{ nomeCompleto$ | async }}</h2>\n            <h3>{{ (perfil$ | async)?.descricao }}</h3>\n            <ng-container *ngIf=\"(esfera$ | async) as esfera\">\n                <ng-template #withoutDescricaoEsferaAtuacao>\n                    <h4>{{ esfera.descricao }}</h4>\n                </ng-template>\n                <h4 *ngIf=\"!!esfera?.descricaoEsferaAtuacao else withoutDescricaoEsferaAtuacao\" [matTooltip]=\"esfera.descricao\">\n                    {{ esfera?.descricaoEsferaAtuacao | datasusSwitchSlashToDashPipe }}\n                </h4>\n            </ng-container>\n        </div>\n    </div>\n\n    <div class=\"list\">\n        <datasus-system-menu-button datasusOnMobile=\"show\" type=\"menu-item\"></datasus-system-menu-button>\n        <mat-divider *ngIf=\"(countToChoose$ | async) > 1\" datasusOnMobile=\"show\"></mat-divider>\n        <button mat-menu-item *ngIf=\"(countToChoose$ | async) > 1\" (click)=\"changeProfile()\">\n            <mat-icon class=\"icon\" matListIcon>compare_arrows</mat-icon>\n            <span>Perfil</span>\n        </button>\n        <mat-divider *ngIf=\"helpLink\"></mat-divider>\n        <a mat-menu-item *ngIf=\"helpLink\" [href]=\"helpLink\" target=\"_blank\">\n            <mat-icon class=\"icon\" matListIcon>help</mat-icon>\n            <span>Ajuda</span>\n        </a>\n        <mat-divider></mat-divider>\n        <button mat-menu-item (click)=\"logout()\">\n            <mat-icon class=\"icon\" matListIcon>exit_to_app</mat-icon>\n            <span>Sair</span>\n        </button>\n    </div>\n</mat-menu>\n\n<button datasusOnMobile=\"show\" mat-icon-button [matMenuTriggerFor]=\"menu\">\n    <mat-icon matListIcon>account_circle</mat-icon>\n</button>\n\n<button datasusOnMobile=\"hide\" class=\"button\" mat-button [matMenuTriggerFor]=\"menu\">\n    <span class=\"username\">{{ nomeCompleto$ | async | datasusFirstWord }}</span>\n    <mat-icon matListIcon>account_circle</mat-icon>\n</button>\n",
                    styles: [".header{background:#424242;color:#fafafa;padding:20px}.header .avatar{font-size:40px;width:60px!important;height:60px!important;line-height:60px;text-align:center;padding:0;flex-shrink:0}.header .details h2,.header .details h3,.header .details h4{margin:0}.list{padding-top:0}.list .icon{font-size:18px;width:27px!important;height:27px!important;line-height:27px;text-align:center;padding:0;flex-shrink:0}.button{padding-right:12px}.button .username{margin:0 4px;font-size:16px;max-width:80px;display:inline-block;overflow:hidden;text-overflow:ellipsis}"]
                }] }
    ];
    /** @nocollapse */
    UserProfileMenuButtonComponent.ctorParameters = function () { return [
        { type: AuthService },
        { type: SecurityService }
    ]; };
    return UserProfileMenuButtonComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var CardContentComponent = /** @class */ (function () {
    function CardContentComponent() {
        this.elevationValue = 1;
        this.dir = 'ltr';
    }
    Object.defineProperty(CardContentComponent.prototype, "elevation", {
        get: /**
         * @return {?}
         */
        function () {
            return this.elevationValue;
        },
        set: /**
         * @param {?} elevationValue
         * @return {?}
         */
        function (elevationValue) {
            this.elevationValue = +elevationValue;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    CardContentComponent.prototype.getClass = /**
     * @return {?}
     */
    function () {
        /** @type {?} */
        var classes = [];
        /** @type {?} */
        var colorVariant = this.colorVariant === 'light'
            ? 'Light'
            : (this.colorVariant === 'dark' ? 'Dark' : '');
        classes.push(!!this.color
            ? "background-" + this.color + colorVariant
            : '');
        classes.push(this.elevationValue > 0
            ? "mat-elevation-z" + this.elevationValue
            : "mat-elevation-z" + Math.abs(this.elevationValue) + "-upside-down");
        return classes.join(' ');
    };
    CardContentComponent.decorators = [
        { type: Component, args: [{
                    selector: 'datasus-card-content',
                    template: "<div [attr.dir]=\"dir\" class=\"dashboard-wrapper\">\n    <div class=\"card-content\">\n        <p class=\"card-content-heading mat-subheading-2 \">{{ header }}</p>\n        <mat-card [ngClass]=\"getClass()\" [class.no-padding]=\"noPadding\">\n            <ng-content></ng-content>\n        </mat-card>\n    </div>\n</div>\n",
                    styles: [".dashboard-wrapper .card-content-heading{border-color:#1565c0}.dashboard-wrapper .card-content-heading::after{background-color:#ff8f00;left:-2px;right:initial}.dashboard-wrapper[dir=rtl] .card-content-heading{padding-right:12px;padding-left:0;border-left-width:0;border-right-width:2px;border-right-style:solid}.dashboard-wrapper[dir=rtl] .card-content-heading::after{left:initial;right:-2px}.card-content{margin-bottom:16px}.card-content-heading{text-transform:uppercase;padding-left:12px;border-left-width:2px;border-left-style:solid;position:relative}.card-content-heading::after{content:\"\";width:2px;height:0%;position:absolute;bottom:0;transition:height .5s}.card-content:hover .card-content-heading::after{height:100%}.no-padding{padding:0}"]
                }] }
    ];
    CardContentComponent.propDecorators = {
        header: [{ type: Input }],
        dir: [{ type: Input }],
        noPadding: [{ type: Input }],
        color: [{ type: Input }],
        colorVariant: [{ type: Input }],
        elevation: [{ type: Input }]
    };
    return CardContentComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var layoutConfigDefault = {
    withGovBrBar: false,
    appName: '',
    appVersion: '',
};
var ɵ0 = layoutConfigDefault;
var LayoutModule$1 = /** @class */ (function () {
    function LayoutModule$$1() {
    }
    /**
     * Criando o Módulo com suas configurações
     * @param layoutConfig Configuração do layout: Com ou sem a barra do GOV.BR, etc...
     */
    /**
     * Criando o Módulo com suas configurações
     * @param {?} layoutConfig Configuração do layout: Com ou sem a barra do GOV.BR, etc...
     * @return {?}
     */
    LayoutModule$$1.forRoot = /**
     * Criando o Módulo com suas configurações
     * @param {?} layoutConfig Configuração do layout: Com ou sem a barra do GOV.BR, etc...
     * @return {?}
     */
    function (layoutConfig) {
        return {
            ngModule: LayoutModule$$1,
            providers: [{
                    provide: 'LayoutConfig',
                    useValue: layoutConfig,
                }],
        };
    };
    LayoutModule$$1.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        // Angular
                        CommonModule,
                        RouterModule,
                        // Angular Flex-Layout
                        FlexLayoutModule,
                        // Angular Material
                        LayoutModule,
                        MatBottomSheetModule,
                        MatButtonModule,
                        MatCardModule,
                        MatDialogModule,
                        MatExpansionModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule,
                        MatListModule,
                        MatMenuModule,
                        MatProgressBarModule,
                        MatProgressSpinnerModule,
                        MatSidenavModule,
                        MatToolbarModule,
                        MatTooltipModule,
                    ],
                    declarations: [
                        // Pipes
                        SafeHtmlPipe,
                        FirstWordPipe,
                        SwitchSlashToDashPipe,
                        ListAfterIndexPipe,
                        ListUntilIndexPipe,
                        RelativeDatePipe,
                        // Directives
                        OnMobileDirective,
                        // Components
                        ContainerComponent,
                        ContainerTransparentComponent,
                        DialogAlertComponent,
                        DialogConfirmationComponent,
                        DialogPromptComponent,
                        FooterComponent,
                        LayoutComponent,
                        LoaderComponent,
                        MenuSidenavComponent,
                        NotificationButtonComponent,
                        NotificationCardComponent,
                        NotificationSidenavComponent,
                        RootComponent,
                        SystemMenuDialogComponent,
                        SystemMenuButtonComponent,
                        ToolbarComponent,
                        UserProfileMenuButtonComponent,
                        CardContentComponent,
                    ],
                    entryComponents: [
                        DialogAlertComponent,
                        DialogConfirmationComponent,
                        DialogPromptComponent,
                        SystemMenuDialogComponent,
                    ],
                    exports: [
                        // Pipes
                        FirstWordPipe,
                        SwitchSlashToDashPipe,
                        // Directives
                        OnMobileDirective,
                        // Components
                        ContainerComponent,
                        ContainerTransparentComponent,
                        LayoutComponent,
                        CardContentComponent,
                        RootComponent,
                    ],
                    providers: [{
                            provide: 'LayoutConfig',
                            useValue: ɵ0,
                        }],
                },] }
    ];
    return LayoutModule$$1;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { LayoutService, DialogService, MenuService, DatasusColors, FirstWordPipe, SwitchSlashToDashPipe, LayoutModule$1 as LayoutModule, CardContentComponent as ɵx, ContainerTransparentComponent as ɵg, ContainerComponent as ɵf, DialogAlertComponent as ɵh, DialogConfirmationComponent as ɵi, DialogPromptComponent as ɵj, FooterComponent as ɵk, LayoutComponent as ɵl, LoaderComponent as ɵm, MenuSidenavComponent as ɵn, NotificationButtonComponent as ɵo, NotificationCardComponent as ɵp, NotificationSidenavComponent as ɵq, RootComponent as ɵr, SystemMenuButtonComponent as ɵu, SystemMenuDialogComponent as ɵs, ToolbarComponent as ɵv, UserProfileMenuButtonComponent as ɵw, OnMobileDirective as ɵe, ListAfterIndexPipe as ɵb, ListUntilIndexPipe as ɵc, RelativeDatePipe as ɵd, SafeHtmlPipe as ɵa, SistemaService as ɵt };

//# sourceMappingURL=datasus-layout.js.map