import { Component, OnInit, Input, Output, EventEmitter, OnDestroy } from '@angular/core';
import { ErrorModel } from '@datasus/core';

import { DynamicTableColumnsConfig } from './dynamic-table-columns.config';
import { DynamicTableRequestDataConfig } from './dynamic-table-request-data.config';
import { ActionConfig } from '../../configs/actions.config';


@Component({
  selector: 'datasus-dynamic-table',
  templateUrl: './dynamic-table.component.html',
  styleUrls: ['./dynamic-table.component.scss']
})


export class DynamicTableComponent implements OnInit, OnDestroy {

  @Input() columns: DynamicTableColumnsConfig[] = [];
  @Input() data: any[] = [];
  @Input() total = 0;
  @Input() pageSize = 0;
  @Input() actions: ActionConfig[] = [];
  @Input() loading = false;
  @Input() typeActions: any;
  @Output() request: EventEmitter<DynamicTableRequestDataConfig> = new EventEmitter<DynamicTableRequestDataConfig>(true);
  @Output() error: EventEmitter<ErrorModel> = new EventEmitter<ErrorModel>(true);

  displayedColumns: string[];
  actionButtonCtrl: Map<any, boolean> = new Map();
  showActions = false;

  teste: ActionConfig[];

  private resquestDataCache: DynamicTableRequestDataConfig = {};

  ngOnInit(): void {
    if (this.actions.length > 0) {
      this.displayedColumns = this.columns.map(column => column.cell).concat(['actions']);
    } else {
      this.displayedColumns = this.columns.map(column => column.cell);
    }
    this.resquestDataCache = {};
  }

  ngOnDestroy(): void {
    this.resquestDataCache = {};
  }

  onRequest(data: DynamicTableRequestDataConfig): void {
    const newData = { ...this.resquestDataCache, ...data };
    this.request.emit(newData);
    this.resquestDataCache = newData;
  }

  urlWrap(path: string): string {
    return `url('${path}')`;
  }

}
