import { Component, OnInit, OnDestroy } from '@angular/core';
import { Router } from '@angular/router';

import { LayoutService } from '@datasus/layout';
import { DATASUS_ROUTE_HOME } from '@datasus/core';

@Component({
  selector: 'datasus-error-backend',
  templateUrl: './error-backend.component.html',
  styleUrls: ['./error-backend.component.scss']
})
export class ErrorBackendComponent implements OnInit, OnDestroy {

  progress = 0;
  flipProgress = false;

  private interval: any;

  constructor(
    private router: Router,
    private layoutService: LayoutService,
  ) { }

  ngOnInit(): void {
    this.layoutService.off();

    const reloadAndFlipIf = (test: boolean) => {
      if (test) {
        this.router.navigate([`/${DATASUS_ROUTE_HOME}`]);
        this.flipProgress = !this.flipProgress;
      }
    };

    this.interval = setInterval(() => {
      reloadAndFlipIf(this.flipProgress && --this.progress <= -1);
      reloadAndFlipIf(!this.flipProgress && ++this.progress >= 101);
    }, 100);

    console.log('%cError back-end!', 'font-size: 1.2em; color: #f66;');
  }

  ngOnDestroy(): void {
    clearInterval(this.interval);
  }

  reload(): void {
    this.progress = this.flipProgress ? 100 : 0;
  }
}
