import { MatPaginatorIntl } from '@angular/material/paginator';

export class PaginatorIntl extends MatPaginatorIntl {
  itemsPerPageLabel = 'Itens por página';
  nextPageLabel = 'Próxima página';
  previousPageLabel = 'Página anterior';
  firstPageLabel = 'Primeira página';
  lastPageLabel = 'Última página';

  /**
  * ✓ 0: Nenhum item
  * ✓ 1 até 1 de 1: Único item
  * ✓ 1 até X de X: X itens
  * ✓ X até X de X: Último item dos X itens
  * ✓ X até Y de Y itens
  * ✓ X até Y de Z itens
  */
  getRangeLabel = (page: number, pageSize: number, length: number): string => {
    if (length === 0 || pageSize === 0) {
      return 'Nenhum item';
    }

    length = Math.max(length, 0);

    const index = page * pageSize;
    const end = index < length ? Math.min(index + pageSize, length) : index + pageSize;
    const start = index + 1;

    if (start === 1) {
      if (start === length) {
        return 'Único item';
      }
      if (end === length) {
        return `${length} itens`;
      }
    }

    if (start === end && end === length) {
      return `Último item dos ${length} itens`;
    }

    return `${start} até ${end} de ${length} itens`;
  }
}
