import { Routes, Route } from '@angular/router';

import {
  AuthGuard,
  SecurityGuard,
  DATASUS_ROUTE_HOME,
  DATASUS_ROUTE_CHOOSE_PROFILE,
  DATASUS_ROUTE_ERROR_BACKEND,
  DATASUS_ROUTE_FORBIDDEN,
  DATASUS_ROUTE_RELEASE_NOTES,
} from '@datasus/core';

import { WelcomeComponent } from '../components/welcome/welcome.component';
import { NotFoundComponent } from '../components/not-found/not-found.component';
import { ErrorBackendComponent } from '../components/error-backend/error-backend.component';
import { ForbiddenComponent } from '../components/forbidden/forbidden.component';
import { ChooseProfileComponent } from '../components/choose-profile/choose-profile.component';
import { ReleaseNotesComponent } from '../components/release-notes/release-notes.component';


const welcomeRoute: Route = {
  component: WelcomeComponent,
  path: DATASUS_ROUTE_HOME,
  data: {
    layoutColor: 'primary',
    layoutAnimation: true,
  },
  canActivate: [
    AuthGuard,
    SecurityGuard,
  ],
};

const selectProfileRoute: Route = {
  component: ChooseProfileComponent,
  path: DATASUS_ROUTE_CHOOSE_PROFILE,
  data: {
    layoutColor: 'accent',
    layoutAnimation: true,
  },
  canActivate: [
    AuthGuard,
  ],
};

const errorBackendRoute: Route = {
  component: ErrorBackendComponent,
  path: DATASUS_ROUTE_ERROR_BACKEND,
  data: {
    layoutColor: 'error',
    layoutAnimation: false,
  }
};

const forbiddenRoute: Route = {
  component: ForbiddenComponent,
  path: DATASUS_ROUTE_FORBIDDEN,
  data: {
    layoutColor: 'error',
    layoutAnimation: true,
  },
};

const notFoundRoute: Route = {
  component: NotFoundComponent,
  path: '**',
  data: {
    layoutColor: 'error',
    layoutAnimation: true,
  }
};

const releaseNotesRoute: Route = {
  component: ReleaseNotesComponent,
  path: DATASUS_ROUTE_RELEASE_NOTES,
  data: {
    layoutColor: 'success',
    layoutAnimation: true,
  }
};

export const routesDefault: Routes = [
  welcomeRoute,
  selectProfileRoute,
  errorBackendRoute,
  forbiddenRoute,
  releaseNotesRoute,
  notFoundRoute,
];
