import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, CanActivate, CanLoad, Route, Router, RouterStateSnapshot, UrlSegment } from '@angular/router';
import { Observable, throwError } from 'rxjs';
import { catchError, tap } from 'rxjs/operators';

import { DATASUS_ROUTE_ERROR_BACKEND, DATASUS_ROUTE_FORBIDDEN } from '../constants/routes.contants';
import { ErrorModel } from '../models/error.model';
import { AuthService } from '../services/auth.service';


@Injectable({
  providedIn: 'root'
})
export class AuthGuard implements CanActivate, CanLoad {

  constructor(
    private router: Router,
    private authService: AuthService,
  ) { }

  canActivate(
    next: ActivatedRouteSnapshot,
    state: RouterStateSnapshot
  ): Observable<boolean> | Promise<boolean> | boolean {
    try {
      console.log('[AuthGuard::canActivate]');
      return this.isAuthenticatedOrExit();
    } catch (error) {
      console.warn('[AuthGuard::canActivate] catch error', error);
      return false;
    }
  }

  canLoad(
    route: Route,
    segments: UrlSegment[],
  ): Observable<boolean> | Promise<boolean> | boolean {
    try {
      console.log('[AuthGuard::canLoad]');
      return this.isAuthenticatedOrExit();
    } catch (error) {
      console.warn('[AuthGuard::canLoad] catch error', error);
      return false;
    }
  }

  private isAuthenticatedOrExit(): Observable<boolean> {
    return this.authService.isAuthenticated().pipe(
      catchError((error: ErrorModel) => {
        if (error.code === 401) {
          console.log('[AuthGuard::isAuthenticatedOrExit] Não está autenticado (status: 401)');
          this.authService.login();
        } else if (error.code === 403) {
          console.log('[AuthGuard::isAuthenticatedOrExit] Acesso proíbido cadastrado (status: 403)');
          this.router.navigate([`/${DATASUS_ROUTE_FORBIDDEN}`]);
        } else {
          console.warn('[AuthGuard::isAuthenticatedOrExit] Ops, erro na verificação', error);
          this.router.navigate([`/${DATASUS_ROUTE_ERROR_BACKEND}`]);
        }
        return throwError(false);
      }),
      tap((result: boolean) => {
        if (!result) {
          console.log('[AuthGuard::isAuthenticatedOrExit] Não está autenticado (status: 200)');
          this.authService.login();
        }
        console.log('[AuthGuard::isAuthenticatedOrExit] Está autentidado (status: 200)');
      }),
    );
  }
}
