import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable, interval, of as observableOf, EMPTY } from 'rxjs';
import { switchMap, take, tap } from 'rxjs/operators';

import { NotificacaoModel } from '../models/notificacao.model';
import { ConfigService } from './config.service';

@Injectable({
  providedIn: 'root'
})
export class NotificacaoService {

  constructor(
    private httpClient: HttpClient,
    private configService: ConfigService,
  ) { }

  getIntervalNonReceivedCounter(
    intervalSeconds: number = 10,
    intervalConditional = () => true
  ): Observable<number> {
    return interval(intervalSeconds * 1000).pipe(
      switchMap(() => !intervalConditional() ? EMPTY :
        this.configService.get('backendUrl').pipe(
          switchMap((backendUrl: string) => this.httpClient.get<number>(
            `${backendUrl}/notificacao/quantidade-mensagens-novas`
          ).pipe(
            take(1),
          )),
        )
      ),
    );
  }

  getNotifications(): Observable<NotificacaoModel[]> {
    return this.configService.get('backendUrl').pipe(
      switchMap((backendUrl: string) => this.httpClient.get<NotificacaoModel[]>(
        `${backendUrl}/notificacao/`
      ).pipe(
        take(1),
      )),
    );
  }

  getDetails(id: number): Observable<string> {
    return this.configService.get('backendUrl').pipe(
      switchMap((backendUrl: string) => this.httpClient.get(
        `${backendUrl}/notificacao/${id}/texto-detalhado`, {
          responseType: 'text'
        }
      ).pipe(
        take(1),
      )),
    );
  }

  send(data: NotificacaoModel): Observable<void> {
    return this.configService.get('backendUrl').pipe(
      switchMap((backendUrl: string) => this.httpClient.post<void>(
        `${backendUrl}/notificacao/`,
        data,
      ).pipe(
        take(1),
      )),
    );
  }

  remove(ids: number[]): Observable<void> {
    return this.configService.get('backendUrl').pipe(
      switchMap((backendUrl: string) => this.httpClient.delete<void>(
        `${backendUrl}/notificacao/`, {
          params : {
            ids: ids.map((id: number) => id + '')
          }
        }
      ).pipe(
        take(1),
      )),
    );
  }

  performAction(notificationId: number, actionId: number) {
    return this.configService.get('backendUrl').pipe(
      switchMap((backendUrl: string) => this.httpClient.delete<void>(
        `${backendUrl}/notificacao/${notificationId}/acao/${actionId}`
      ).pipe(
        take(1),
      )),
    );
  }
}
