import { Injectable } from '@angular/core';
import { MatDialog, MatDialogRef, MatDialogConfig } from '@angular/material/dialog';

import {
  AssinaturaDigitalSignDialogComponent
} from '../components/assinatura-digital-sign-dialog/assinatura-digital-sign-dialog.component';
import {
  AssinaturaDigitalTestDialogComponent
} from '../components/assinatura-digital-test-dialog/assinatura-digital-test-dialog.component';
import {
  AssinaturaDigitalPreviewDialogComponent
} from '../components/assinatura-digital-preview-dialog/assinatura-digital-preview-dialog.component';
import { SignAndSendExtraInfo } from '../models/sign-and-send-extraInfo.model';

export interface AssinaturaDigitalDialogInputData {
  idArquivo: string;
  extraInfo?: SignAndSendExtraInfo;
}

@Injectable({
  providedIn: 'root',
})
export class AssinaturaDigitalDialogService {

  private dialogOptions: MatDialogConfig = {
    height: '500px',
    width: '550px',
    ariaLabel: 'Assinatura Digital',
    disableClose: true,
    hasBackdrop: true,
  };

  constructor(
    private matDialog: MatDialog,
  ) { }

  openSignDialog(idArquivo: string, extraInfo?: SignAndSendExtraInfo):
    MatDialogRef<AssinaturaDigitalSignDialogComponent, AssinaturaDigitalDialogInputData> {
    return this.matDialog.open(AssinaturaDigitalSignDialogComponent, {
      ...this.dialogOptions,
      data: {
        idArquivo,
        extraInfo,
      }
    });
  }

  openTestDialog(): MatDialogRef<AssinaturaDigitalTestDialogComponent> {
    return this.matDialog.open(AssinaturaDigitalTestDialogComponent, {
      ...this.dialogOptions,
    });
  }

  openPreviewDialog(idArquivo: string): MatDialogRef<AssinaturaDigitalPreviewDialogComponent, AssinaturaDigitalDialogInputData> {
    return this.matDialog.open(AssinaturaDigitalPreviewDialogComponent, {
      ...this.dialogOptions,
      data: {
        idArquivo,
      }
    });
  }
}
