import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { switchMap, map, take } from 'rxjs/operators';

import { ConfigService } from '@datasus/core';

export interface AssinaturaDigitalStampData {
  rotulo: string;
  valor: string;
}

@Injectable({
  providedIn: 'root'
})
export class AssinaturaDigitalService {

  constructor(
    private httpClient: HttpClient,
    private configService: ConfigService,
  ) { }

  arquivoAssinado(idArquivo: string): Observable<string> {
    return this.configService.get('backendUrl').pipe(
      switchMap(
        (backendUrl: string) => this.httpClient.get(
          `${backendUrl}/assinatura-digital/arquivo-assinado/${idArquivo}`,
          { responseType: 'text' }
        ),
      )
    ).pipe(take(1));
  }

  carimbos(idArquivo: string): Observable<AssinaturaDigitalStampData[]> {
    return this.configService.get('backendUrl').pipe(
      switchMap(
        (backendUrl: string) => this.httpClient.get<any>(`${backendUrl}/assinatura-digital/carimbos/${idArquivo}`),
      ),
      map((carimbos: any) => Object.keys(carimbos).map(carimbo => ({
        rotulo: carimbo,
        valor: carimbos[carimbo],
      }))),
    ).pipe(take(1));
  }



}
