import {
  Component,
  OnInit,
  forwardRef,
  ChangeDetectionStrategy,
  DoCheck,
  Input,
  Output,
  EventEmitter,
  ViewChild,
  Optional,
  Self,
  ChangeDetectorRef
} from '@angular/core';
import { MatFormFieldControl,  } from '@angular/material/form-field';
import { MatSelect, MatSelectChange } from '@angular/material/select';
import { ErrorStateMatcher } from '@angular/material';
import { ControlValueAccessor, NgControl, FormControlName } from '@angular/forms';

@Component({
  selector: 'datasus-select-autocomplete-multiple',
  templateUrl: './select-autocomplete-multiple.component.html',
  styleUrls: ['./select-autocomplete-multiple.component.scss'],
  providers: [{
    provide: MatFormFieldControl,
    useExisting: forwardRef(() => SelectAutocompleteMultipleComponent),
    multi: true
  }],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SelectAutocompleteMultipleComponent implements OnInit, DoCheck, ControlValueAccessor {

  searchText = '';
  selectedValue: any = null;

  @ViewChild('selectElem') selectElem: MatSelect;

  @Input() placeholder: string;
  @Input() floatLabel = true;
  @Input() options: any[] = [];
  @Input() disabled = false;
  @Input() required: boolean;
  @Input() display = 'display';
  @Input() optionField: (string | number);
  @Input() inputSearchPlaceholder = 'Pesquisar';
  @Input() filterSearch: string;
  @Input() appearance: ('legacy' | 'standard' | 'fill' | 'outline') = 'standard';
  @Input() tooltip: string;
  @Input() customErroMessage: string;
  @Input() loading = false;
  @Input() loadingDiameter = '18';
  @Input()
  get errorStateMatcher(): ErrorStateMatcher {
    return this.selectElem.errorStateMatcher;
  }
  set errorStateMatcher(val) {
    console.log('vall --> ', val);
    this.selectElem.errorStateMatcher = val;
  }

  @Output() selectionChange: EventEmitter<any> = new EventEmitter();
  @Output() openedChangeSelect: EventEmitter<boolean> = new EventEmitter();

  constructor(
    @Optional() @Self() ngControl: NgControl,
    private changeDetectorRef: ChangeDetectorRef,
    @Optional() private controlName: FormControlName,
  ) {
    if (ngControl) {
      ngControl.valueAccessor = this;
    }
  }

  ngOnInit() {
    this.options = this.options || [];
  }

  ngDoCheck(): void {
    this.selectElem.updateErrorState();
  }

  onChange: any = () => { };
  onTouched: any = () => { };

  writeValue(obj: any): void {
    this.selectedValue = obj;
  }

  registerOnChange(fn: any): void {
    this.selectElem.registerOnChange(fn);
    this.onChange = fn;
  }

  registerOnTouched(fn: any): void {
    this.selectElem.registerOnTouched(fn);
    this.onTouched = fn;
  }

  setDisabledState?(isDisabled: boolean): void {
    this.selectElem.setDisabledState(isDisabled);
  }

  clearSearchText() {
    this.searchText = '';
  }

  onSelectionChange(event: MatSelectChange) {
    this.selectedValue = event.value;
    this.onChange(this.selectedValue);
    this.selectElem.writeValue(this.selectedValue);
    this.onTouched();
    this.selectionChange.emit(this.selectedValue);
    this.changeDetectorRef.detectChanges();
  }

  openedChange(isOpen: boolean) {
    this.openedChangeSelect.emit(isOpen);
    this.changeDetectorRef.detectChanges();
  }

  stopEventAndAppendSpace(event: Event): void {
    event.stopPropagation();
    event.preventDefault();
    this.searchText += ' ';
  }

  findFieldInObj(field: string, obj: any): any {
    if (obj instanceof Object && obj.hasOwnProperty(field)) {
      return obj[field];
    }
    return null;
  }

}
