import { Directive, ElementRef, HostListener, Input, OnInit } from '@angular/core';

type DateMaskSeparator = '-' | '.' | '/';

// tslint:disable-next-line: max-line-length
const DATE_REG_EXP = /^(?:(?:31(\/|-|\.)(?:0?[13578]|1[02]))\1|(?:(?:29|30)(\/|-|\.)(?:0?[1,3-9]|1[0-2])\2))(?:(?:1[6-9]|[2-9]\d)?\d{2})$|^(?:29(\/|-|\.)0?2\3(?:(?:(?:1[6-9]|[2-9]\d)?(?:0[48]|[2468][048]|[13579][26])|(?:(?:16|[2468][048]|[3579][26])00))))$|^(?:0?[1-9]|1\d|2[0-8])(\/|-|\.)(?:(?:0?[1-9])|(?:1[0-2]))\4(?:(?:1[6-9]|[2-9]\d)?\d{2})$/gm;

@Directive({
  selector: 'input[datasusDateMask], input[matInput][matDatepicker]'
})
export class DateMaskDirective implements OnInit {

  @Input() dateMaskSeparator: DateMaskSeparator = '/';

  constructor(
    private elementRef: ElementRef<HTMLInputElement>,
  ) { }

  ngOnInit(): void {
    const allowed: DateMaskSeparator[] = ['-', '.', '/'];
    if (!allowed.includes(this.dateMaskSeparator)) {
      this.dateMaskSeparator = '/';
    }
  }

  @HostListener('input', ['$event.target.value'])
  onInput(value: string): void {
    this.elementRef.nativeElement.value = this.formatedValue(value);
  }

  @HostListener('blur', ['$event.target.value'])
  onBlur(value: string): void {
    const valid = DATE_REG_EXP.test(value);
    if (!valid) {
      this.elementRef.nativeElement.value = '';
    }
  }

  private formatedValue(value: string = ''): string {
    if (!value || typeof value !== 'string') {
      return '';
    }
    return this.limit(this.addSeparator(this.clear(value)));
  }

  private clear(value: string = ''): string {
    return value.replace(/[^(-./)\d]/g, '');
  }

  private addSeparator(value: string = ''): string {
    if (
      value.length === 2 // dd + / = dd/
      ||
      value.length === 5 // dd/mm + / = dd/mm/
    ) {
      return value.concat(this.dateMaskSeparator);
    }
    return value;
  }

  private limit(value: string): string {
    if (value.length > 10) { // dd/mm/aaaa + ?
      return value.substring(0, 10);
    }
    return value;
  }

}
