import { FormControl } from '@angular/forms';

import { CnsValidator } from './cns.validator';
import { FormValidators } from './form.validators';

describe('CNS Validator', () => {

  const CNS_VALID = '705202469442277';
  const CNS_INVALID = '705202469442279';
  const CNS_EMPTY_LIST = [null, undefined, ''];
  const CNS_INVALID_LIST = ['9898', '', 'asd', 123];

  it(`Teste da expressão regular o CNS: ${CNS_VALID} (válido)`, () => {
    expect(CnsValidator.CNS_REG_EXP.test(CNS_VALID)).toBeTruthy();
  });

  it(`Valida o CNS: ${CNS_VALID} (válido)`, () => {
    expect(CnsValidator.isValid(CNS_VALID)).toBeTruthy();
  });

  it(`Valida o CNS: ${CNS_INVALID} (inválido)`, () => {
    expect(CnsValidator.isValid(CNS_INVALID)).toBeFalsy();
  });

  it(`Valida CNS inválidos`, () => {
    CNS_INVALID_LIST.map((CNS: string) => expect(CnsValidator.isValid(CNS)).toBeFalsy());
  });

  it(`Valida o FormControl com o CNS: ${CNS_VALID} (válido)`, () => {
    const formControlValid = new FormControl(CNS_VALID, FormValidators.cns);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CNS: ${CNS_INVALID} (inválido)`, () => {
    const formControlInvalid = new FormControl(CNS_INVALID, FormValidators.cns);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida FormControls com CNS vazios`, () => {
    CNS_EMPTY_LIST.map((CNS: string) => {
      const formControlValid = new FormControl(CNS, FormValidators.cns);
      expect(formControlValid.valid).toBeTruthy();
    });
  });

});
