import { FormControl } from '@angular/forms';

import { CpfValidator } from './cpf.validator';
import { FormValidators } from './form.validators';

describe('CpfValidator', () => {

  const CPF_VALID_MASKED = '989.821.251-91';
  const CPF_INVALID_MASKED = '989.821.251-99';
  const CPF_VALID_UNMASKED = '98982125191';
  const CPF_INVALID_UNMASKED = '98982125199';
  const CPF_EMPTY_LIST = [null, undefined, ''];
  const CPF_INVALID_LIST = ['9898', '', 'asd', 123];

  it(`Teste da expressão regular o CPF: ${CPF_VALID_MASKED} (válido)`, () => {
    expect(CpfValidator.CPF_REG_EXP.test(CPF_VALID_MASKED)).toBeTruthy();
  });

  it(`Valida o CPF: ${CPF_VALID_MASKED} (válido)`, () => {
    expect(CpfValidator.isValid(CPF_VALID_MASKED)).toBeTruthy();
  });

  it(`Valida o CPF: ${CPF_INVALID_MASKED} (inválido)`, () => {
    expect(CpfValidator.isValid(CPF_INVALID_MASKED)).toBeFalsy();
  });

  it(`Valida o CPF: ${CPF_VALID_UNMASKED} (válido)`, () => {
    expect(CpfValidator.isValid(CPF_VALID_UNMASKED)).toBeTruthy();
  });

  it(`Valida o CPF: ${CPF_INVALID_UNMASKED} (inválido)`, () => {
    expect(CpfValidator.isValid(CPF_INVALID_UNMASKED)).toBeFalsy();
  });

  it(`Valida CPF inválidos`, () => {
    CPF_INVALID_LIST.map((CPF: string) => expect(CpfValidator.isValid(CPF)).toBeFalsy());
  });

  it(`Valida o FormControl com o CPF: ${CPF_VALID_MASKED} (válido)`, () => {
    const formControlValid = new FormControl(CPF_VALID_MASKED, FormValidators.cpf);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CPF: ${CPF_INVALID_MASKED} (inválido)`, () => {
    const formControlInvalid = new FormControl(CPF_INVALID_MASKED, FormValidators.cpf);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida o FormControl com o CPF: ${CPF_VALID_UNMASKED} (válido)`, () => {
    const formControlValid = new FormControl(CPF_VALID_UNMASKED, FormValidators.cpf);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CPF: ${CPF_INVALID_UNMASKED} (inválido)`, () => {
    const formControlInvalid = new FormControl(CPF_INVALID_UNMASKED, FormValidators.cpf);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida FormControls com CPF vazios`, () => {
    CPF_EMPTY_LIST.map((CPF: string) => {
      const formControlValid = new FormControl(CPF, FormValidators.cpf);
      expect(formControlValid.valid).toBeTruthy();
    });
  });

});
