import { FormControl } from '@angular/forms';

import { FormValidators } from './form.validators';

describe('CPF/CNPJ Validator', () => {

  const CPF_VALID_MASKED = '989.821.251-91';
  const CPF_INVALID_MASKED = '989.821.251-99';
  const CPF_VALID_UNMASKED = '98982125191';
  const CPF_INVALID_UNMASKED = '98982125199';
  const CPF_EMPTY_LIST = [null, undefined, ''];
    const CNPJ_VALID_MASKED = '10.565.000/0001-92';
  const CNPJ_INVALID_MASKED = '10.565.000/0001-99';
  const CNPJ_VALID_UNMASKED = '10565000000192';
  const CNPJ_INVALID_UNMASKED = '10565000000199';
  const CNPJ_EMPTY_LIST = [null, undefined, ''];

  it(`Valida o FormControl com o CPF: ${CPF_VALID_MASKED} (válido)`, () => {
    const formControlValid = new FormControl(CPF_VALID_MASKED, FormValidators.cpfCnpj);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CPF: ${CPF_INVALID_MASKED} (inválido)`, () => {
    const formControlInvalid = new FormControl(CPF_INVALID_MASKED, FormValidators.cpfCnpj);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida o FormControl com o CPF: ${CPF_VALID_UNMASKED} (válido)`, () => {
    const formControlValid = new FormControl(CPF_VALID_UNMASKED, FormValidators.cpfCnpj);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CPF: ${CPF_INVALID_UNMASKED} (inválido)`, () => {
    const formControlInvalid = new FormControl(CPF_INVALID_UNMASKED, FormValidators.cpfCnpj);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida FormControls com CPF vazios`, () => {
    CPF_EMPTY_LIST.map((CPF: string) => {
      const formControlValid = new FormControl(CPF, FormValidators.cpfCnpj);
      expect(formControlValid.valid).toBeTruthy();
    });
  });

  it(`Valida o FormControl com o CNPJ: ${CNPJ_VALID_MASKED} (válido)`, () => {
    const formControlValid = new FormControl(CNPJ_VALID_MASKED, FormValidators.cpfCnpj);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CNPJ: ${CNPJ_INVALID_MASKED} (inválido)`, () => {
    const formControlInvalid = new FormControl(CNPJ_INVALID_MASKED, FormValidators.cpfCnpj);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida o FormControl com o CNPJ: ${CNPJ_VALID_UNMASKED} (válido)`, () => {
    const formControlValid = new FormControl(CNPJ_VALID_UNMASKED, FormValidators.cpfCnpj);
    expect(formControlValid.valid).toBeTruthy();
  });

  it(`Valida o FormControl com o CNPJ: ${CNPJ_INVALID_UNMASKED} (inválido)`, () => {
    const formControlInvalid = new FormControl(CNPJ_INVALID_UNMASKED, FormValidators.cpfCnpj);
    expect(formControlInvalid.valid).toBeFalsy();
  });

  it(`Valida FormControls com CNPJ vazios`, () => {
    CNPJ_EMPTY_LIST.map((CNPJ: string) => {
      const formControlValid = new FormControl(CNPJ, FormValidators.cpfCnpj);
      expect(formControlValid.valid).toBeTruthy();
    });
  });

});
