import { AbstractControl, ValidatorFn } from '@angular/forms';

import { CpfValidator } from './cpf.validator';
import { CnpjValidator } from './cnpj.validator';
import { CnsValidator } from './cns.validator';


export class FormValidators {

  static cpfCnpj(ctrl: AbstractControl): { [cpf: string]: boolean } | { [cnpj: string]: boolean } | null {
    if (FormValidators.isNull(ctrl)) {
      return null;
    }
    const value: string = ctrl.value ? ctrl.value.replace(/[^\d]+/g, '') : '';
    if (value.length === 11) {
      return FormValidators.cpf(ctrl);
    } else if (value.length === 14) {
      return FormValidators.cnpj(ctrl);
    } else {
      return null;
    }
  }

  static cpf(ctrl: AbstractControl): { [cpf: string]: boolean } | null {
    if (FormValidators.isNull(ctrl)) {
      return null;
    }
    if (CpfValidator.isValid(ctrl.value)) {
      return null;
    }
    return { cpfInvalid: true };
  }

  static cnpj(ctrl: AbstractControl): { [cnpj: string]: boolean } | null {
    if (FormValidators.isNull(ctrl)) {
      return null;
    }
    if (CnpjValidator.isValid(ctrl.value)) {
        return null;
    }
    return { cnpjInvalid: true };
  }

  static cns(ctrl: AbstractControl): { [cns: string]: boolean } | null {
    if (FormValidators.isNull(ctrl)) {
      return null;
    }
    if (CnsValidator.isValid(ctrl.value)) {
      return null;
    }
    return { cnsInvalid: true };
  }

  static requiredIf(checkFn: (ctrl: AbstractControl) => boolean): ValidatorFn {
    function validator(ctrl: AbstractControl): { [requiredIf: string]: boolean } | null {
      if (checkFn(ctrl)) {
        if (!!ctrl.value) {
          return null;
        }
        return { requiredIf: true };
      }
      return null;
    }
    return validator;
  }

  static maxLength(max: number): ValidatorFn {
    function validator(ctrl: AbstractControl): { [maxLength: string]: boolean } | null {
      if (FormValidators.isNull(ctrl)) {
        return null;
      }

      if (ctrl.value.length <= max) {
        return null;
      }

      return { maxLength: true };
    }
    return validator;
  }

  static minLength(min: number): ValidatorFn {
    function validator(ctrl: AbstractControl): { [minLength: string]: boolean } | null {
      if (FormValidators.isNull(ctrl)) {
        return null;
      }

      if (ctrl.value.length >= min) {
        return null;
      }

      return { minLength: true };
    }
    return validator;
  }


  private static isNull(ctrl: AbstractControl): boolean {
    // if (ctrl.touched) {
    //   return false;
    // }
    return !(ctrl.value !== undefined && ctrl.value !== '' && ctrl.value !== null);
  }

}
