import { Component, OnInit, Input, OnDestroy } from '@angular/core';
import { MatSidenav } from '@angular/material/sidenav';
import { Subscription, of as observableOf, EMPTY } from 'rxjs';

import { NotificacaoService } from '@datasus/core';
import { tap, switchMap } from 'rxjs/operators';


const INTERVAL_SECONDS = 10;

@Component({
  selector: 'datasus-notification-button',
  templateUrl: './notification-button.component.html',
  styleUrls: ['./notification-button.component.scss']
})
export class NotificationButtonComponent implements OnInit, OnDestroy {

  @Input() sidenav: MatSidenav;

  nonReceivedCounter = 0;

  private intervalNonReceivedCounterSubscription: Subscription;

  constructor(
    private notificacaoService: NotificacaoService,
  ) { }

  ngOnInit(): void {
    this.intervalNonReceivedCounterSubscription = this.notificacaoService.getIntervalNonReceivedCounter(
      INTERVAL_SECONDS,
      () => !this.sidenav.opened
    ).subscribe(
      (counter: number) => this.nonReceivedCounter = counter,
    );
  }

  ngOnDestroy(): void {
    this.intervalNonReceivedCounterSubscription.unsubscribe();
    this.nonReceivedCounter = 0;
  }

  hasNonReceivedMessages(counter: number): boolean {
    return !!counter && counter > 0;
  }

  nonReceivedText(counter: number): string {
    if (!counter) {
      return '';
    }
    const counterMax = 9;
    return counter > counterMax ? `${counterMax}+` : counter.toString();
  }

  showMessages(): void {
    this.sidenav.open();
    this.nonReceivedCounter = 0;
  }

}
