import { DatePipe } from '@angular/common';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { delay, finalize } from 'rxjs/operators';

import { ErrorModel, NotificacaoModel, NotificacaoService } from '@datasus/core';

interface PayloadToRemove {
  notification: NotificacaoModel;
  actionId?: number;
}

@Component({
  selector: 'datasus-notification-card',
  templateUrl: './notification-card.component.html',
  styleUrls: ['./notification-card.component.scss']
})
export class NotificationCardComponent {

  @Input() notification: NotificacaoModel;
  @Output() removed: EventEmitter<PayloadToRemove> = new EventEmitter<PayloadToRemove>(true);

  hasFocusOnRemoveIcon: boolean;
  showDetails: boolean;
  loadingDetails: boolean;

  constructor(
    private notificacaoService: NotificacaoService,
  ) { }

  getAndShowDetails(): void {
    this.showDetails = true;
    if (this.notification.temTextoDetalhado && !this.notification.textoDetalhado) {
      this.loadingDetails = true;
      this.notificacaoService.getDetails(this.notification.id).pipe(
        delay(2000), // TODO Remover
        finalize(() => this.loadingDetails = false),
      ).subscribe(
        (details: string) => this.notification.textoDetalhado = details,
        (error: ErrorModel) => console.error('Erro ao buscar os detalhes da notificação', error),
      );
    }
  }

  hideDetails(): void {
    this.showDetails = false;
  }

  removeMe(actionId?: number): void {
    this.removed.emit({
      notification: this.notification,
      actionId
    });
  }

  getDate(dataAtual?: (string | number | Date)): Date {
    return new Date(dataAtual || Date.now());
  }

  resolveDate(relativeDate: string, absoluteDate: (string| number | Date)): string {
    const datePipe = new DatePipe('pt');
    const formats = {
      'Dias atrás': () => datePipe.transform(absoluteDate, 'dd/MM/yyyy HH:mm'),
      'Semanas atrás': () => datePipe.transform(absoluteDate, 'dd/MM/yyyy'),
      'Meses atrás': () => datePipe.transform(absoluteDate, 'MMMM/yyyy'),
      'Anos atrás': () => datePipe.transform(absoluteDate, 'MMMM/yyyy'),
    };

    if (typeof formats[relativeDate] === 'function') {
      return formats[relativeDate]();
    }

    return relativeDate;
  }
}
