import { Component, Input, OnDestroy } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Subscription } from 'rxjs';

import { redirectTo } from '@datasus/core';

import { SystemMenuDialogComponent } from '../system-menu-dialog/system-menu-dialog.component';
import { SistemaModel } from '../../models/sistema.model';

@Component({
  selector: 'datasus-system-menu-button',
  templateUrl: './system-menu-button.component.html',
  styleUrls: ['./system-menu-button.component.scss']
})
export class SystemMenuButtonComponent implements OnDestroy {

  @Input() type: ('icon'|'menu-item');

  private dialogSubscription: Subscription;

  constructor(
    private dialog: MatDialog,
  ) { }

  ngOnDestroy(): void {
    if (!!this.dialogSubscription) {
      this.dialogSubscription.unsubscribe();
    }
  }

  openDialog(): void {
    const dialog: MatDialogRef<SystemMenuDialogComponent> = this.dialog.open(SystemMenuDialogComponent, {
      backdropClass: (this.type === 'menu-item') ? '' : 'backdrop-transparent',
      panelClass: 'custom-dialog-container',
      disableClose: false,
      ariaLabel: 'Troca de sistema',
      maxWidth: '300px',
      position: (this.type === 'menu-item') ? {} : {top: '45px', right: '65px'},
      direction: 'ltr',
    });
    this.dialogSubscription = dialog.afterClosed().subscribe(
      (system: SistemaModel) => this.selected(system)
    );
  }

  selected(system: SistemaModel): void {
    if (!!system) {
      redirectTo(system.paginaInicial);
    }
  }
}
