import { Component, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { map, pluck } from 'rxjs/operators';

import {
  AuthService,
  SecurityService,
  PerfilModel,
  EsferaModel
} from '@datasus/core';

@Component({
  selector: 'datasus-user-profile-menu-button',
  templateUrl: './user-profile-menu-button.component.html',
  styleUrls: ['./user-profile-menu-button.component.scss']
})
export class UserProfileMenuButtonComponent implements OnInit {

  nomeCompleto$: Observable<string>;
  perfil$: Observable<PerfilModel>;
  esfera$: Observable<EsferaModel>;
  countToChoose$: Observable<number>;
  helpLink: string;

  constructor(
    private authService: AuthService,
    private securityService: SecurityService,
  ) { }

  ngOnInit(): void {
    this.helpLink = ''; // @TODO Ver como vamos mostrar o ajuda

    this.nomeCompleto$ = this.authService.getUser().pipe(pluck('nome'));

    this.countToChoose$ = this.securityService.getPerfis().pipe(
      map(
        (perfis: PerfilModel[]) => {
          let counter = 0;
          perfis.forEach(
            (perfil: PerfilModel) => counter += (perfil.esferas ? perfil.esferas.length : 0)
          );
          return counter;
        }
      )
    );

    this.perfil$ = this.securityService.getPerfilSelecionado();
    this.esfera$ = this.securityService.getEsferaSelecionada();
  }

  changeProfile(): void {
    this.securityService.navigateToChooseProfile(true);
  }

  logout(): void {
    this.authService.logout();
  }

}
