import { Directive, ElementRef, Input, OnInit, OnDestroy } from '@angular/core';
import { BreakpointObserver, Breakpoints } from '@angular/cdk/layout';
import { Subscription } from 'rxjs';

import { LayoutService } from '../services/layout.service';


@Directive({
  selector: '[datasusOnMobile]'
})
export class OnMobileDirective implements OnInit, OnDestroy {

  @Input() datasusOnMobile: ('show'|'hide');

  private breakpointSubscription: Subscription;

  constructor(
    private elementRef: ElementRef<HTMLElement>,
    private breakpointObserver: BreakpointObserver,
    private layoutService: LayoutService,
  ) { }

  ngOnInit(): void {
    this.showOrHide(this.breakpointObserver.isMatched(Breakpoints.Handset));
    this.breakpointSubscription = this.layoutService.onMobile().subscribe(
      (onMobile: boolean) => this.showOrHide(onMobile)
    );
  }

  ngOnDestroy(): void {
    this.breakpointSubscription.unsubscribe();
  }

  private showOrHide(onMobile: boolean): void {
    if (!this.datasusOnMobile) {
      return;
    }

    const isShow  = 'show' === this.datasusOnMobile;
    const isHide  = 'hide' === this.datasusOnMobile;
    const block   = ((onMobile && isShow) || (!onMobile && isHide));
    const none    = ((onMobile && isHide) || (!onMobile && isShow));
    const display = block ? 'block' : none ? 'none' : null;

    if (display) {
      this.elementRef.nativeElement.style.display = display;
    }
  }

}
