import { NgModule, ModuleWithProviders } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';
import { FlexLayoutModule } from '@angular/flex-layout';
import { LayoutModule as CdkLayoutModule } from '@angular/cdk/layout';
import { MatBottomSheetModule } from '@angular/material/bottom-sheet';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatDialogModule } from '@angular/material/dialog';
import { MatExpansionModule } from '@angular/material/expansion';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatListModule } from '@angular/material/list';
import { MatMenuModule } from '@angular/material/menu';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatSidenavModule } from '@angular/material/sidenav';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatTooltipModule } from '@angular/material/tooltip';

import { LayoutConfig } from './configs/layout.config';
import { SafeHtmlPipe } from './pipes/safeHtml.pipe';
import { FirstWordPipe } from './pipes/first-word.pipe';
import { SwitchSlashToDashPipe } from './pipes/switch-slash-to-dash.pipe';
import { ListAfterIndexPipe } from './pipes/list-after-index.pipe';
import { ListUntilIndexPipe } from './pipes/list-until-index.pipe';
import { RelativeDatePipe } from './pipes/relative-date.pipe';
import { OnMobileDirective } from './directives/on-mobile.directive';
import { ContainerComponent } from './components/container/container.component';
import { ContainerTransparentComponent } from './components/container-transparent/container-transparent.component';
import { DialogAlertComponent } from './components/dialog-alert/dialog-alert.component';
import { DialogConfirmationComponent } from './components/dialog-confirmation/dialog-confirmation.component';
import { DialogPromptComponent } from './components/dialog-prompt/dialog-prompt.component';
import { FooterComponent } from './components/footer/footer.component';
import { LayoutComponent } from './components/layout/layout.component';
import { LoaderComponent } from './components/loader/loader.component';
import { MenuSidenavComponent } from './components/menu-sidenav/menu-sidenav.component';
import { NotificationButtonComponent } from './components/notification-button/notification-button.component';
import { NotificationCardComponent } from './components/notification-card/notification-card.component';
import { NotificationSidenavComponent } from './components/notification-sidenav/notification-sidenav.component';
import { RootComponent } from './components/root/root.component';
import { SystemMenuDialogComponent } from './components/system-menu-dialog/system-menu-dialog.component';
import { SystemMenuButtonComponent } from './components/system-menu-button/system-menu-button.component';
import { ToolbarComponent } from './components/toolbar/toolbar.component';
import { UserProfileMenuButtonComponent } from './components/user-profile-menu-button/user-profile-menu-button.component';
import { CardContentComponent } from './components/card-content/card-content.component';

const layoutConfigDefault: LayoutConfig = {
  withGovBrBar: false,
  appName: '',
  appVersion: '',
  localMenu: null,
};

@NgModule({
  imports: [
    // Angular
    CommonModule,
    RouterModule,
    // Angular Flex-Layout
    FlexLayoutModule,
    // Angular Material
    CdkLayoutModule,
    MatBottomSheetModule,
    MatButtonModule,
    MatCardModule,
    MatDialogModule,
    MatExpansionModule,
    MatFormFieldModule,
    MatIconModule,
    MatInputModule,
    MatListModule,
    MatMenuModule,
    MatProgressBarModule,
    MatProgressSpinnerModule,
    MatSidenavModule,
    MatToolbarModule,
    MatTooltipModule,
  ],
  declarations: [
    // Pipes
    SafeHtmlPipe,
    FirstWordPipe,
    SwitchSlashToDashPipe,
    ListAfterIndexPipe,
    ListUntilIndexPipe,
    RelativeDatePipe,
    // Directives
    OnMobileDirective,
    // Components
    ContainerComponent,
    ContainerTransparentComponent,
    DialogAlertComponent,
    DialogConfirmationComponent,
    DialogPromptComponent,
    FooterComponent,
    LayoutComponent,
    LoaderComponent,
    MenuSidenavComponent,
    NotificationButtonComponent,
    NotificationCardComponent,
    NotificationSidenavComponent,
    RootComponent,
    SystemMenuDialogComponent,
    SystemMenuButtonComponent,
    ToolbarComponent,
    UserProfileMenuButtonComponent,
    CardContentComponent,
  ],
  entryComponents: [
    DialogAlertComponent,
    DialogConfirmationComponent,
    DialogPromptComponent,
    SystemMenuDialogComponent,
  ],
  exports: [
    // Pipes
    FirstWordPipe,
    SwitchSlashToDashPipe,
    // Directives
    OnMobileDirective,
    // Components
    ContainerComponent,
    ContainerTransparentComponent,
    LayoutComponent,
    CardContentComponent,
    RootComponent,
  ],
  providers: [{
    provide: 'LayoutConfig',
    useValue: layoutConfigDefault,
  }],
})
export class LayoutModule {

  /**
   * Criando o Módulo com suas configurações
   * @param layoutConfig Configuração do layout: Com ou sem a barra do GOV.BR, etc...
   */
  public static forRoot(layoutConfig: LayoutConfig): ModuleWithProviders<LayoutModule> {
    return {
      ngModule: LayoutModule,
      providers: [{
        provide: 'LayoutConfig',
        useValue: layoutConfig,
      }],
    };
  }
}
