import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { HttpClientModule } from '@angular/common/http';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { FlexLayoutModule } from '@angular/flex-layout';
import { RouterModule, Routes } from '@angular/router';
import { NgxMaskModule } from 'ngx-mask';
import { MultiSelectModule } from 'primeng/multiselect';

import { routesDefault, guardsDefault } from '@datasus/commons';

import { MaterialModule } from '../material/material.module';
import { DatasusModule } from '../datasus/datasus.module';
import { ParentComponent } from './parent.component';
import { ListComponent } from './list/list.component';
import { ListWithoutLayoutComponent } from './list-without-layout/list-without-layout.component';

const appRoutes: Routes = [
  {
    path: 'list',
    component: ListComponent,
    data: {
      layoutAnimation: true,
      layoutColor: 'warn',
    },
    canActivate: [
      ...guardsDefault,
    ],
  },
  {
    path: 'list-without-layout',
    component: ListWithoutLayoutComponent,
    data: {
      layoutAnimation: true,
      layoutColor: 'warn',
    },
    canActivate: [
      ...guardsDefault,
    ],
  },
  {
    path: 'lazy',
    loadChildren: './lazy.module#LazyModule',
    canActivate: [
      ...guardsDefault,
    ],
    canLoad: [
      ...guardsDefault,
    ],
  },
];

@NgModule({
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    HttpClientModule,
    FormsModule,
    ReactiveFormsModule,
    FlexLayoutModule,
    MaterialModule,
    NgxMaskModule.forRoot({ dropSpecialCharacters: true }),
    MultiSelectModule,
    DatasusModule,
    RouterModule.forRoot([...appRoutes, ...routesDefault], {
      useHash: false,
      enableTracing: true,
      onSameUrlNavigation: 'reload',
      scrollPositionRestoration: 'top',
    }),
  ],
  declarations: [
    ParentComponent,
    ListComponent,
    ListWithoutLayoutComponent,
  ],
  bootstrap: [
    ParentComponent
  ]
})
export class AppModule { }
