import { Component, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup, FormGroupDirective, Validators } from '@angular/forms';
import { Observable } from 'rxjs';

import { DialogService, LayoutService } from '@datasus/layout';
import { CustomErrorStateMatcher } from '@datasus/forms';
import { SHA256, download } from '@datasus/core';
import { AssinaturaDigitalDialogService } from '@datasus/externals';
import { take } from 'rxjs/operators';


interface Opt {
  id: number;
  nome: string;
  descricao?: string;
}

@Component({
  selector: 'datasus-app-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.scss'],
})
export class ListComponent implements OnInit {

  myDate: Date;
  list: string[];
  onMobile$: Observable<boolean>;
  loading = false;
  teste: any;

  formGroup: FormGroup;
  selected: any;
  options: Opt[];
  matcher = new CustomErrorStateMatcher();
  foods: any[] = [
    { id: 1, value: 'steak-0', descricao: 'Steak' },
    { id: 2, value: 'pizza-1', descricao: 'Pizza' },
    { id: 3, value: 'tacos-2', descricao: 'Tacos' }
  ];
  outputSHA256 = '';
  inputputSHA256 = '';

  @ViewChild(FormGroupDirective) formGroupDirective: FormGroupDirective;

  constructor(
    private layoutService: LayoutService,
    private dialogService: DialogService,
    private formBuilder: FormBuilder,
    private assinaturaDigitalDialogService: AssinaturaDigitalDialogService,
  ) { }

  ngOnInit(): void {
    this.layoutService.setTitle('Nome da Funcionalidade');

    this.onMobile$ = this.layoutService.onMobile();

    // this.options = Array(100)
    //   .fill({ id: 0, nome: 'TESTE - LOREN ASAFSAFSADFSDAF', descricao: '' })
    //   .map((item: any, index: number) => ({
    //     id: index++,
    //     nome: `${item.nome} - ${index}`,
    //     descricao: `TOOLTIP - ${index}`
    //   }));

    // this.options = [
    //   { id: 151, nome: "0-Tipificação Jeffe", descricao: "Teste " },
    //   { id: 241, nome: "007", descricao: "teste" },
    //   { id: 242, nome: "007 / 007-1", descricao: "007-filho " },
    //   { id: 114, nome: "TESTE GABRIEL CONFIGURAÇÃO" },
    //   { id: 115, nome: "TESTE GABRIEL CONFIGURAÇÃO / TESTE GABRIEL CONFIGURAÇÃO 1" },
    //   { id: 116, nome: "TESTE GABRIEL CONFIGURAÇÃO / TESTE GABRIEL CONFIGURAÇÃO 1 / TESTE GABRIEL CONFIGURAÇÃO 1.1" },
    //   { id: 117, nome: "TESTE GABRIEL CONFIGURAÇÃO / TESTE GABRIEL CONFIGURAÇÃO 2" },
    //   { id: 118, nome: "TESTE GABRIEL CONFIGURAÇÃO / TESTE GABRIEL CONFIGURAÇÃO 2 / TESTE GABRIEL CONFIGURAÇÃO 2.1" },
    //   { id: 102, nome: "TESTE SEM BARRA" },
    //   { id: 103, nome: "TESTE TIPIFICAÇÃO COM BARRA" },
    //   { id: 101, nome: "TESTE TRAÇO AQUI", descricao: "TESTE TRAÇO - AQUI" },
    //   { id: 142, nome: "TIP MARCOS 1", descricao: "TIP MARCOS 1" },
    //   { id: 143, nome: "TIP MARCOS 1 / TIP MARCOS 1.1", descricao: "TIP MARCOS 1.1" },
    //   { id: 146, nome: "TIP MARCOS 1 / TIP MARCOS 1.2", descricao: "TIP MARCOS 1.2" },
    //   { id: 119, nome: "TIPIFICACAO ANDRE 1", descricao: "TIPIFICACAO ANDRE 1" },
    //   { id: 120, nome: "TIPIFICACAO ANDRE 1 / TIPIFICACAO ANDRE 2", descricao: "TIPIFICACAO ANDRE 2" },
    //   { id: 121, nome: "TIPIFICACAO ANDRE 1 / TIPIFICACAO ANDRE 2 / TIPIFICACAO ANDRE 3", descricao: "TTIPIFICACAO ANDRE 3" },
    //   { id: 2, nome: "TIPIFICAÇÃO 2", descricao: "TIPIFICAÇÃO 2" },
    //   { id: 24, nome: "TIPIFICAÇÃO 2 / TIPIFICACAO 2.5", descricao: "TIPIFICACAO 2.5" },
    //   { id: 3, nome: "TIPIFICAÇÃO 2 / TIPIFICAÇÃO 2.1", descricao: "TIPIFICAÇÃO 2.1" },
    //   { id: 10, nome: "TIPIFICAÇÃO 2 / TIPIFICAÇÃO 2.2", descricao: "TIPIFICAÇÃO 2.2" },
    //   { id: 22, nome: "TIPIFICAÇÃO 2 / TIPIFICAÇÃO 2.3", descricao: "TIPIFICAÇÃO 2.3" },
    //   { id: 23, nome: "TIPIFICAÇÃO 2 / TIPIFICAÇÃO 2.4", descricao: "TIPIFICAÇÃO 2.4" },
    //   { id: 25, nome: "TIPIFICAÇÃO 5", descricao: "TIPIFICAÇÃO 5" },
    //   { id: 26, nome: "TIPIFICAÇÃO 5 / TIPIFICAÇÃO 5.1", descricao: "TIPIFICAÇÃO 5.1" },
    //   { id: 27, nome: "TIPIFICAÇÃO 5 / TIPIFICAÇÃO 5.1 / TIPIFICAÇÃO 5.1.1", descricao: "TIPIFICAÇÃO 5.1.1" },
    //   { id: 28, nome: "TIPIFICAÇÃO 5 / TIPIFICAÇÃO 5.1 / TIPIFICAÇÃO 5.1.1 / TIPIFICAÇÃO 5.1.1.1", descricao: "TIPIFICAÇÃO 5.1.1.1" },
    //   { id: 29, nome: "TIPIFICAÇÃO 6", descricao: "TIPIFICAÇÃO 6" },
    //   { id: 31, nome: "TIPIFICAÇÃO 6 / TIPIFICAÇÃO 6.2", descricao: "TIPIFICAÇÃO 6.2" },
    //   { id: 35, nome: "TIPIFICAÇÃO 7", descricao: "TIPIFICAÇÃO 7" },
    //   { id: 56, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3" },
    //   { id: 57, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3" },
    //   { id: 61, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3" },
    //   { id: 62, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3" },
    //   { id: 63, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3" },
    //   { id: 64, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3 / TIPIFICAÇÃO 7.3.1", descricao: "TIPIFICAÇÃO 7.3.1" },
    //   { id: 65, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3 / TIPIFICAÇÃO 7.3.1 / TIPIFICAÇÃO 7.3.2", descricao: "TIPIFICAÇÃO 7.3.2" },
    //   { id: 66, nome: "TIPIFICAÇÃO 7 / TIPIFICAÇÃO 7.3 / TIPIFICAÇÃO 7.3.1 / TIPIFICAÇÃO 7.3.2 / TIPIFICAÇÃO 7.3.2.1", descricao: "TIPIFICAÇÃO 7.3.2.1" },
    //   { id: 42, nome: "TIPIFICAÇÃO 8", descricao: "TIPIFICAÇÃO 8" },
    //   { id: 43, nome: "TIPIFICAÇÃO 8 / TIPIFICAÇÃO 8.1", descricao: "TIPIFICAÇÃO 8.1" },
    //   { id: 47, nome: "TIPIFICAÇÃO 8 / TIPIFICAÇÃO 8.1 / TIPIFICAÇÃO 8.1.1", descricao: "TIPIFICAÇÃO 8.1.1" },
    //   { id: 48, nome: "TIPIFICAÇÃO 8 / TIPIFICAÇÃO 8.1 / TIPIFICAÇÃO 8.1.1 / TIPIFICAÇÃO 8.1.2", descricao: "TIPIFICAÇÃO 8.1.2" },
    //   { id: 44, nome: "TIPIFICAÇÃO 8 / TIPIFICAÇÃO 8.2", descricao: "TIPIFICAÇÃO 8.2" },
    //   { id: 45, nome: "TIPIFICAÇÃO 8 / TIPIFICAÇÃO 8.2 / TIPIFICAÇÃO 8.2.1", descricao: "TIPIFICAÇÃO 8.2.1" },
    //   { id: 46, nome: "TIPIFICAÇÃO 8 / TIPIFICAÇÃO 8.2 / TIPIFICAÇÃO 8.2.1 / TIPIFICAÇÃO 8.2.1.1", descricao: "TIPIFICAÇÃO 8.2.1.1" },
    //   { id: 104, nome: "teste barra       " },
    //   { id: 105, nome: "teste barra        / dsadsa      " }
    // ];

    this.options = [
      { id: 261, nome: 'A PONTO DE RESPOSTA'},
      { id: 181, nome: 'ALTERAR EVIDENCIA'},
      { id: 45, nome: 'B Ponto de resposta'},
      { id: 182, nome: 'BBBBBBB'},
      { id: 46, nome: 'C Ponto de restposta'},
      { id: 184, nome: 'CCCCCCC'},
      { id: 221, nome: 'DCSGDFGSD'},
      { id: 183, nome: 'DDDDDDDD'},
      { id: 101, nome: 'DENASUS'},
      { id: 1, nome: 'MINISTÉRIO DA SAÚDE'},
      { id: 141, nome: 'MS ¿ Ministério da Saúde'},
      { id: 186, nome: 'OUVIDORIA EVIDENCIA 1'},
      { id: 262, nome: 'OUVIDORIA NÍVEL 1'},
      { id: 44, nome: 'OUVIDORIA NÍVEL 2'},
      { id: 203, nome: 'OUVIDORIA NÍVEL 3'},
      { id: 110, nome: 'OUVIDORIA-GERAL DO SUS'},
      { id: 2, nome: 'Ouvidoria Gabriel 1'},
      { id: 18, nome: 'Ouvidoria Gabriel 2'},
      { id: 42, nome: 'PONTO DE RESPOSTA GABRIEL'},
      { id: 103, nome: 'PONTO DE RESPOSTA SECRETARIA DE SAUDE DO DISTRITO FEDERAL'},
      { id: 7, nome: 'SECRETARIA DE SAUDE DO DISTRITO FEDERAL'},
      { id: 63, nome: 'TESTE CAIXA ALTA ALTERADO'},
      { id: 62, nome: 'TESTE CAIXA ALTA NO CAMPO ALTERADOA'},
      { id: 64, nome: 'TESTE CAIXA ALTA ORGAO ALTERADO'},
      { id: 109, nome: 'TESTE ITEM 670'},
      { id: 121, nome: 'TESTE OUVIDORIA OD'},
      { id: 205, nome: 'TESTE PONTO DE REPOSTA REGISTRO RL_TEMA'},
      { id: 187, nome: 'TESTE RELACAO CO_TEMA'},
      { id: 3, nome: 'teste pesquisa de ouvidorias'},
    ];

    this.formGroup = this.formBuilder.group({
      data: [null],
      select: [null, Validators.required],
      teste: [null, Validators.required],
      selectMultiple: [null, Validators.required],
      food: [null]
    });

    this.formGroup.get('data').valueChanges
      .subscribe((value) => console.log('%cData:', 'color: red; font-size: 3em;', value));

    this.formGroup.get('food').valueChanges
      .subscribe((value) => {
        this.loading = true;
        setTimeout(() => {
          this.options = [];
          this.options = Array(3000)
            .fill({ id: 0, nome: 'TESTE - LOREN ASAFSAFSADFSDAF', descricao: '' })
            .map((item: any, index: number) => ({
              id: index++,
              nome: `${value} ${item.nome} - ${index}`,
              descricao: `TOOLTIP - ${index}`
            }));
          this.loading = false;
        }, 5000);
      });
  }

  assinaturaDigitalSignDialog(): void {
    const dialog = this.assinaturaDigitalDialogService
      .openSignDialog('exemplo-20200102-ce7efd4c-a60d-43d1-9502-175ff69ce6b4');

    dialog.afterClosed().pipe(take(1))
      .subscribe(() => console.log('assinaturaDigitalSignDialog: afterClosed'));
    dialog.afterOpened().pipe(take(1))
      .subscribe(() => console.log('assinaturaDigitalSignDialog: afterOpened'));
  }
  assinaturaDigitalTestDialog(): void {
    const dialog = this.assinaturaDigitalDialogService.openTestDialog();

    dialog.afterClosed().pipe(take(1))
      .subscribe(() => console.log('assinaturaDigitalTestDialog: afterClosed'));
    dialog.afterOpened().pipe(take(1))
      .subscribe(() => console.log('assinaturaDigitalTestDialog: afterOpened'));
  }
  assinaturaDigitalPreviewDialog(): void {
    const dialog = this.assinaturaDigitalDialogService
      .openPreviewDialog('exemplo-20200102-ce7efd4c-a60d-43d1-9502-175ff69ce6b4');

    dialog.afterClosed().pipe(take(1))
      .subscribe(() => console.log('assinaturaDigitalPreviewDialog: afterClosed'));
    dialog.afterOpened().pipe(take(1))
      .subscribe(() => console.log('assinaturaDigitalPreviewDialog: afterOpened'));
  }

  sha256(input: string): string {
    return SHA256(input);
  }

  execDownload(): void {
    download('hello,world', 'teste.csv', 'text/csv');
  }

  submit(event: Event): void {
    event.preventDefault();
    event.stopPropagation();
    if (this.formGroup.valid) {
      this.dialogService.showNotification('form OKKKK!');
    }
  }

  resetForm(): void {
    this.formGroup.reset();
    this.formGroupDirective.resetForm();
  }

  compareItemLista(list: Opt[], item: Opt): boolean {
    return true; // list.some((i: Opt) => i.id === item.id);
  }

  getSelectedOptions(selected: any) {
    this.selected = selected;
  }
}
