import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';

import { BaseService, PageableRequestModel, PageableResponseModel } from '@datasus/core';
import { delay } from 'rxjs/operators';
import { TabelaFilterModel } from './tabelas-filter.model';
import { TabelaModel } from './tabelas.model';

@Injectable({
  providedIn: 'root'
})
export class SomeService extends BaseService {

  requestStringOk(): Observable<string> {
    return this.baseGet<string>('retorna/string-ok');
  }

  requestBooleanTrue(): Observable<boolean> {
    return this.baseGet<boolean>('retorna/boolean-true');
  }

  requestInteger1(): Observable<number> {
    return this.baseGet<number>('retorna/integer-1');
  }

  requestVoid(): Observable<void> {
    return this.baseGet<void>('retorna/void');
  }

  requestError400(): Observable<any> {
    return this.baseGet<any>('lanca-erro/400');
  }

  requestError500(): Observable<any> {
    return this.baseGet<any>('lanca-erro/500');
  }

  post(): Observable<boolean> {
    return this.basePost<boolean>('diferente-de-get/', {});
  }

  put(): Observable<boolean> {
    return this.basePut<boolean>('diferente-de-get/1', {});
  }

  delete(): Observable<boolean> {
    return this.baseDelete<boolean>('diferente-de-get/1');
  }

  paged(data: PageableRequestModel<TabelaFilterModel>): Observable<PageableResponseModel<TabelaModel>> {
    return this.basePost<PageableResponseModel<TabelaModel>>('/tabelas/paginado', data)
      .pipe(delay(2000));
  }

}
