--------------------------------------------------------
--  DDL for Table tb_acesso
--------------------------------------------------------
CREATE SEQUENCE dbscodes.sq_acesso_coseqacesso;

CREATE TABLE dbscodes.tb_acesso
(	
	co_seq_acesso bigint NOT NULL DEFAULT nextval('dbscodes.sq_acesso_coseqacesso'::regclass),
	no_usuario character varying(12) NOT NULL, 
	co_sessao character varying(50) NOT NULL, 
	nu_ip_cliente character varying(50), 
	nu_ip_servidor character varying(50), 
	dt_entrada timestamp NOT NULL, 
	dt_saida timestamp, 
	ds_falha character varying(100),
	CONSTRAINT pk_acesso PRIMARY KEY (co_seq_acesso)
);

COMMENT ON TABLE dbscodes.tb_acesso IS 'Registros de acesso ao sistema';
COMMENT ON COLUMN dbscodes.tb_acesso.co_seq_acesso IS 'Codigo de Identificacão do Acesso, gerador pela sequence: dbscodes.sq_acesso_coseqacesso';
COMMENT ON COLUMN dbscodes.tb_acesso.no_usuario IS 'Usuario que acessou';
COMMENT ON COLUMN dbscodes.tb_acesso.co_sessao IS 'Código de identificacão da Sessão';
COMMENT ON COLUMN dbscodes.tb_acesso.nu_ip_cliente IS 'IP do Cliente';
COMMENT ON COLUMN dbscodes.tb_acesso.nu_ip_servidor IS 'IP do Servidor';
COMMENT ON COLUMN dbscodes.tb_acesso.dt_entrada IS 'Data da Entrada no sistema';
COMMENT ON COLUMN dbscodes.tb_acesso.dt_saida IS 'Data de Saida do sistema';
COMMENT ON COLUMN dbscodes.tb_acesso.ds_falha IS 'Descrição da Falha';

--------------------------------------------------------
--  DDL for Table tb_usuario
--------------------------------------------------------
CREATE SEQUENCE dbscodes.sq_usuario_cosequsuario;

CREATE TABLE dbscodes.tb_usuario
(	
	co_seq_usuario bigint NOT NULL DEFAULT nextval('dbscodes.sq_usuario_cosequsuario'::regclass),
	no_login character varying(12) NOT NULL, 
	ds_senha character varying(32) NOT NULL, 
	nu_tentativas bigint NOT NULL, 
	st_ativo boolean NOT NULL DEFAULT false, 
	ds_email character varying(50) NOT NULL, 
	st_travado boolean NOT NULL DEFAULT false, 
	ds_falta_acesso character varying(255), 
	dt_cadastro timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, 
	dt_ultimo_acesso timestamp,
	CONSTRAINT pk_usuario PRIMARY KEY (co_seq_usuario),

);

CREATE UNIQUE INDEX in_usuario_login ON dbscodes.tb_usuario(no_login);
CREATE UNIQUE INDEX in_usuario_email ON dbscodes.tb_usuario(ds_email);

COMMENT ON TABLE dbscodes.tb_usuario IS 'Registros de usuários do sistema';
COMMENT ON COLUMN dbscodes.tb_usuario.co_seq_usuario IS 'Codigo de identificacão do Usuario, gerador pela sequence: dbscodes.sq_usuario_cosequsuario';
COMMENT ON COLUMN dbscodes.tb_usuario.no_login IS 'Login';
COMMENT ON COLUMN dbscodes.tb_usuario.ds_senha IS 'Senha';
COMMENT ON COLUMN dbscodes.tb_usuario.nu_tentativas IS 'Quantidade de Tentativas';
COMMENT ON COLUMN dbscodes.tb_usuario.st_ativo IS 'Usuário Ativo (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_usuario.ds_email IS 'Email do Usuario';
COMMENT ON COLUMN dbscodes.tb_usuario.st_travado IS 'Usuario Travado (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_usuario.ds_falta_acesso IS 'Descrição da falta de acesso.';
COMMENT ON COLUMN dbscodes.tb_usuario.dt_cadastro IS 'Data e hora da inclusão do cadastro.';
COMMENT ON COLUMN dbscodes.tb_usuario.dt_ultimo_acesso IS 'Data e hora do último login.';

--------------------------------------------------------
--  DDL for Table tb_cartao_acesso
--------------------------------------------------------
CREATE SEQUENCE dbscodes.sq_cartaoacesso_coseqcartaoacesso;

CREATE TABLE dbscodes.tb_cartao_acesso
(	
    co_seq_cartao_acesso bigint NOT NULL DEFAULT nextval('dbscodes.sq_cartaoacesso_coseqcartaoacesso'::regclass),
    st_ativo boolean NOT NULL DEFAULT false,
    nu_tentativas bigint NOT NULL,
    co_usuario bigint NOT NULL,
    CONSTRAINT pk_cartaoacesso PRIMARY KEY (co_seq_cartao_acesso)
);

ALTER TABLE dbscodes.tb_cartao_acesso ADD CONSTRAINT fk_cartaoacesso_usuario FOREIGN KEY(co_usuario)
    REFERENCES dbscodes.tb_usuario(co_seq_usuario);

COMMENT ON TABLE dbscodes.tb_cartao_acesso IS 'Registros de cartões de acesso do sistema';
COMMENT ON COLUMN dbscodes.tb_cartao_acesso.co_seq_cartao_acesso IS 'Codigo de identificacão, gerador pela sequence: dbscodes.sq_cartaoacesso_coseqcartaoacesso';
COMMENT ON COLUMN dbscodes.tb_cartao_acesso.st_ativo IS 'Cartão de acesso Ativo (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_cartao_acesso.nu_tentativas IS 'Número de tentativas.';
COMMENT ON COLUMN dbscodes.tb_cartao_acesso.co_usuario IS 'Código do usuário, chave estrangeira para dbscodes.tb_usuario';


--------------------------------------------------------
--  DDL for Table tb_cartao_posicao
--------------------------------------------------------
CREATE TABLE dbscodes.tb_cartao_posicao
(	
	co_cartao_acesso bigint NOT NULL,
	nu_posicao bigint NOT NULL, 
	nu_numero bigint NOT NULL,
    CONSTRAINT pk_cartaoposicao PRIMARY KEY (co_cartao_acesso, nu_posicao)
);


ALTER TABLE dbscodes.tb_cartao_posicao ADD CONSTRAINT fk_cartaoacesso_cartaoposicao FOREIGN KEY(co_cartao_acesso)
	  REFERENCES dbscodes.tb_cartao_acesso(co_seq_cartao_acesso);

COMMENT ON TABLE dbscodes.tb_cartao_posicao IS 'Registros da posição dos cartões de acess';
COMMENT ON COLUMN dbscodes.tb_cartao_posicao.co_cartao_acesso IS 'Código do cartão de acesso, chave estrangeira para dbscodes.tb_cartao_acesso';
COMMENT ON COLUMN dbscodes.tb_cartao_posicao.nu_posicao IS 'Número da ordenação posição.';
COMMENT ON COLUMN dbscodes.tb_cartao_posicao.nu_numero IS 'Número da posição.';


--------------------------------------------------------
--  DDL for Table tb_funcionalidade
--------------------------------------------------------
CREATE SEQUENCE dbscodes.sq_funcionalidade_coseqfuncionalidade;

CREATE TABLE dbscodes.tb_funcionalidade
(	
	co_seq_funcionalidade bigint NOT NULL DEFAULT nextval('dbscodes.sq_funcionalidade_coseqfuncionalidade'::regclass),
	no_funcionalidade character varying(40), 
	st_criar boolean NOT NULL DEFAULT false, 
	st_pesquisar boolean NOT NULL DEFAULT false,  
	st_alterar boolean NOT NULL DEFAULT false, 
	st_excluir boolean NOT NULL DEFAULT false, 
	st_imprimir boolean NOT NULL DEFAULT false, 
	co_funcionalidade_pai bigint,
    CONSTRAINT pk_funcionalidade PRIMARY KEY (co_seq_funcionalidade)
);

ALTER TABLE dbscodes.tb_funcionalidade ADD CONSTRAINT fk_funcionalidade_funcionalidade FOREIGN KEY(co_funcionalidade_pai)
	  REFERENCES dbscodes.tb_funcionalidade(co_seq_funcionalidade);

COMMENT ON TABLE dbscodes.tb_funcionalidade IS 'Registros das funcionalidades e permissões disponíveis em cada uma, com hierarquia.';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.co_seq_funcionalidade IS 'Codigo de identificacão, gerador pela sequence: dbscodes.sq_funcionalidade_coseqfuncionalidade';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.no_funcionalidade IS 'Noome da Funcionalidade';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.st_criar IS 'Permissão para Incluir (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.st_pesquisar IS 'Permissão para Pesquisar (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.st_alterar IS 'Permissão para Alterar (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.st_excluir IS 'Permissão para Excluir (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.st_imprimir IS 'Permissão para Imprimir (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_funcionalidade.co_funcionalidade_pai IS 'Codigo de identificacão da Funcionalidade Pai, auto relacionamento com a coluna co_seq_funcionalidade';

--------------------------------------------------------
--  DDL for Table tb_grupo
--------------------------------------------------------
CREATE SEQUENCE dbscodes.sq_grupo_coseqrupo;

CREATE TABLE dbscodes.tb_grupo
(	
	co_seq_grupo bigint NOT NULL DEFAULT nextval('dbscodes.sq_grupo_coseqrupo'::regclass),
	no_grupo character varying(20) NOT NULL, 
	ds_grupo character varying(50) NOT NULL, 
	st_ativo boolean NOT NULL DEFAULT false,
	CONSTRAINT pk_grupo PRIMARY KEY (co_seq_grupo)
);

COMMENT ON TABLE dbscodes.tb_grupo IS 'Registros dos grupos de usuários do sistema.';
COMMENT ON COLUMN dbscodes.tb_grupo.co_seq_grupo IS 'Codigo de identificacão, gerador pela sequence: dbscodes.sq_grupo_coseqrupo';
COMMENT ON COLUMN dbscodes.tb_grupo.no_grupo IS 'Nome do grupo';
COMMENT ON COLUMN dbscodes.tb_grupo.ds_grupo IS 'Descrição do grupo';
COMMENT ON COLUMN dbscodes.tb_grupo.st_ativo IS 'Grupo ativo (false - Falso / true - Verdadeiro)';

--------------------------------------------------------
--  DDL for Table rl_grupo_usuario
--------------------------------------------------------
CREATE TABLE dbscodes.rl_grupo_usuario
(	
	co_usuario bigint NOT NULL, 
	co_grupo bigint NOT NULL,
	CONSTRAINT pk_grupousuario PRIMARY KEY (co_usuario, co_grupo)
);

ALTER TABLE  dbscodes.rl_grupo_usuario ADD CONSTRAINT fk_usuario_grupousuario FOREIGN KEY(co_usuario)
	REFERENCES dbscodes.tb_usuario(co_seq_usuario);

ALTER TABLE dbscodes.rl_grupo_usuario ADD CONSTRAINT fk_grupo_grupousuario FOREIGN KEY(co_grupo)
	REFERENCES dbscodes.tb_grupo(co_seq_grupo);

COMMENT ON TABLE dbscodes.rl_grupo_usuario IS 'Relacionamento entre usuário e grupos.';
COMMENT ON COLUMN dbscodes.rl_grupo_usuario.co_usuario IS 'Codigo de identificacão do Usuario, chave estrangeira para dbscodes.tb_usuario';
COMMENT ON COLUMN dbscodes.rl_grupo_usuario.co_grupo IS 'Codigo de identificacão do Grupo, chave estrangeira para dbscodes.tb_grupo';

--------------------------------------------------------
--  DDL for Table tb_perfil
--------------------------------------------------------
CREATE SEQUENCE dbscodes.sq_perfil_coseqperfil;

CREATE TABLE dbscodes.tb_perfil
(	
	co_seq_perfil bigint NOT NULL DEFAULT nextval('dbscodes.sq_perfil_coseqperfil'::regclass),
	no_perfil character varying(20) NOT NULL, 
	ds_perfil character varying(50) NOT NULL, 
	st_ativo boolean NOT NULL DEFAULT false,
	CONSTRAINT pk_perfil PRIMARY KEY (co_seq_perfil)
);

COMMENT ON TABLE dbscodes.tb_perfil IS 'Tabela com perfis do sistema.';
COMMENT ON COLUMN dbscodes.tb_perfil.co_seq_perfil IS 'Codigo de identificacão, gerador pela sequence: dbscodes.sq_perfil_coseqperfil';
COMMENT ON COLUMN dbscodes.tb_perfil.no_perfil IS 'Nome do Perfil';
COMMENT ON COLUMN dbscodes.tb_perfil.ds_perfil IS 'Descricão do Perfil';
COMMENT ON COLUMN dbscodes.tb_perfil.st_ativo IS 'Perfil ativo (false - Falso / true - Verdadeiro)';

--------------------------------------------------------
--  DDL for Table tb_perfil_funcionalidade
--------------------------------------------------------
CREATE TABLE dbscodes.tb_perfil_funcionalidade
(	
	co_perfil bigint NOT NULL, 
	co_funcionalidade bigint NOT NULL, 
	st_criar boolean NOT NULL DEFAULT false, 
	st_pesquisar boolean NOT NULL DEFAULT false,  
	st_alterar boolean NOT NULL DEFAULT false, 
	st_excluir boolean NOT NULL DEFAULT false, 
	st_imprimir boolean NOT NULL DEFAULT false, 
	CONSTRAINT pk_perfilfuncionalidade PRIMARY KEY(co_perfil, co_funcionalidade)
);

COMMENT ON TABLE dbscodes.tb_perfil_funcionalidade IS 'Tabela com as permissões disponíveis por perfil.';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.co_perfil IS 'Codigo de identificacão do Perfil, chave estrangeira para dbscodes.tb_perfil';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.co_funcionalidade IS 'Codigo de identificacão da Funcionalidade, chave estrangeira para dbscodes.tb_funcionalidade';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.st_criar IS 'Permissão para a Funcionalidade incluir para determinado perfil (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.st_pesquisar IS 'Permisã?o para a Funcionalidade Pesquisar para determinado perfil (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.st_alterar IS 'Permissão para a Funcionalidade alterar para determinado perfil (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.st_excluir IS 'Permissão para a Funcionalidade excluir para determinado perfil (false - Falso / true - Verdadeiro)';
COMMENT ON COLUMN dbscodes.tb_perfil_funcionalidade.st_imprimir IS 'Permissão para a Funcionalidade imprimir para determinado perfil (false - Falso / true - Verdadeiro)';

ALTER TABLE dbscodes.tb_perfil_funcionalidade ADD CONSTRAINT fk_perfil_perfilfuncionalidade FOREIGN KEY(co_perfil)
	REFERENCES dbscodes.tb_perfil(co_seq_perfil);

ALTER TABLE dbscodes.tb_perfil_funcionalidade ADD CONSTRAINT fk_grupo_perfilfuncionalidade FOREIGN KEY(co_funcionalidade)
	REFERENCES dbscodes.tb_funcionalidade(co_seq_funcionalidade);

--------------------------------------------------------
--  DDL for Table rl_perfil_grupo
--------------------------------------------------------

CREATE TABLE dbscodes.rl_perfil_grupo
(	
	co_grupo bigint NOT NULL, 
	co_perfil bigint NOT NULL,
	CONSTRAINT pk_perfilgrupo PRIMARY KEY(co_grupo, co_perfil)
);

COMMENT ON TABLE dbscodes.rl_perfil_grupo IS 'Tabela de relacionamento entre grupo de usuários e perfis.';
COMMENT ON COLUMN dbscodes.rl_perfil_grupo.co_grupo IS 'Codigo de identificacão do Grupo, chave estrangeira para dbscodes.tb_grupo';
COMMENT ON COLUMN dbscodes.rl_perfil_grupo.co_perfil IS 'Codigo de identificacão do Perfil, chave estrangeira para dbscodes.tb_perfil';

ALTER TABLE dbscodes.rl_perfil_grupo ADD CONSTRAINT fk_perfil_perfilgrupo FOREIGN KEY(co_perfil)
	REFERENCES dbscodes.tb_perfil(co_seq_perfil);

ALTER TABLE dbscodes.rl_perfil_grupo ADD CONSTRAINT fk_grupo_perfilgrupo FOREIGN KEY(co_grupo)
	REFERENCES dbscodes.tb_grupo(co_seq_grupo);

--------------------------------------------------------
--  DDL for Table rl_perfil_usuario
--------------------------------------------------------

CREATE TABLE dbscodes.rl_perfil_usuario
(	
	co_usuario bigint NOT NULL, 
	co_perfil bigint NOT NULL,
	CONSTRAINT pk_perfilusuario PRIMARY KEY(co_usuario, co_perfil)
);

COMMENT ON TABLE dbscodes.rl_perfil_usuario IS 'Tabela de relacionamento entre usuários e perfis.';
COMMENT ON COLUMN dbscodes.rl_perfil_usuario.co_usuario IS 'Codigo de identificacão do Usuario, chave estrangeira para dbscodes.tb_usuario';
COMMENT ON COLUMN dbscodes.rl_perfil_usuario.co_perfil IS 'Codigo de identificacão do Perfil, chave estrangeira para dbscodes.tb_perfil';


ALTER TABLE dbscodes.rl_perfil_usuario ADD CONSTRAINT fk_perfil_perfilusuario FOREIGN KEY(co_perfil)
	REFERENCES dbscodes.tb_perfil(co_seq_perfil);

ALTER TABLE dbscodes.rl_perfil_usuario ADD CONSTRAINT fk_usuario_perfilusuario FOREIGN KEY(co_usuario)
	REFERENCES dbscodes.tb_usuario(co_seq_usuario);
