--------------------------------------------------------
--  DDL for Table tb_feriado
--------------------------------------------------------

DROP TABLE IF EXISTS dbscodes.tb_feriado;

CREATE SEQUENCE dbscodes.sq_feriado_coseqferiado;

CREATE TABLE dbscodes.tb_feriado
(
  co_seq_feriado          BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_feriado_coseqferiado'::REGCLASS),
  dt_data_feriado         DATE NOT NULL,
  no_dia_semana           CHARACTER VARYING(45) NOT NULL,
  ds_descricao            CHARACTER VARYING(250) NOT NULL,
  tp_feriado              CHARACTER VARYING(1) NOT NULL,
  co_uf                   CHARACTER VARYING(2) NOT NULL,
  co_unidade_dispensadora BIGINT,
  CONSTRAINT ck_feriado_tpferiado CHECK (tp_feriado::text = 'E'::text OR tp_feriado::text = 'F'::text OR tp_feriado::text = 'M'::text),
  CONSTRAINT pk_feriado PRIMARY KEY (co_seq_feriado)
);

COMMENT ON TABLE  dbscodes.tb_feriado
  IS 'Registros dos feriados';
COMMENT ON COLUMN dbscodes.tb_feriado.co_seq_feriado
	IS 'Codigo de identificacão do feriado, gerado pela sequence: dbscodes.sq_feriado_coseqferiado';
COMMENT ON COLUMN  dbscodes.tb_feriado.dt_data_feriado
	IS 'Data do Feriado do feriado';
COMMENT ON COLUMN  dbscodes.tb_feriado.no_dia_semana
	IS 'Dia da Semana do feriado';
COMMENT ON COLUMN  dbscodes.tb_feriado.ds_descricao
	IS 'Descrição do feriado';
COMMENT ON COLUMN  dbscodes.tb_feriado.tp_feriado
	IS 'Tipo do feriado, onde E = Estadual, F = Federal e  M = Municipal';
COMMENT ON COLUMN  dbscodes.tb_feriado.co_uf
	IS 'Chave estrangeira para a tabela dbscodes.tb_uf';
COMMENT ON COLUMN  dbscodes.tb_feriado.co_unidade_dispensadora
	IS 'Chave estrangeira para a tabela dbscodes.tb_unidade_dispensadora';

--------------------------------------------------------
--  Constraints for Table tb_feriado
--------------------------------------------------------

ALTER TABLE dbscodes.tb_feriado ADD CONSTRAINT fk_unidadedispensadora_feriado FOREIGN KEY(co_unidade_dispensadora)
    REFERENCES dbscodes.tb_unidade_dispensadora(co_seq_unidade_dispensadora);

ALTER TABLE dbscodes.tb_feriado ADD CONSTRAINT fk_uf_feriado FOREIGN KEY(co_uf)
    REFERENCES dbscodes.tb_uf(sg_uf);
