
--Criação tabela demanda

CREATE SEQUENCE dbscodes.sq_demanda_coseqdemanda;
CREATE TABLE dbscodes.tb_demanda
(
   co_seq_demanda BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_demanda_coseqdemanda'::regclass) CONSTRAINT pk_demanda PRIMARY KEY,
   dt_entrada TIMESTAMP NOT NULL,
   dt_inclusao TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   nu_protocolo CHARACTER VARYING(50) NOT NULL,
   nu_processo CHARACTER VARYING(50),
   nu_senha_processo CHARACTER VARYING(100),
   co_relatorio_tecnico BIGINT,
   co_tipo_demanda BIGINT NOT NULL CONSTRAINT fk_tipodemanda_demanda REFERENCES dbscodes.tb_tipo_demanda(co_seq_tipo_demanda),
   co_unidade_organizacional BIGINT NOT NULL CONSTRAINT fk_unidadeorg_demanda REFERENCES dbscodes.tb_unidade_organizacional(co_seq_unidade_organizacional),
   tp_processo CHARACTER VARYING(1) NOT NULL,
   co_cidade BIGINT CONSTRAINT fk_cidade_demanda REFERENCES dbscodes.tb_cidade(co_seq_cidade),
   CONSTRAINT ck_demanda_tpprocesso CHECK (tp_processo::text = 'I'::text OR tp_processo::text = 'C'::text)
);

---ajustado nome do indice
CREATE UNIQUE INDEX in_demanada_protprocecounidorg ON dbscodes.tb_demanda
(
  nu_protocolo,
  nu_processo,
  co_unidade_organizacional
);

COMMENT ON TABLE dbscodes.tb_demanda IS 'Registros de demandas';
COMMENT ON COLUMN dbscodes.tb_demanda.co_seq_demanda IS 'Codigo de identificacão da demanda, gerado pela sequence: dbscodes.sq_demanda_coseqdemanda';
COMMENT ON COLUMN dbscodes.tb_demanda.dt_entrada IS 'Data de entrada da demanda';
COMMENT ON COLUMN dbscodes.tb_demanda.dt_inclusao IS 'Data de inclusão da demanada';
COMMENT ON COLUMN dbscodes.tb_demanda.nu_protocolo IS 'Número protocolo da demanda';
COMMENT ON COLUMN dbscodes.tb_demanda.nu_processo IS 'Número do processo da demanda';
COMMENT ON COLUMN dbscodes.tb_demanda.nu_senha_processo IS 'Senha da demanda';
COMMENT ON COLUMN dbscodes.tb_demanda.tp_processo IS 'Número do Tipo do Processo';
COMMENT ON COLUMN dbscodes.tb_demanda.co_tipo_demanda IS 'Codigo de identificacão do tipo tipo da demanda, chave estrangeira para dbscodes.tb_tipo_demanda';
COMMENT ON COLUMN dbscodes.tb_demanda.tp_processo IS 'Informa o tipo do processo, onde I = Individual C = Coletivo';
COMMENT ON COLUMN dbscodes.tb_demanda.co_unidade_organizacional IS 'Codigo de identificacão da unidade organizacional da demanda, chave estrangeira para dbscodes.tb_unidade_organizacional';
COMMENT ON COLUMN dbscodes.tb_demanda.co_cidade IS 'Código de identificacão cidade, chave estrangeira para dbscodes.tb_cidade';
COMMENT ON COLUMN dbscodes.tb_demanda.tp_acao_contra IS '
 E = Estado
 M = Município
 EM = Estado + Município
 UEM = Estado + Município + União
 UE = Estado + União
 UM = Município + União';

--Criação tabela autor

CREATE SEQUENCE dbscodes.sq_autor_coseqautor;
CREATE TABLE dbscodes.tb_autor
(
   co_seq_autor BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_autor_coseqautor'::regclass) CONSTRAINT pk_autor PRIMARY KEY,
   no_nome  CHARACTER VARYING(80) NOT NULL,
   dt_nascimento DATE NOT NULL DEFAULT CURRENT_DATE,
   tp_sexo  CHARACTER VARYING(1) NOT NULL,
   nu_rg  CHARACTER VARYING(16),
   nu_cpf  CHARACTER VARYING(15),
   nu_cns  CHARACTER VARYING(20),
   ds_mae  CHARACTER VARYING(80),
   nu_telefone  CHARACTER VARYING(20),
   ds_obs_outro_telefone  CHARACTER VARYING(100),
   nu_outro_telefone  CHARACTER VARYING(20),
   ds_email  CHARACTER VARYING(80),
   ds_obs_telefone  CHARACTER VARYING(100),
   nu_cep  CHARACTER VARYING(9),
   ds_bairro character varying(60),
   ds_logradouro  CHARACTER VARYING(100),
   nu_numero CHARACTER VARYING(5),
   ds_complemento  CHARACTER VARYING(30),
   co_cidade BIGINT CONSTRAINT fk_cidade_autordemanda REFERENCES dbscodes.tb_cidade(co_seq_cidade),
   CONSTRAINT ck_autor_tpsexo CHECK (tp_sexo::text = 'M'::text OR tp_sexo::text = 'F'::text OR tp_sexo::text = 'O'::text)
);

COMMENT ON TABLE dbscodes.tb_autor IS 'Registros de autores';
COMMENT ON COLUMN dbscodes.tb_autor.co_seq_autor IS 'Codigo de identificacão do autor, gerado pela sequence: dbscodes.sq_autor_coseqautor';
COMMENT ON COLUMN dbscodes.tb_autor.dt_nascimento IS 'Data de nascimento do autor';
COMMENT ON COLUMN dbscodes.tb_autor.no_nome IS 'Nome do autor';
COMMENT ON COLUMN dbscodes.tb_autor.nu_rg IS 'Número do Registro Geral do autor';
COMMENT ON COLUMN dbscodes.tb_autor.nu_cpf IS 'Número do Código Pessoa Física do autor';
COMMENT ON COLUMN dbscodes.tb_autor.nu_cns IS 'Número do Cartão Nacional de Saúde';
COMMENT ON COLUMN dbscodes.tb_autor.ds_mae IS 'Nome da Mãe do autor';
COMMENT ON COLUMN dbscodes.tb_autor.nu_telefone IS 'Número de telefone';
COMMENT ON COLUMN dbscodes.tb_autor.ds_obs_telefone IS 'Observação sobre o número de telefone';
COMMENT ON COLUMN dbscodes.tb_autor.nu_outro_telefone IS 'Número de outro número de telefone';
COMMENT ON COLUMN dbscodes.tb_autor.ds_obs_outro_telefone IS 'Observação sobre outro número de telefone';
COMMENT ON COLUMN dbscodes.tb_autor.ds_email IS 'E-mail para contato';
COMMENT ON COLUMN dbscodes.tb_autor.nu_cep IS 'CEP para localização';
COMMENT ON COLUMN dbscodes.tb_autor.ds_bairro IS 'CEP para localização';
COMMENT ON COLUMN dbscodes.tb_autor.ds_logradouro IS 'Logradouro para localização';
COMMENT ON COLUMN dbscodes.tb_autor.nu_numero IS 'Número para localização';
COMMENT ON COLUMN dbscodes.tb_autor.ds_complemento IS 'Complemento da localização';
COMMENT ON COLUMN dbscodes.tb_autor.tp_sexo IS 'Informa o tipo de sexo, M = Masculino, F = Feminino e O = Outros';
COMMENT ON COLUMN dbscodes.tb_autor.co_cidade IS 'Código de identificacão cidade, chave estrangeira para dbscodes.tb_cidade';


--Criação tabela status

CREATE SEQUENCE dbscodes.sq_status_coseqstatus;
CREATE TABLE dbscodes.tb_status
(
   co_seq_status BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_status_coseqstatus'::regclass) CONSTRAINT pk_status PRIMARY KEY,
   ds_descricao  CHARACTER VARYING(80) ,
   nu_ordem BIGINT,
   nu_classificacao BIGINT
);

COMMENT ON TABLE dbscodes.tb_status IS 'Registros dos status';
COMMENT ON COLUMN dbscodes.tb_status.co_seq_status IS 'Codigo de identificacão do status, gerado pela sequence: dbscodes.sq_status_coseqstatus';
COMMENT ON COLUMN dbscodes.tb_status.ds_descricao IS 'Descrição do status';
COMMENT ON COLUMN dbscodes.tb_status.nu_ordem IS 'Ordem do status';
COMMENT ON COLUMN dbscodes.tb_status.nu_classificacao IS 'classificação do status';

-------------------------------------------------------
--  DML for tb_status
-------------------------------------------------------

INSERT INTO dbscodes.tb_status (co_seq_status, ds_descricao, nu_ordem, nu_classificacao) VALUES
(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Autor incluído',1,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Aguardando Documentação',2,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Determinação Incluída',3,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Avaliação Técnica Incluída',5,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Aguardando Decisão Judicial',4,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Ordem de Dispensação Incluída',7,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Aguardando Fornecimento',8,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Demanda em Atendimento',9,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - OD Sem Dispensação',10,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Suspensão Temporária',12,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Suspensão Definitiva',13,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Integralmente Atendida',14,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Fornecimento Não Autorizado',6,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Ativa - Orientar Migração',17,1)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Migrado Programa',18,0)
,(nextval('dbscodes.sq_status_coseqstatus'),'Demanda Inativa - Atendimento em local de origem prescrição',19,0);

--Criação tabela autor_demanda

CREATE SEQUENCE dbscodes.sq_autordemanda_coseqautordemanda;
CREATE TABLE dbscodes.tb_autor_demanda
(
   co_seq_autor_demanda BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_autordemanda_coseqautordemanda'::regclass) CONSTRAINT pk_autordemanda PRIMARY KEY,
   dt_entrada TIMESTAMP NOT NULL,
   st_atendido boolean NOT NULL DEFAULT false,
   st_cobranca_judicial boolean NOT NULL DEFAULT false,
   co_autor BIGINT NOT NULL CONSTRAINT fk_autor_autordemanda REFERENCES dbscodes.tb_autor(co_seq_autor),
   co_demanda BIGINT NOT NULL CONSTRAINT fk_demanda_autordemanda REFERENCES dbscodes.tb_demanda(co_seq_demanda),
   co_status BIGINT CONSTRAINT fk_status_autordemanda REFERENCES dbscodes.tb_status(co_seq_status)
);

COMMENT ON TABLE dbscodes.tb_autor_demanda IS 'Registros de autores com demandas';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.co_seq_autor_demanda IS 'Codigo de identificacão dos autores da demanda, gerado pela sequence: dbscodes.sq_autordemanda_coseqautordemanda';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.dt_entrada IS 'Data de entrada';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.st_cobranca_judicial IS 'Verificação se houve cobrança judicial, onde Sim = TRUE, Não = false';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.co_autor IS 'Codigo de identificacão do autor, gerado pela sequence: dbscodes.sq_autor_coseqautor';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.co_demanda IS 'Data de entrada da demanda';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.co_status IS 'Código de identificacão do status da demanda, chave estrangeira para dbscodes.tb_status';
COMMENT ON COLUMN dbscodes.tb_autor_demanda.st_atendido IS 'Verifica se foi atendido ou não, onde , onde Sim = TRUE, Não = false';

--Criação relacionamento autores e autor demanda

CREATE TABLE dbscodes.rl_autor_autor_demanda
(
   co_autor_demanda BIGINT NOT NULL CONSTRAINT fk_autordemanda_autorautordemanda REFERENCES dbscodes.tb_autor_demanda(co_seq_autor_demanda),
   co_autor BIGINT NOT NULL CONSTRAINT fk_autor_autorautordemanda REFERENCES dbscodes.tb_autor(co_seq_autor),
   CONSTRAINT pk_autorautordemanda PRIMARY KEY (co_autor_demanda,co_autor)
);

COMMENT ON TABLE dbscodes.rl_autor_autor_demanda IS 'Tabela de relacionamento entre as tabelas tb_autor_demanda e tb_autor';
COMMENT ON COLUMN dbscodes.rl_autor_autor_demanda.co_autor_demanda IS 'Codigo de identificacão do autore da demanda, FK da tabela tb_autor_demanda';
COMMENT ON COLUMN dbscodes.rl_autor_autor_demanda.co_autor IS 'Codigo de identificacão dos autores, FK da tabela co_autor';


 --Criação tabela relatório técnico

CREATE SEQUENCE dbscodes.sq_relatoriotecnico_coseqreltecnico;
CREATE TABLE dbscodes.tb_relatorio_tecnico
(
   co_seq_relatorio_tecnico BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_relatoriotecnico_coseqreltecnico'::regclass) CONSTRAINT pk_relatoriotecnico PRIMARY KEY,
   ds_permanente CHARACTER VARYING(500),
   ds_provisorio CHARACTER VARYING(500),
   nu_pagina BIGINT,
   co_autor_demanda BIGINT NOT NULL CONSTRAINT fk_autordemanda_relatotecnico REFERENCES dbscodes.tb_autor_demanda(co_seq_autor_demanda)
);

COMMENT ON TABLE dbscodes.tb_relatorio_tecnico IS 'Registros de relatorios';
COMMENT ON COLUMN dbscodes.tb_relatorio_tecnico.co_seq_relatorio_tecnico IS 'Codigo de identificacão do relatorio tecnico, gerado pela sequence: dbscodes.sq_relatoriotecnico_coseqreltecnico';
COMMENT ON COLUMN dbscodes.tb_relatorio_tecnico.ds_permanente IS 'Descrição permanente';
COMMENT ON COLUMN dbscodes.tb_relatorio_tecnico.ds_provisorio IS 'Descrição provisoria';
COMMENT ON COLUMN dbscodes.tb_relatorio_tecnico.nu_pagina IS 'Número de paginas';
COMMENT ON COLUMN dbscodes.tb_relatorio_tecnico.co_autor_demanda IS 'Codigo de identificacão do autor, chave estrangeira para dbscodes.tb_autor_demanda';

ALTER TABLE dbscodes.tb_demanda ADD CONSTRAINT fk_relatoriotecnico_demanda  FOREIGN KEY (co_relatorio_tecnico)
REFERENCES dbscodes.tb_relatorio_tecnico(co_seq_relatorio_tecnico);

--Criação tabela pessoa
CREATE SEQUENCE dbscodes.sq_pessoa_coseqpessoa;
CREATE TABLE dbscodes.tb_pessoa
(
   co_seq_pessoa BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_pessoa_coseqpessoa'::regclass) CONSTRAINT pk_pessoa PRIMARY KEY,
   no_nome CHARACTER VARYING(80) NOT NULL,
   tp_sexo CHARACTER VARYING(1) NOT NULL,
   nu_rg CHARACTER VARYING(16),
   nu_cpf CHARACTER VARYING(15),
   nu_telefone  CHARACTER VARYING(20),
   nu_outro_telefone  CHARACTER VARYING(20),
   ds_relacao_autor CHARACTER VARYING(50),
   st_ativo boolean NOT NULL DEFAULT false,
   co_autor_demanda BIGINT NOT NULL CONSTRAINT fk_autor_demanda REFERENCES dbscodes.tb_autor_demanda(co_seq_autor_demanda),
   CONSTRAINT ck_pessoa_tpsexo CHECK (tp_sexo::text = 'M'::text OR tp_sexo::text = 'F'::text OR tp_sexo::text = 'O'::text)
);

COMMENT ON TABLE dbscodes.tb_pessoa IS 'Registros de pessoas';
COMMENT ON COLUMN dbscodes.tb_pessoa.co_seq_pessoa IS 'Codigo de identificacão do pessoa, gerado pela sequence: dbscodes.sq_pessoa_coseqpessoa';
COMMENT ON COLUMN dbscodes.tb_pessoa.no_nome IS 'Nome do pessoa';
COMMENT ON COLUMN dbscodes.tb_pessoa.tp_sexo IS 'Informa o tipo de sexo, M = Masculino, F = Feminino e O = Outros';
COMMENT ON COLUMN dbscodes.tb_pessoa.nu_rg IS 'Número do Registro Geral do pessoa';
COMMENT ON COLUMN dbscodes.tb_pessoa.nu_cpf IS 'Número do Código Pessoa Física do pessoa';
COMMENT ON COLUMN dbscodes.tb_pessoa.nu_telefone IS 'Número de telefone';
COMMENT ON COLUMN dbscodes.tb_pessoa.nu_outro_telefone IS 'Número de outro número de telefone';
COMMENT ON COLUMN dbscodes.tb_pessoa.ds_relacao_autor IS 'Descrição da relação do autor';
COMMENT ON COLUMN dbscodes.tb_pessoa.st_ativo IS 'Situação se a pessoa está ativo, False - inativo e True - ativo';
COMMENT ON COLUMN dbscodes.tb_pessoa.co_autor_demanda IS 'Codigo de identificacão do autor, chave estrangeira para dbscodes.tb_autor_demanda';

--Criação tabela diretorio
CREATE SEQUENCE dbscodes.sq_diretorio_coseqdiretorio;

CREATE TABLE dbscodes.tb_diretorio
(
   co_seq_diretorio BIGINT  NOT NULL DEFAULT nextval('dbscodes.sq_diretorio_coseqdiretorio'::regclass) constraint pk_diretorio PRIMARY KEY,
   ds_descricao CHARACTER VARYING(80)
);

COMMENT ON TABLE dbscodes.tb_diretorio IS 'Registros de diretorios';
COMMENT ON COLUMN dbscodes.tb_diretorio.diretorio.co_seq_diretorio IS 'Codigo de identificacão do diretorio, gerado pela sequence: dbscodes.sq_diretorio_coseqdiretorio';
COMMENT ON COLUMN dbscodes.tb_diretorio.ds_descricao IS 'Descrição';

--Criação tabela arquivo

CREATE SEQUENCE dbscodes.sq_arquivo_coseqarquivo;
CREATE TABLE dbscodes.tb_arquivo
(
   co_seq_arquivo BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_arquivo_coseqarquivo'::regclass) CONSTRAINT pk_arquivo PRIMARY KEY,
   ds_descricao CHARACTER VARYING(80),
   ds_extensao CHARACTER VARYING(80),
   dt_inclusao TIMESTAMP,
   dt_protocolo TIMESTAMP,
   ar_arquivo BYTEA,
   co_diretorio BIGINT NOT NULL CONSTRAINT fk_diretorio REFERENCES dbscodes.tb_diretorio(co_seq_diretorio),
   co_autor_demanda BIGINT NOT NULL CONSTRAINT fk_autor_demanda REFERENCES dbscodes.tb_autor_demanda(co_seq_autor_demanda)
);

COMMENT ON TABLE dbscodes.tb_arquivo IS 'Registros de arquivos';
COMMENT ON COLUMN dbscodes.tb_arquivo.co_seq_arquivo IS 'Codigo de identificacão de arquivos, gerado pela sequence: dbscodes.sq_arquivo_coseqarquivo';
COMMENT ON COLUMN dbscodes.tb_arquivo.ds_descricao IS 'Descrição';
COMMENT ON COLUMN dbscodes.tb_arquivo.ds_extensao IS 'Extensão';
COMMENT ON COLUMN dbscodes.tb_arquivo.dt_inclusao IS 'Data de inclusão';
COMMENT ON COLUMN dbscodes.tb_arquivo.dt_protocolo IS 'Data do protocolo';
COMMENT ON COLUMN dbscodes.tb_arquivo.co_diretorio IS 'Código do diretório';
COMMENT ON COLUMN dbscodes.tb_arquivo.co_autor_demanda IS 'Código do autor da demanda';
