--------------------------------------------------------
--  DDL FOR TABLE TB_ORDEM_DISPENSACAO
--------------------------------------------------------

DROP TABLE IF EXISTS DBSCODES.TB_ORDEM_DISPENSACAO CASCADE;

DROP SEQUENCE IF EXISTS DBSCODES.SQ_ORDEM_DISPENSACAO_COSEQORDDISP;

CREATE SEQUENCE DBSCODES.SQ_ORDEMDISP_COSQORDDISP;

CREATE TABLE DBSCODES.TB_ORDEM_DISPENSACAO
(
  CO_SEQ_ORDEM_DISPENSACAO BIGINT NOT NULL DEFAULT NEXTVAL('DBSCODES.SQ_ORDEMDISP_COSQORDDISP'::REGCLASS),
  DS_OBSERVACAO CHARACTER VARYING(1000),
  DT_DATA_FALTA_ESTOQUE DATE,
  CO_AUTOR_DEMANDA BIGINT NOT NULL,
  CO_UNIDADE_DISPENSADORA BIGINT NOT NULL,
  CONSTRAINT PK_ORDEMDISPENSACAO PRIMARY KEY (CO_SEQ_ORDEM_DISPENSACAO)
);

COMMENT ON TABLE  DBSCODES.TB_ORDEM_DISPENSACAO
	IS 'REGISTROS DAS ORDENS DISPENSACAO';
COMMENT ON COLUMN DBSCODES.TB_ORDEM_DISPENSACAO.CO_SEQ_ORDEM_DISPENSACAO
	IS 'CODIGO DE IDENTIFICACÃO DA ORDEM DISPENSACAO, GERADO PELA SEQUENCE: DBSCODES.SQ_ORDEMDISP_COSQORDDISP';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_DISPENSACAO.DS_OBSERVACAO
	IS 'OBSERVAÇÃO DA ORDEM DISPENSACAO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_DISPENSACAO.DT_DATA_FALTA_ESTOQUE
	IS 'DATA FALTA ESTOQUE DA ORDEM DISPENSACAO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_DISPENSACAO.CO_AUTOR_DEMANDA
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_AUTOR_DEMANDA';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_DISPENSACAO.CO_UNIDADE_DISPENSADORA
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_UNIDADE_DISPENSADORA';

--------------------------------------------------------
--  CONSTRAINTS FOR TABLE TB_ORDEM_DISPENSACAO
--------------------------------------------------------

ALTER TABLE DBSCODES.TB_ORDEM_DISPENSACAO ADD CONSTRAINT FK_AUTORDEMAND_ORDEMDISPENSA FOREIGN KEY(CO_AUTOR_DEMANDA)
    REFERENCES DBSCODES.TB_AUTOR_DEMANDA(CO_SEQ_AUTOR_DEMANDA);

ALTER TABLE DBSCODES.TB_ORDEM_DISPENSACAO ADD CONSTRAINT FK_UNIDDISPENSAD_ORDEMDISPENSA FOREIGN KEY(CO_UNIDADE_DISPENSADORA)
    REFERENCES DBSCODES.TB_UNIDADE_DISPENSADORA(CO_SEQ_UNIDADE_DISPENSADORA);

--------------------------------------------------------
--  DDL FOR TABLE TB_ORDEM_PRODUTO
--------------------------------------------------------

DROP TABLE IF EXISTS DBSCODES.TB_ORDEM_PRODUTO CASCADE;

DROP SEQUENCE IF EXISTS DBSCODES.SQ_ORDEM_PRODUTO_COSEQORDPRO;

CREATE SEQUENCE DBSCODES.SQ_ORDEMPRODUTO_COSEQORDEMPROD;

CREATE TABLE DBSCODES.TB_ORDEM_PRODUTO
(
  CO_SEQ_ORDEM_PRODUTO BIGINT NOT NULL DEFAULT NEXTVAL('DBSCODES.SQ_ORDEMPRODUTO_COSEQORDEMPROD'::REGCLASS),
  DT_DATA_ENTRADA_PRODUTO DATE NOT NULL,
  QT_PRODUTO BIGINT NOT NULL,
  NU_RETORNO BIGINT,
  NU_PRAZO BIGINT,
  NU_PERIODICIDADE BIGINT,
  ST_IRREGULAR CHARACTER VARYING(1) NOT NULL,
  QT_PRAZO BIGINT,
  ST_HABILITA_IMPORTADO CHARACTER VARYING(1),
  ST_ATIVO CHARACTER VARYING(1) NOT NULL,
  DT_DATA_FIM DATE NOT NULL,
  NU_ATIVO_ATUAL BIGINT NOT NULL,
  NU_CONCLUIDO BIGINT NOT NULL,
  CO_ORDEM_DISPENSACAO BIGINT NOT NULL,
  CO_PRODUTO BIGINT NOT NULL,
  CONSTRAINT PK_ORDEMPRODUTO PRIMARY KEY (CO_SEQ_ORDEM_PRODUTO),
  CONSTRAINT CK_ORDEMPRODUTO_STIRREGULAR CHECK (ST_IRREGULAR::TEXT = 'S'::TEXT OR ST_IRREGULAR::TEXT = 'N'::TEXT),
  CONSTRAINT CK_ORDEMPRODUTO_STHABILITAIMPORTADO CHECK (ST_HABILITA_IMPORTADO::TEXT = 'S'::TEXT OR ST_HABILITA_IMPORTADO::TEXT = 'N'::TEXT),
  CONSTRAINT CK_ORDEMPRODUTO_STATIVO CHECK (ST_ATIVO::TEXT = 'A'::TEXT OR ST_ATIVO::TEXT = 'I'::TEXT)
);

COMMENT ON TABLE  DBSCODES.TB_ORDEM_PRODUTO
	IS 'REGISTROS DAS ORDENS PRODUTO';
COMMENT ON COLUMN DBSCODES.TB_ORDEM_PRODUTO.CO_SEQ_ORDEM_PRODUTO
	IS 'CODIGO DE IDENTIFICACÃO DA ORDEM PRODUTO, GERADO PELA SEQUENCE: DBSCODES.SQ_ORDEMPRODUTO_COSEQORDEMPROD';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.DT_DATA_ENTRADA_PRODUTO
	IS 'DATA ENTRADA PRODUTO DA ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.QT_PRODUTO
	IS 'QUANTIDADE DO PRODUTO DA ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.NU_RETORNO
	IS 'RETORNO DA ORDEM PRODUTO, PERIODO EM DIAS PARA RETORNO DE DISPENSACAO DE ITEM IRREGULAR';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.NU_PRAZO
	IS 'PRAZO DA ORDEM PRODUTO, PRAZO DE FORNCECIMENTO 1 - UNICO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.NU_PERIODICIDADE
	IS 'PERIODICIDADE DA ORDEM PRODUTO, PERIODO EM DIAS PARA RETORNO DE DISPENSAC?O DE ITEM REGULAR';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.ST_IRREGULAR
	IS 'IRREGULAR DA ORDEM PRODUTO, ONDE S - SIM E N - NÃO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.QT_PRAZO
	IS 'QUANTIDADE PRAZO DA ORDEM PRODUTO, QUANTIDADE DE PRODUTO EM RELACÃO AO PRAZO DE FORNECIMENTO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.ST_HABILITA_IMPORTADO
	IS 'HABILITA IMPORTADO DA ORDEM PRODUTO, ONDE S - SIM E N - NÃO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.ST_ATIVO
	IS 'ATIVO DA ORDEM PRODUTO, SITUAÇÃO DO PRODUTO QUANDO UM ITEM É EXCLUÍDO DA OD ELE E REGISTRADO COMO INATIVO. A - ATIVO  I - INATIVO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.DT_DATA_FIM
	IS 'DATA FIM DA ORDEM PRODUTO, IDENTIFICA A DATA EM QUE O REGISTRO DO ITEM FOI FINALIZADO PARA A ENTRADA DE UM NOVO REGISTRO. EX: QUANDO OCORRE UMA ALTERACÃO.';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.NU_ATIVO_ATUAL
	IS 'ATIVO ATUAL DA ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.NU_CONCLUIDO
	IS 'CONCLUIDO DA ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.CO_ORDEM_DISPENSACAO
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_ORDEM_DISPENSACAO';
COMMENT ON COLUMN  DBSCODES.TB_ORDEM_PRODUTO.CO_PRODUTO
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_PRODUTO';

--------------------------------------------------------
--  CONSTRAINTS FOR TABLE TB_ORDEM_PRODUTO
--------------------------------------------------------

ALTER TABLE DBSCODES.TB_ORDEM_PRODUTO ADD CONSTRAINT FK_ORDEMDISPENSA_ORDEMPRODUTO FOREIGN KEY(CO_ORDEM_DISPENSACAO)
    REFERENCES DBSCODES.TB_ORDEM_DISPENSACAO(CO_SEQ_ORDEM_DISPENSACAO);

ALTER TABLE DBSCODES.TB_ORDEM_PRODUTO ADD CONSTRAINT FK_PRODUTO_ORDEMPRODUTO FOREIGN KEY(CO_PRODUTO)
    REFERENCES DBSCODES.TB_PRODUTO(CO_SEQ_PRODUTO);

--------------------------------------------------------
--  DDL FOR TABLE TB_RECIBO
--------------------------------------------------------

DROP TABLE IF EXISTS DBSCODES.TB_RECIBO CASCADE;

DROP SEQUENCE IF EXISTS DBSCODES.SQ_RECIBO_COSEQRECIBO;

CREATE SEQUENCE DBSCODES.SQ_RECIBO_COSEQRECIBO;

CREATE TABLE DBSCODES.TB_RECIBO
(
  CO_SEQ_RECIBO BIGINT NOT NULL DEFAULT NEXTVAL('DBSCODES.SQ_RECIBO_COSEQRECIBO'::REGCLASS),
  DT_DATA_ENTREGA DATE,
  DS_OBSERVACAO CHARACTER VARYING(1000),
  ST_SITUACAO CHARACTER VARYING(1) DEFAULT 'V' NOT NULL,
  DT_DATA_INVALIDAR DATE,
  CO_PESSOA BIGINT,
  CO_EVENTO BIGINT,
  CO_USUARIO_INVALIDAR BIGINT,
  CONSTRAINT PK_RECIBO PRIMARY KEY (CO_SEQ_RECIBO),
  CONSTRAINT CK_RECIBO_STSITUACAO CHECK (ST_SITUACAO::TEXT = 'V'::TEXT OR ST_SITUACAO::TEXT = 'I'::TEXT)
);

COMMENT ON TABLE  DBSCODES.TB_RECIBO
	IS 'REGISTROS DOS RECIBOS';
COMMENT ON COLUMN DBSCODES.TB_RECIBO.CO_SEQ_RECIBO
	IS 'CODIGO DE IDENTIFICACÃO DA ORDEM DISPENSACAO, GERADO PELA SEQUENCE: DBSCODES.SQ_RECIBO_COSEQRECIBO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.DT_DATA_ENTREGA
	IS 'DATA ENTREGA DO RECIBO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.DS_OBSERVACAO
	IS 'OBSERVAÇÃO DO RECIBO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.ST_SITUACAO
	IS 'SITUAÇÃO DO RECIBO, ONDE V - VALIDO  E I - INVALIDO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.DT_DATA_INVALIDAR
	IS 'DATA INVALIDAR DO RECIBO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.CO_PESSOA
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_PESSOA';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.CO_EVENTO
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_EVENTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO.CO_USUARIO_INVALIDAR
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_USUARIO';

--------------------------------------------------------
--  CONSTRAINTS FOR TABLE TB_RECIBO
--------------------------------------------------------

ALTER TABLE DBSCODES.TB_RECIBO ADD CONSTRAINT FK_PESSOA_RECIBO FOREIGN KEY(CO_PESSOA)
    REFERENCES DBSCODES.TB_PESSOA(CO_SEQ_PESSOA);

ALTER TABLE DBSCODES.TB_RECIBO ADD CONSTRAINT FK_EVENTO_RECIBO FOREIGN KEY(CO_EVENTO)
    REFERENCES DBSCODES.TB_EVENTO(CO_SEQ_EVENTO);

ALTER TABLE DBSCODES.TB_RECIBO ADD CONSTRAINT FK_USUARIO_RECIBO FOREIGN KEY(CO_USUARIO_INVALIDAR)
    REFERENCES DBSCODES.TB_USUARIO(CO_SEQ_USUARIO);

--------------------------------------------------------
--  DDL FOR TABLE TB_MOTIVO
--------------------------------------------------------

DROP TABLE IF EXISTS DBSCODES.TB_MOTIVO CASCADE;

DROP SEQUENCE IF EXISTS DBSCODES.SQ_MOTIVO_COSEQMOTIVO;

CREATE SEQUENCE DBSCODES.SQ_MOTIVO_COSEQMOTIVO;

CREATE TABLE DBSCODES.TB_MOTIVO
(
  CO_SEQ_MOTIVO BIGINT NOT NULL DEFAULT NEXTVAL('DBSCODES.SQ_MOTIVO_COSEQMOTIVO'::REGCLASS),
  DS_DESCRICAO CHARACTER VARYING(50),
  TP_MOTIVO CHARACTER VARYING(1),
  CONSTRAINT PK_MOTIVO PRIMARY KEY (CO_SEQ_MOTIVO),
  CONSTRAINT CK_MOTIVO_TPMOTIVO CHECK (TP_MOTIVO::TEXT = 'E'::TEXT OR TP_MOTIVO::TEXT = 'R'::TEXT)
);

COMMENT ON TABLE  DBSCODES.TB_MOTIVO
	IS 'REGISTROS DOS MOTIVOS';
COMMENT ON COLUMN DBSCODES.TB_MOTIVO.CO_SEQ_MOTIVO
	IS 'CODIGO DE IDENTIFICACÃO DO MOTIVO, GERADO PELA SEQUENCE: DBSCODES.SQ_MOTIVO_COSEQMOTIVO';
COMMENT ON COLUMN  DBSCODES.TB_MOTIVO.DS_DESCRICAO
	IS 'DESCRIÇÃO DO MOTIVO';
COMMENT ON COLUMN  DBSCODES.TB_MOTIVO.TP_MOTIVO
	IS 'TIPO DO MOTIVO, ONDE E = ? E R = ?';

--------------------------------------------------------
--  DDL FOR TABLE TB_RECIBO_ORDEM_PRODUTO
--------------------------------------------------------

DROP TABLE IF EXISTS DBSCODES.TB_RECIBO_ORDEM_PRODUTO CASCADE;

DROP SEQUENCE IF EXISTS DBSCODES.SQ_RECORDPRO_COSEQRECORDPRO;

CREATE SEQUENCE DBSCODES.SQ_RECORDPRO_COSEQRECORDPRO;

CREATE TABLE DBSCODES.TB_RECIBO_ORDEM_PRODUTO
(
  CO_SEQ_RECIBO_ORDEM_PRODUTO BIGINT NOT NULL DEFAULT NEXTVAL('DBSCODES.SQ_RECORDPRO_COSEQRECORDPRO'::REGCLASS),
  NU_DISPENSADO BIGINT,
  NU_HAVER BIGINT,
  DT_DATA_RETORNO DATE,
  ST_SITUACAO CHARACTER VARYING(1) DEFAULT 'N' NOT NULL,
  NU_CUSTO BIGINT,
  ST_ATIVO CHARACTER VARYING(1) DEFAULT 'S' NOT NULL,
  NU_DIAS_ADIADOS BIGINT,
  DT_DATA_CONCLUSAO DATE,
  CO_ORDEM_PRODUTO BIGINT NOT NULL,
  CO_RECIBO BIGINT NOT NULL,
  CO_MOTIVO BIGINT NOT NULL,
  CO_CONTA_DISP BIGINT,
  CONSTRAINT PK_RECIBOORDEMPRODUTO PRIMARY KEY (CO_SEQ_RECIBO_ORDEM_PRODUTO),
  CONSTRAINT CK_RECIBOORDEMPRODUTO_STSITUACAO CHECK (ST_SITUACAO::TEXT = 'N'::TEXT OR ST_SITUACAO::TEXT = 'A'::TEXT OR ST_SITUACAO::TEXT = 'C'::TEXT),
  CONSTRAINT CK_RECIBOORDEMPRODUTO_STATIVO CHECK (ST_ATIVO::TEXT = 'N'::TEXT OR ST_ATIVO::TEXT = 'A'::TEXT)
);

COMMENT ON TABLE  DBSCODES.TB_RECIBO_ORDEM_PRODUTO
	IS 'REGISTROS DOS RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN DBSCODES.TB_RECIBO_ORDEM_PRODUTO.CO_SEQ_RECIBO_ORDEM_PRODUTO
	IS 'CODIGO DE IDENTIFICACÃO DO MOTIVO, GERADO PELA SEQUENCE: DBSCODES.SQ_RECORDPRO_COSEQRECORDPRO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.NU_DISPENSADO
	IS 'DISPENSADO DO RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.NU_HAVER
	IS 'HAVER DO RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.DT_DATA_RETORNO
	IS 'DATA RETORNO DO RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.ST_SITUACAO
	IS 'SITUAÇÃO DO RECIBO ORDEM PRODUTO, ONDE N - NOVO, A - ANDAMENTO C - CONCLUIDO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.NU_CUSTO
	IS 'CUSTO DO RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.ST_ATIVO
	IS 'ATIVO DO RECIBO ORDEM PRODUTO, ONDE S - SIM E N = NÃO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.NU_DIAS_ADIADOS
  IS 'DIAS ADIADOS DO RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.DT_DATA_CONCLUSAO
  IS 'DATA CONCLUSÃO DO RECIBO ORDEM PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.CO_ORDEM_PRODUTO
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_ORDEM_PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.CO_RECIBO
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_RECIBO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.CO_MOTIVO
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_MOTIVO';
COMMENT ON COLUMN  DBSCODES.TB_RECIBO_ORDEM_PRODUTO.CO_CONTA_DISP
	IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_RECIBO_ORDEM_PRODUTO';

--------------------------------------------------------
--  CONSTRAINTS FOR TABLE TB_RECIBO_ORDEM_PRODUTO
--------------------------------------------------------

ALTER TABLE DBSCODES.TB_RECIBO_ORDEM_PRODUTO ADD CONSTRAINT FK_ORDPROD_RECIBOORDEMPRODUTO FOREIGN KEY(CO_ORDEM_PRODUTO)
    REFERENCES DBSCODES.TB_ORDEM_PRODUTO(CO_SEQ_ORDEM_PRODUTO);

ALTER TABLE DBSCODES.TB_RECIBO_ORDEM_PRODUTO ADD CONSTRAINT FK_RECIBO_RECIBOORDEMPRODUTO FOREIGN KEY(CO_RECIBO)
    REFERENCES DBSCODES.TB_RECIBO(CO_SEQ_RECIBO);

ALTER TABLE DBSCODES.TB_RECIBO_ORDEM_PRODUTO ADD CONSTRAINT FK_MOTIVO_RECIBOORDEMPRODUTO FOREIGN KEY(CO_MOTIVO)
    REFERENCES DBSCODES.TB_MOTIVO(CO_SEQ_MOTIVO);

ALTER TABLE DBSCODES.TB_RECIBO_ORDEM_PRODUTO ADD CONSTRAINT FK_RECORDPROD_RECIBOORDEMPRODUTO FOREIGN KEY(CO_CONTA_DISP)
    REFERENCES DBSCODES.TB_RECIBO_ORDEM_PRODUTO(CO_SEQ_RECIBO_ORDEM_PRODUTO);

--------------------------------------------------------
--  DDL FOR TABLE TB_ALTERACAO_DATA_RETORNO_PRODUTO
--------------------------------------------------------

DROP TABLE IF EXISTS DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO CASCADE;

DROP SEQUENCE IF EXISTS DBSCODES.SQ_ALTDTRETPROD_COSEQALTDTRETPROD;

CREATE SEQUENCE DBSCODES.SQ_ALTDTRETPROD_COSQALTDTRETPROD;

CREATE TABLE DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO
(
	CO_SEQ_ALT_DT_RETORNO_PRODUTO BIGINT NOT NULL DEFAULT NEXTVAL('DBSCODES.SQ_ALTDTRETPROD_COSQALTDTRETPROD'::REGCLASS),
	DT_RETORNO_ANTERIOR DATE,
	CO_RECIBO_ORDEM_PRODUTO BIGINT,
	CO_ALTERACAO_DATA_RETORNO BIGINT,
	CONSTRAINT PK_ALTERACAODATARETORNOPRODUTO PRIMARY KEY (CO_SEQ_ALT_DT_RETORNO_PRODUTO)
);

COMMENT ON TABLE  DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO
	IS 'REGISTROS DA ALTERAÇÃO DE DATA DE RETORNO PRODUTO';
COMMENT ON COLUMN DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO.CO_SEQ_ALT_DT_RETORNO_PRODUTO
	IS 'CODIGO DE IDENTIFICACÃO DA ALTERAÇÃO DE DATA DE RETORNO PRODUTO, GERADO PELA SEQUENCE: DBSCODES.SQ_ALTDTRETPROD_COSQALTDTRETPROD';
COMMENT ON COLUMN  DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO.DT_RETORNO_ANTERIOR
  IS 'DATA DE RETORNO ANTERIOR DA ALTERAÇÃO DE DATA DE RETORNO PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO.CO_RECIBO_ORDEM_PRODUTO
	IS 'CÓDIGO DO RECIDO DA ORDEM DE PRODUTO DA ALTERAÇÃO DE DATA DE RETORNO PRODUTO';
COMMENT ON COLUMN  DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO.CO_ALTERACAO_DATA_RETORNO
  IS 'CHAVE ESTRANGEIRA PARA A TABELA DBSCODES.TB_ALTERACAO_DATA_RETORNO';

---------------------------------------------------------------
--  CONSTRAINTS FOR TABLE TB_ALTERACAO_DATA_RETORNO_PRODUTO
---------------------------------------------------------------

ALTER TABLE DBSCODES.TB_ALTERACAO_DATA_RETORNO_PRODUTO ADD CONSTRAINT FK_ALTERADTRET_ALTERADTRETPROD FOREIGN KEY(CO_ALTERACAO_DATA_RETORNO)
    REFERENCES DBSCODES.TB_ALTERACAO_DATA_RETORNO(CO_SEQ_ALTERACAO_DATA_RETORNO);
