--Criação tabela tipo vara

CREATE SEQUENCE dbscodes.sq_tipovara_coseqtipovara;
CREATE TABLE dbscodes.tb_tipo_vara
(
   co_seq_tipo_vara BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_tipovara_coseqtipovara'::regclass) CONSTRAINT pk_tipovara PRIMARY KEY,
   ds_descricao CHARACTER VARYING(80) NOT NULL
);

COMMENT ON TABLE dbscodes.tb_tipo_vara IS 'Registros de tipo varas';
COMMENT ON COLUMN dbscodes.tb_tipo_vara.co_seq_tipo_vara IS 'Codigo de identificacão da tipo vara, gerado pela sequence: dbscodes.sq_tipovara_coseqtipovara';
COMMENT ON COLUMN dbscodes.tb_tipo_vara.ds_descricao IS 'Descrição';
 
--Criação tabela vara

CREATE SEQUENCE dbscodes.sq_vara_coseqvara;
CREATE TABLE dbscodes.tb_vara
(
   co_seq_vara BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_vara_coseqvara'::regclass) CONSTRAINT pk_vara PRIMARY KEY,
   ds_descricao CHARACTER VARYING(100) NOT NULL,
   ds_endereco CHARACTER VARYING(100),
   ds_bairro CHARACTER VARYING(25),
   nu_cep CHARACTER VARYING(15),
   nu_telefone CHARACTER VARYING(15),
   no_forum CHARACTER VARYING(100),
   co_tipo_vara BIGINT NOT NULL CONSTRAINT fk_tipovara_vara REFERENCES dbscodes.tb_tipo_vara(co_seq_tipo_vara),
   co_cidade BIGINT NOT NULL CONSTRAINT fk_cidade_vara REFERENCES dbscodes.tb_cidade(co_seq_cidade)
);

COMMENT ON TABLE dbscodes.tb_vara IS 'Registros de varas';
COMMENT ON COLUMN dbscodes.tb_vara.co_seq_vara IS 'Codigo de identificacão da vara, gerado pela sequence: dbscodes.sq_vara_coseqvara';
COMMENT ON COLUMN dbscodes.tb_vara.ds_descricao IS 'Descrição';
COMMENT ON COLUMN dbscodes.tb_vara.ds_endereco IS 'Endereço vara';
COMMENT ON COLUMN dbscodes.tb_vara.ds_bairro IS 'Bairro vara';
COMMENT ON COLUMN dbscodes.tb_vara.nu_cep IS 'CEP vara';
COMMENT ON COLUMN dbscodes.tb_vara.nu_telefone IS 'Telefone vara';
COMMENT ON COLUMN dbscodes.tb_vara.no_forum IS 'Nome fórum';
COMMENT ON COLUMN dbscodes.tb_vara.co_tipo_vara IS 'Código de identificacão do tipo da vara, chave estrangeira para dbscodes.tb_tipo_vara';
COMMENT ON COLUMN dbscodes.tb_vara.co_cidade IS 'Código de identificacão da cidade, chave estrangeira para dbscodes.tb_cidade';

--Criação tabela prazo

CREATE SEQUENCE dbscodes.sq_prazo_coseqprazo;
CREATE TABLE dbscodes.tb_prazo
(
   co_seq_prazo BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_prazo_coseqprazo'::regclass) CONSTRAINT pk_prazo PRIMARY KEY,
   ds_descricao CHARACTER VARYING(20) NOT NULL,
   nu_qtd_hrs BIGINT NOT NULL,
   tp_urgente BOOLEAN NOT NULL DEFAULT false
);

COMMENT ON TABLE dbscodes.tb_prazo IS 'Registros de prazos';
COMMENT ON COLUMN dbscodes.tb_prazo.co_seq_prazo IS 'Codigo de identificacão do prazo, gerado pela sequence: dbscodes.sq_prazo_coseqprazo';
COMMENT ON COLUMN dbscodes.tb_prazo.ds_descricao IS 'Descrição';
COMMENT ON COLUMN dbscodes.tb_prazo.nu_qtd_hrs IS 'Quantidade de horas';
COMMENT ON COLUMN dbscodes.tb_prazo.tp_urgente IS 'Verificação se é urgente, onde Sim = true, Não = false';


--Criação tabela tipo profissão

CREATE SEQUENCE dbscodes.sq_tipoprofissao_coseqtipoprofissao;
CREATE TABLE dbscodes.tb_tipo_profissao
(
   co_seq_tipo_profissao BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_tipoprofissao_coseqtipoprofissao'::regclass) CONSTRAINT pk_tipoprofissao PRIMARY KEY,
   ds_tipo_profissao CHARACTER VARYING(50),
   ds_conselho CHARACTER VARYING(10)
);

COMMENT ON TABLE dbscodes.tb_tipo_profissao IS 'Registros de tipo profissoes';
COMMENT ON COLUMN dbscodes.tb_tipo_profissao.co_seq_tipo_profissao IS 'Codigo de identificacão do tipo profissao, gerado pela sequence: dbscodes.sq_tipoprofissao_coseqtipoprofissao';
COMMENT ON COLUMN dbscodes.tb_tipo_profissao.ds_tipo_profissao IS 'Descrição do tipo de profissao';
COMMENT ON COLUMN dbscodes.tb_tipo_profissao.ds_conselho IS 'Descrição do conselho';


--Criação tabela profissional

CREATE SEQUENCE dbscodes.sq_profissional_coseqprofissional;
CREATE TABLE dbscodes.tb_profissional
(
   co_seq_profissional BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_profissional_coseqprofissional'::regclass) CONSTRAINT pk_profissional PRIMARY KEY,
   ds_camara CHARACTER VARYING(50),
   nu_conselho CHARACTER VARYING(15),
   tp_status BOOLEAN NOT NULL DEFAULT true,
   ds_motivo CHARACTER VARYING(100),
   ds_titulo CHARACTER VARYING(50),
   no_nome CHARACTER VARYING(80) not null,
   ds_email CHARACTER VARYING(100),
   co_tipo_profissao BIGINT NOT NULL CONSTRAINT fk_tipoprofissao_profissional REFERENCES dbscodes.tb_tipo_profissao(co_seq_tipo_profissao),
   sg_uf CHARACTER VARYING(2) NOT NULL CONSTRAINT fk_uf_profissional REFERENCES dbscodes.tb_uf(sg_uf)
);

COMMENT ON TABLE dbscodes.tb_profissional IS 'Registros de profissionals';
COMMENT ON COLUMN dbscodes.tb_profissional.co_seq_profissional IS 'Codigo de identificacão da profissional, gerado pela sequence: dbscodes.sq_profissional_coseqprofissional';
COMMENT ON COLUMN dbscodes.tb_profissional.ds_camara IS 'Descrição';
COMMENT ON COLUMN dbscodes.tb_profissional.nu_conselho IS 'Número do conselho do profissional';
COMMENT ON COLUMN dbscodes.tb_profissional.tp_status IS 'Verificação de status, onde Ativo = true, Inativo = false';
COMMENT ON COLUMN dbscodes.tb_profissional.ds_motivo IS 'Motivo do profissional';
COMMENT ON COLUMN dbscodes.tb_profissional.ds_titulo IS 'Titulo do profissional';
COMMENT ON COLUMN dbscodes.tb_profissional.no_nome IS 'Nome do profissional';
COMMENT ON COLUMN dbscodes.tb_profissional.ds_email IS 'E-mail do profissional';
COMMENT ON COLUMN dbscodes.tb_profissional.co_tipo_profissao IS 'Código de identificacão do tipo da profissão, chave estrangeira para dbscodes.sq_tipoprofissao_coseqtipoprofissao';
COMMENT ON COLUMN dbscodes.tb_profissional.sg_uf IS 'Código de identificacão da UF, chave estrangeira para dbscodes.tb_uf';

--Criação tabela relatório do profissional

CREATE TABLE dbscodes.rl_relatorio_profissional
(
   co_seq_profissional BIGINT NOT NULL,
   co_seq_relatorio_tecnico BIGINT NOT NULL,
   tp_principal BOOLEAN NOT NULL DEFAULT false,
   CONSTRAINT pk_relatorioprofissional PRIMARY KEY (co_seq_profissional,co_seq_relatorio_tecnico)
);

COMMENT ON COLUMN dbscodes.rl_relatorio_profissional.co_seq_profissional IS 'Codigo de identificacão da profissional, gerado pela sequence: dbscodes.sq_profissional_coseqprofissional';
COMMENT ON COLUMN dbscodes.rl_relatorio_profissional.co_seq_relatorio_tecnico IS 'Codigo do relatório técnico, gerado pela sequence: dbscodes.sq_relatoriotecnico_coseqreltecnico';
COMMENT ON COLUMN dbscodes.rl_relatorio_profissional.tp_principal IS 'Verificação se é o relatório principal, onde Sim = true, Não = false';


--Criação tabela determinação

CREATE SEQUENCE dbscodes.sq_determinacao_coseqdeterminacao;
CREATE TABLE dbscodes.tb_determinacao
(
   co_seq_determinacao BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_determinacao_coseqdeterminacao'::regclass) CONSTRAINT pk_determinacao PRIMARY KEY,
   tp_ordem BIGINT NOT NULL,
   tp_decisao CHARACTER VARYING(1) NOT NULL,
   tp_suspencao CHARACTER VARYING(1)NOT NULL,
   tp_patologia BOOLEAN DEFAULT false,
   tp_substituicao BOOLEAN DEFAULT false,
   tp_inclusao BOOLEAN DEFAULT false,
   ds_observacao CHARACTER VARYING(1000),
   tp_status CHARACTER VARYING(1),
   co_profissional BIGINT NULL CONSTRAINT fk_profissional_determinacao REFERENCES dbscodes.tb_profissional(co_seq_profissional),
   co_evento BIGINT NOT NULL CONSTRAINT fk_evento_determinacao REFERENCES dbscodes.tb_evento(co_seq_evento),   
   CONSTRAINT ck_determinacao_tpordem CHECK (tp_ordem = 1 OR tp_ordem = 2 OR tp_ordem = 3 OR tp_ordem = 4 OR tp_ordem = 5 OR tp_ordem = 6 OR tp_ordem = 7 OR tp_ordem = 8),
   CONSTRAINT ck_determinacao_tpsuspencao CHECK (tp_suspencao::text = '1'::text OR tp_suspencao::text = '2'::text),
   CONSTRAINT ck_determinacao_tpdecisao CHECK (tp_decisao::text = 'A'::text OR tp_decisao::text = 'F'::text),
   CONSTRAINT ck_determinacao_tpstatus CHECK (tp_status::text = 'V'::text OR tp_status::text = 'P'::text OR tp_status::text = 'S'::text OR tp_status::text = 'N'::text)
);

COMMENT ON TABLE dbscodes.tb_determinacao IS 'Registros de profissionals';
COMMENT ON COLUMN dbscodes.tb_determinacao.co_seq_determinacao IS 'Codigo de identificacão da determinação, gerado pela sequence: dbscodes.sq_determinacao_coseqdeterminacao';
COMMENT ON COLUMN dbscodes.tb_determinacao.co_profissional IS 'Codigo de identificacão da profissional, gerado pela sequence: dbscodes.sq_profissional_coseqprofissional';
COMMENT ON COLUMN dbscodes.tb_determinacao.co_evento IS 'Codigo de identificacão do evento, gerado pela sequence: dbscodes.sq_evento_coseqevento';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_ordem IS 'Fornecer = 1, Aguardar Documentação = 2, Prestar Informação = 3, Manter = 4, Alterar = 5, Suspender = 6, Nao Fornecer = 7, Em Fase de Cadastro = 8';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_suspencao IS 'Verificação da suspencao, onde Definitivo = 1, Temporariamente = 2';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_patologia IS 'Verificação se tem patologia, onde Sim = true, Não = false';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_substituicao IS 'Verificação se é substituição, onde Sim = true, Não = false';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_inclusao IS 'Verificação se é inclusão, onde Sim = true, Não = false';
COMMENT ON COLUMN dbscodes.tb_determinacao.ds_observacao IS 'Observação';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_status IS 'Verificação de status, onde Vigente = V, Pendente = P, Substituida = S, Nenhum = N';
COMMENT ON COLUMN dbscodes.tb_determinacao.tp_decisao IS 'Verificação o tipo de decisão A =  F = ';

--Criação tabela elemento

CREATE SEQUENCE dbscodes.sq_elemento_coseqelemento;
CREATE TABLE dbscodes.tb_elemento
(
   co_seq_elemento BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_sq_elemento_coseqelemento'::regclass) CONSTRAINT pk_elemento PRIMARY KEY,
   nu_quantidade BIGINT,   
   tp_acao BIGINT NOT NULL, 
   tp_marca BOOLEAN NOT NULL DEFAULT false, 
   tp_elemento BIGINT NOT NULL,
   co_determinacao BIGINT NOT NULL CONSTRAINT fk_elemento_determinacao REFERENCES dbscodes.tb_determinacao(co_seq_determinacao),
   CONSTRAINT ck_elemento_tpacao CHECK (tp_acao = 1 OR tp_acao = 2 OR tp_acao = 3 OR tp_acao = 4),
   CONSTRAINT ck_elemento_tpelemento CHECK (tp_elemento = 1 OR tp_elemento = 2 OR tp_elemento = 3 OR tp_elemento = 4 OR tp_elemento = 5),
   
);

COMMENT ON TABLE dbscodes.tb_elemento IS 'Registros de profissionals';
COMMENT ON COLUMN dbscodes.tb_elemento.co_seq_elemento IS 'Codigo de identificacão da elemento, gerado pela sequence: dbscodes.sq_elemento_coseqelemento';
COMMENT ON COLUMN dbscodes.tb_elemento.co_determinacao IS 'Codigo de identificacão da determinação, FK da tabela tb_determinacao, gerado pela sequence: dbscodes.sq_determinacao_coseqdeterminacao';
COMMENT ON COLUMN dbscodes.tb_elemento.tp_elemento IS 'Medicamento = 1, Nutrição = 2, Material = 3, Procedimento = 4, Outros itens = 5';
COMMENT ON COLUMN dbscodes.tb_elemento.tp_marca IS 'Verificação se tem marca, onde Sim = true, Não = false';
COMMENT ON COLUMN dbscodes.tb_elemento.tp_acao IS 'Fornecer = 1, Incluir = 2, Alterar = 3, Excluir = 4';
COMMENT ON COLUMN dbscodes.tb_elemento.nu_quantidade IS 'quantidade de elementos';

--Criação da tebela processual

CREATE SEQUENCE dbscodes.sq_processual_coseqprocessual;
CREATE TABLE dbscodes.tb_processual
(
   co_seq_processual BIGINT NOT NULL DEFAULT nextval('dbscodes.sq_processual_coseqprocessual'::regclass) CONSTRAINT pk_processual PRIMARY KEY,
   st_segredo BOOLEAN NOT NULL DEFAULT false, 
   tp_acao_contra CHARACTER VARYING(2) NOT NULL,
   st_doc_completa BOOLEAN DEFAULT false, 
   dt_nao_cobranca_jud TIMESTAMP,
   tp_status CHARACTER VARYING(1),
   co_profissional BIGINT NULL CONSTRAINT fk_profissional_processual REFERENCES dbscodes.tb_profissional(co_seq_profissional),
   co_tipo_profissao BIGINT NULL CONSTRAINT fk_tipoprofissao_processual REFERENCES dbscodes.tb_tipo_profissao(co_seq_tipo_profissao),
   co_tipo_acao BIGINT NULL CONSTRAINT fk_tipo_acao_processual REFERENCES dbscodes.tb_tipo_acao(co_seq_tipo_acao),
   co_cidade BIGINT NULL CONSTRAINT fk_cidade_processual REFERENCES dbscodes.tb_cidade(co_seq_cidade),
   co_prazo BIGINT NOT NULL CONSTRAINT fk_prazo_processual REFERENCES dbscodes.tb_prazo(co_seq_prazo),
   co_vara BIGINT NOT NULL CONSTRAINT fk_vara_processual REFERENCES dbscodes.tb_vara(co_seq_vara),
   co_autor_demanda BIGINT NOT NULL CONSTRAINT fk_autordemanda_processual REFERENCES dbscodes.tb_autor_demanda(co_seq_autor_demanda),

   CONSTRAINT ck_processual_tpacaocontra CHECK (tp_acao_contra::text = 'E'::text OR tp_acao_contra::text = 'M'::text OR tp_acao_contra::text = 'EM'::text 
OR tp_acao_contra::text = 'UEM'::text OR tp_acao_contra::text = 'UE'::text OR tp_acao_contra::text = 'UM'::text),
   CONSTRAINT ck_processual_tpstatus CHECK (tp_status::text = 'V'::text OR tp_status::text = 'P'::text OR tp_status::text = 'S'::text OR tp_status::text = 'N'::text)
);

COMMENT ON TABLE dbscodes.tb_processual IS 'Registros de profissionals';
COMMENT ON COLUMN dbscodes.tb_processual.co_seq_processual IS 'Codigo de identificacão da determinação, gerado pela sequence: dbscodes.sq_processual_coseqprocessual';
COMMENT ON COLUMN dbscodes.tb_processual.co_profissional IS 'Codigo de identificacão da profissional, gerado pela sequence: dbscodes.sq_profissional_coseqprofissional';
COMMENT ON COLUMN dbscodes.tb_processual.co_tipo_profissao IS 'Código de identificacão do tipo da profissão, chave estrangeira gerado pela sequence: dbscodes.sq_tipoprofissao_coseqtipoprofissao';
COMMENT ON COLUMN dbscodes.tb_processual.co_tipo_acao IS 'Codigo de identificacão do tipo de ação, gerado pela sequence:: dbscodes.sq_tipoacao_coseqtipoacao';
COMMENT ON COLUMN dbscodes.tb_processual.co_cidade IS 'Código de identificacão da cidade, gerado pela sequence: dbscodes.sq_cidade_coseqcidade';
COMMENT ON COLUMN dbscodes.tb_processual.co_prazo IS 'Código de identificacão do prazo, gerado pela sequence: dbscodes.sq_prazo_coseqprazo';
COMMENT ON COLUMN dbscodes.tb_processual.co_vara IS 'Código de identificacão do vara, gerado pela sequence: dbscodes.sq_vara_coseqvara';
COMMENT ON COLUMN dbscodes.tb_processual.co_autor_demanda IS 'Codigo de identificacão do autor da demanda, gerado pela sequence: dbscodes.sq_autordemanda_coseqautordemanda';
COMMENT ON COLUMN dbscodes.tb_processual.st_doc_completa IS 'Verificação se é substituição, onde Sim = true, Não = false';
COMMENT ON COLUMN dbscodes.tb_processual.st_segredo IS 'Verificação se é segredo de justiça, onde Sim = true, Não = false';
COMMENT ON COLUMN dbscodes.tb_processual.dt_nao_cobranca_jud IS 'Data da não cobrança judicial';
COMMENT ON COLUMN dbscodes.tb_processual.tp_status IS 'Verificação de status, onde Vigente = V, Pendente = P, Substituida = S, Nenhum = N';
COMMENT ON COLUMN dbscodes.tb_processual.tp_acao_contra IS 'Verificação o tipo de ação, onde: E, M EM, UEM, UE, UM';

