package br.gov.datasus.scodes.acl.controller;

import br.gov.datasus.api.core.integracao.api.AcessoApi;
import br.gov.datasus.api.core.model.dto.acesso.*;
import br.gov.datasus.scodes.acl.model.dto.UserInfoDTO;
import br.gov.datasus.scodes.acl.properties.AppProperties;
import br.gov.datasus.scodes.acl.service.AcessoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.oauth2.client.OAuth2RestTemplate;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Api(tags = "Acesso", description = "Serviços utilizados para obter os dados relativos ao acesso do usuário")
@RestController
@AllArgsConstructor
public class AcessoController implements AcessoApi {

	private final AcessoService acessoService;

	private final OAuth2RestTemplate oauthRestTemplate;

	@Autowired
	protected AppProperties.IntegracaoAutorizador integracaoAutorizador;

	private AcessoService getProvider() {
		return acessoService;
	}

	@ApiOperation(value = "Obtém a estrutura de perfis e esferas, se caso existir.")
	public ResponseEntity<UsuarioAcessoDTO> usuario() {
		UserInfoDTO userInfo = autorizadorRequestUserInfo();
		return ResponseEntity.ok(getProvider().obterUsuario(userInfo));
	}

	@ApiOperation(value = "Obtém a estrutura de perfis e esferas, se caso existir.")
	public ResponseEntity<List<PerfilAcessoDTO>> perfil(@PathVariable("siglaSistema") String siglaSistema) {
		UserInfoDTO userInfo = autorizadorRequestUserInfo();
		return ResponseEntity.ok(getProvider().obterPerfil(userInfo, siglaSistema));
	}

	@ApiOperation(value = "Obtém as estrutura de menu.")
	public ResponseEntity<List<MenuAcessoDTO>> menu(@PathVariable("siglaSistema") String siglaSistema,
			@PathVariable("siglaPerfil") String siglaPerfil) {
		return ResponseEntity.ok(getProvider().obterMenu(siglaSistema, siglaPerfil));
	}

	@ApiOperation(value = "Obtém funcionalidades por perfil e sistema.")
	public ResponseEntity<List<FuncionalidadeAcessoDTO>> funcionalidade(
			@PathVariable("siglaSistema") String siglaSistema, @PathVariable(name = "siglaPerfil") String siglaPerfil) {
		return ResponseEntity.ok(getProvider().obterFuncionaliade(siglaSistema, siglaPerfil));
	}

	@ApiOperation(value = "Obtém os sistemas do usuário logado")
	public ResponseEntity<List<SistemaAcessoDTO>> sistemas() {
		UserInfoDTO userInfo = autorizadorRequestUserInfo();
		return ResponseEntity.ok(getProvider().obterSistemas(userInfo));
	}

	private UserInfoDTO autorizadorRequestUserInfo() {
		return oauthRestTemplate.getForObject(integracaoAutorizador.urlUserInfo, UserInfoDTO.class);
	}

}
