package br.gov.datasus.scodes.acl.controller;

import br.gov.datasus.api.core.exception.BusinessException;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.acl.api.SistemaApi;
import br.gov.datasus.scodes.acl.model.dto.SistemaDTO;
import br.gov.datasus.scodes.acl.properties.MessageProperity;
import br.gov.datasus.scodes.acl.service.SistemaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;
import java.util.Optional;

@Api(tags = "Sistema")
@RequiredArgsConstructor
@RestController
public class SistemaController implements SistemaApi {

    private final SistemaService service;

    @ApiOperation(value = "Obter sistema por id e sigla")
    @Override
    public ResponseEntity<SistemaDTO> obterPorIdSigla(@RequestParam(name = "id", required = false) Optional<Long> id,
                                                      @RequestParam(name = "sigla", required = false) Optional<String> sigla) {
        if (!id.isPresent() && !sigla.isPresent()) {
            throw new BusinessException(MessageProperity.USUARIO_PARAMETROS_NAO_INFORMADOS);
        }
        return ResponseEntity.ok(service.obterPorIdSigla(id, sigla));
    }

    @ApiOperation(value = "Obter todos sistemas paginado")
    @Override
    public ResponseEntity<PageableResponseModel<SistemaDTO>> obterTodosPaginado(
        @Valid @RequestBody PageableRequestModel<?> pageableRequestModel) {
        return ResponseEntity.ok(service.obterTodos(pageableRequestModel));
    }

    @ApiOperation(value = "Obter sistemas de um usuáro")
    @Override
    public ResponseEntity<List<SistemaDTO>> obterSistemasUsuario(@PathVariable(name = "idUsuario") Long idUsuario) {
        List<SistemaDTO> lista = service.obterSistemasUsuario(idUsuario);
        return ResponseEntity.ok(lista);
    }

}
