package br.gov.datasus.scodes.acl.model.entity;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;

import br.gov.datasus.api.core.model.converter.SimNaoToBooleanConverter;
import br.gov.datasus.api.core.model.entity.BaseEntity;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_ACL_FUNCIONALIDADE", schema = "DBSCODES")
@NamedQueries({
		@NamedQuery(name = "Funcionalidade.obterPorSistema", query = "SELECT DISTINCT funcionalidade FROM Funcionalidade funcionalidade "
				+ "WHERE funcionalidade.sistema.sigla = :siglaSistema "),
		@NamedQuery(name = "Funcionalidade.obterPorSistemaPerfil", query = "SELECT DISTINCT funcionalidade FROM Permissao perm "
				+ "WHERE perm.funcionalidade.sistema.sigla = :siglaSistema AND perm.perfil.sigla = :siglaPerfil "),
		@NamedQuery(name = "Funcionalidade.obterDesbloqueadosPorSistemaPerfil", query = "SELECT DISTINCT funcionalidade FROM Permissao perm "
			+ "WHERE perm.funcionalidade.sistema.sigla = :siglaSistema AND perm.perfil.sigla = :siglaPerfil AND perm.funcionalidade.bloqueado = false") })
public class Funcionalidade extends BaseEntity<Long> {

	private static final long serialVersionUID = 1L;

	@Id
	@Column(name = "CO_SEQ_FUNCIONALIDADE")
	private Long id;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "CO_SISTEMA")
	private Sistema sistema;

	@Column(name = "DS_FUNCIONALIDADE", length = 100)
	private String descricao;

	@Column(name = "DS_PATH", length = 100)
	private String path;

	@Column(name = "SG_FUNCIONALIDADE", length = 5)
	private String sigla;

	@Convert(converter = SimNaoToBooleanConverter.class)
	@Column(name = "ST_BLOQUEADO")
	private Boolean bloqueado;

	@Convert(converter = SimNaoToBooleanConverter.class)
	@Column(name = "ST_EXIBE_MENU")
	private Boolean exibeMenu;

}
