package br.gov.datasus.scodes.acl.model.entity;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.hibernate.annotations.Where;

import br.gov.datasus.api.core.model.converter.SimNaoToBooleanConverter;
import br.gov.datasus.api.core.model.entity.BaseEntity;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_ACL_USUARIO", schema = "DBSCODES")
@Where(clause = "ST_CONFIRMADO='S'")
@NamedQueries({
		@NamedQuery(name = Usuario.OBTER_POR_ID_CPF_EMAIL, query = "SELECT u FROM Usuario u WHERE 1=1 AND (u.id = :id ) AND (u.cpf = :cpf) AND (u.email = :email)") })
public class Usuario extends BaseEntity<Long> {

	private static final long serialVersionUID = 1L;

	public static final String OBTER_POR_ID_CPF_EMAIL = "Usuario.obterUsuarioPorIdCpfOuEmail";

	@Id
	@GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_USUARIO")
	@SequenceGenerator(name = "SEQ_GENERATOR_USUARIO", sequenceName = "SQ_ACL_USUARIO_COSEQUSUARIO", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
	@Column(name = "CO_SEQ_USUARIO")
	private Long id;

	@Column(name = "CO_CPF_USUARIO", length = 11)
	private String cpf;

	@Column(name = "DS_EMAIL", length = 100)
	private String email;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "CO_RACA_COR")
	private RacaCor racaCor;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "CO_SEXO")
	private Sexo sexo;

	@Column(name = "DT_NASCIMENTO")
	@Temporal(TemporalType.TIMESTAMP)
	private Date dataNascimento;

	@Column(name = "NO_MAE", length = 70)
	private String nomeMae;

	@Column(name = "NO_USUARIO", length = 70)
	private String nome;

	@Column(name = "NU_CNS", length = 15)
	private String cns;

	@Column(name = "NU_PASSAPORTE", length = 30)
	private String passaporte;

	@Convert(converter = SimNaoToBooleanConverter.class)
	@Column(name = "ST_CONFIRMADO")
	private Boolean confirmado;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "CO_USUARIO_COMPLEMENTO")
	private UsuarioComplemento complemento;
}
