package br.gov.datasus.authorization;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.env.Environment;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableResourceServer;

@SpringBootApplication
@EnableScheduling
@EnableResourceServer
@EnableCaching
@EnableFeignClients
public class ApplicationBoot extends SpringBootServletInitializer {

	private static final Logger LOG = LoggerFactory.getLogger(ApplicationBoot.class);

	public static void main(String[] args) {
		ConfigurableApplicationContext ctx = SpringApplication.run(ApplicationBoot.class, args);
		try {
			// init
			Environment env = ctx.getEnvironment();

			LOG.info(
					"\n\n *** \n\n" + "\tAplicacao {} iniciada com sucesso!\n" + "\tDisponivel nos enderecos:\n"
							+ "\tLocal: http://{}:{}\n" + "\tExterno: http://{}:{}\n" + "\tSwagger Url: http://{}:{}\n"
							+ "\n *** \n\n",
					env.getProperty("spring.application.name"), InetAddress.getLoopbackAddress().getHostAddress(),
					env.getProperty("server.port"), InetAddress.getLocalHost().getHostAddress(),
					env.getProperty("server.port"), InetAddress.getLocalHost().getHostAddress(),
					env.getProperty("server.port") + "/swagger-ui.html");

		} catch (UnknownHostException e) {
			LOG.error("Falha ao executar aplicacao: {}", e);
			ctx.close();
		}

	}

	@Override
	protected SpringApplicationBuilder configure(SpringApplicationBuilder application) {
		return application.sources(ApplicationBoot.class);
	}
}