package br.gov.datasus.authorization.configuration.properties;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.PropertySource;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class ApplicationProperties {

	@Component
	@PropertySource(value = "classpath:application.yml")
	public static class Hazelcast {

		@Value("${hazelcast.kubernetes-service-dns}")
		public String kubernetesServiceDns;

		@Value("${hazelcast.server-url}")
		public String serverUrl;
	}

	@Component
	@ConfigurationProperties()
	@PropertySource(value = "classpath:application.yml")
	public static class ClientIntegration {

		@Value("#{'${client-integration}'.split(':')}")
		public List<String> clients;
	}

	@Component
	@ConfigurationProperties()
	@PropertySource(value = "classpath:application.yml")
	public static class External {

		@Value("${app-external.url-new-password}")
		public String urlNewPassword;

		@Value("${app-external.url-new-user}")
		public String urlNewUser;

		@Value("${app-external.url-new-user-instructions}")
		public String urlNewUserInstructions;

		@Value("${app-external.login-cidadao-enable}")
		public Boolean loginCidadaoEnable;

		@Value("${app-external.cns-digital-enable}")
		public Boolean cnsDigitalEnable;

		@Value("${app-external.url-callback-login-cidadao}")
		public String urlCallbackLoginCidadao;

		@Value("${app-external.url-provider-login-cidadao}")
		public String urlProviderLoginCidadao;

		@Value("${app-external.url-api-cidadao}")
		public String urlApiCidadao;

		@Value("${app-external.provider-cidadao-client_id}")
		public String providerCidadaoClientId;

		@Value("${app-external.provider-cidadao-client_secret}")
		public String providerCidadaoClientSecret;
	}

	@Component
	@ConfigurationProperties()
	@PropertySource(value = "classpath:application.yml")
	public static class Security {

		@Value("${security.captcha-enable}")
		public Boolean captchaEnable = false;

		@Value("${security.captcha-private-key}")
		public String captchaPrivateKey;

		@Value("${security.captcha-public-key}")
		public String captchaPublicKey;

		@Value("${security.captcha-verify-url}")
		public String captchaVerifyUrl;

		@Value("${security.proxy-enable}")
		public Boolean proxyEnable = false;

		@Value("${security.proxy-host}")
		public String proxyHost;

		@Value("${security.proxy-port}")
		public String proxyPort;
	}

	@Component
	@ConfigurationProperties()
	@PropertySource(value = "classpath:application.yml")
	public static class IntegracaoCadsus {
		@Value("${integracao.cadsus.url-login}")
		public String urlLoginCadsus;

		@Value("${integracao.cadsus.username}")
		public String cadsusUsername;

		@Value("${integracao.cadsus.password}")
		public String cadsusPassword;

	}

	private ApplicationProperties() {
	}

}
