package br.gov.datasus.authorization.configuration.security;

import br.gov.datasus.authorization.security.oauth2.filter.LoginAuthenticationFilter;
import br.gov.datasus.authorization.security.oauth2.provider.UserDetailsAuthenticationProvider;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.annotation.Order;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.builders.WebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.web.util.matcher.AntPathRequestMatcher;

@Configuration
@Order(1)
public class WebSecurityConfiguration extends WebSecurityConfigurerAdapter {

    @Override
    protected void configure(HttpSecurity http) throws Exception {
        http.addFilterBefore(loginAuthenticationFilter(), LoginAuthenticationFilter.class);
        http.formLogin()
            .loginPage("/login").permitAll().and()
            .logout().and()
            .requestMatchers().antMatchers(
                "/",
                "/login",
                "/oauth/authorize",
                "/oauth/confirm_access",
                "/logout-sso",
                "/login-cns-digital",
                "/nova-senha",
                "/enviar-senha"

            ).and()
            .authorizeRequests().anyRequest()
            .authenticated();
    }

    @Override
    public void configure(WebSecurity web) throws Exception {
        web.ignoring().antMatchers(
            "/v2/api-docs",
            "/configuration/ui",
            "/swagger-resources",
            "/configuration/security",
            "/swagger-ui.html",
            "/webjars/**",
            "/swagger-resources/configuration/ui",
            "/swagge‌​r-ui.html",
            "/swagger-resources/configuration/security",
            "/actuator",
            "/actuator/info",
            "/actuator/health",
            "/**/favicon.ico",
            "/**/login.min.js",
            "/**/style.min.css",
            "/**/logo-datasus.png",
            "/**/logo-ms.png",
            "/**/bg-graphics-header-cns.png",
            "/**/govbr_original_transparente.png",
            "/**/logo-cns-digital.png",
            "/**/jquery-2.1.3.min.js",
            "/**/material.min.js",
            "/**/material-blue-theme-with-font-rawline.min.css",
            "/**/material-green-theme-with-font-rawline.min.css",
            "/**/material-red-theme-with-font-rawline.min.css",
            "/**/rawline.css",
            "/login-cns-digital",
            "/nova-senha",
            "/enviar-senha",
            "/login-cidadao",
            "/login-cidadao-callback"
        );
    }

    @Override
    protected void configure(AuthenticationManagerBuilder auth) throws Exception {
        auth.authenticationProvider(authenticationProvider());
    }

    @Bean
    public BCryptPasswordEncoder passwordEncoder() {
        return new BCryptPasswordEncoder();
    }

    @Bean
    public UserDetailsAuthenticationProvider authenticationProvider() {
        return new UserDetailsAuthenticationProvider();
    }

    @Bean
    public LoginAuthenticationFilter loginAuthenticationFilter() throws Exception {
        LoginAuthenticationFilter filter = new LoginAuthenticationFilter();
        filter.setAuthenticationManager(authenticationManager());
        filter.setRequiresAuthenticationRequestMatcher(new AntPathRequestMatcher("/login", "POST"));
        return filter;
    }

    @Override
    @Bean
    public AuthenticationManager authenticationManagerBean() throws Exception {
        return super.authenticationManagerBean();
    }

}
