package br.gov.datasus.authorization.controller;

import br.gov.datasus.authorization.configuration.properties.ApplicationProperties;
import br.gov.datasus.authorization.enums.AuthorizationScopeEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.oauth2.common.util.OAuth2Utils;
import org.springframework.security.web.savedrequest.DefaultSavedRequest;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

@Controller
public class LoginController {

    @Autowired
    private ApplicationProperties.Security security;

    @Autowired
    private ApplicationProperties.External external;

    @RequestMapping("/login")
    public ModelAndView loginPage(@RequestParam(value = "error", required = false) Integer errorCode,
            HttpServletRequest request) {
        ModelAndView modelAndView = new ModelAndView();
        if (errorCode != null) {
            modelAndView.addObject("username", request.getParameter("username"));
            switch (errorCode) {
            case 1:// ERROR_LOGIN
                modelAndView.addObject("authenticationError", true);
                break;
            case 2:// ERROR_CAPCHA
                modelAndView.addObject("reCaptchaError", true);
                break;
            default:
                break;
            }
        }
        return modelViewRedirect(request, modelAndView);
    }

    @RequestMapping("/nova-senha")
    public ModelAndView novaSenha(HttpServletRequest request) {
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.addObject("username", request.getParameter("username"));
        modelAndView.setViewName("nova-senha");

        return modelAndView;
    }

    @RequestMapping("/enviar-senha")
    public ModelAndView enviarSenha(HttpServletRequest request) {
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.addObject("username", request.getParameter("username"));
        modelAndView.addObject("success", true); // TODO
        modelAndView.setViewName("nova-senha");

        return modelAndView;
    }

    private ModelAndView modelViewRedirect(final HttpServletRequest request, final ModelAndView modelAndView) {
        Map<String, String> securityRequest = getSecurityRequest(request);
        switch (extractAuthorizationScope(securityRequest)) {
        case SCPA:
            modelAndView.setViewName("login");
            modelAddCaptchaAttributes(modelAndView);
            modelAddScpaLinksAttributes(modelAndView);
            if (extractClientId(securityRequest) != null) {
                modelAddEnableProvidersAttributes(modelAndView);
            }
            break;
        case CNS_DIGITAL:
            modelAndView.setViewName("login-cns-digital");
            modelAndView.addObject("viewReturnButton", false);
            modelAddCaptchaAttributes(modelAndView);
            break;
        case GOV_BR:
            modelAndView.setViewName("redirect:/login-cidadao");
            break;
        default:
            break;
        }
        return modelAndView;
    }

    protected AuthorizationScopeEnum extractAuthorizationScope(Map<String, String> securityRequest) {
        if (securityRequest.containsKey(OAuth2Utils.SCOPE)) {
            return AuthorizationScopeEnum.obterPorCodigo(securityRequest.get(OAuth2Utils.SCOPE))
                    .orElse(AuthorizationScopeEnum.SCPA);
        }
        return AuthorizationScopeEnum.SCPA;
    }

    protected String extractClientId(Map<String, String> securityRequest) {

        if (securityRequest.containsKey(OAuth2Utils.CLIENT_ID)) {
            return securityRequest.get(OAuth2Utils.CLIENT_ID);
        }
        return null;
    }

    protected Map<String, String> getSecurityRequest(final HttpServletRequest request) {
        Map<String, String> securityRequest = new HashMap<String, String>();
        DefaultSavedRequest defaultSavedRequest = (DefaultSavedRequest) request.getSession()
                .getAttribute("SPRING_SECURITY_SAVED_REQUEST");
        if (defaultSavedRequest != null && defaultSavedRequest.getParameterMap() != null) {
            for (Entry<String, String[]> entry : defaultSavedRequest.getParameterMap().entrySet()) {
                securityRequest.put(entry.getKey(), entry.getValue()[0]);

            }
        }
        return securityRequest;
    }

    private void modelAddEnableProvidersAttributes(ModelAndView modelAndView) {
        modelAndView.addObject("govBrEnable", external.loginCidadaoEnable);
        modelAndView.addObject("cnsDigitalEnable", external.cnsDigitalEnable);
    }

    private void modelAddScpaLinksAttributes(ModelAndView modelAndView) {
        modelAndView.addObject("urlNewPassword", external.urlNewPassword);
        modelAndView.addObject("urlNewUser", external.urlNewUser);
        modelAndView.addObject("urlNewUserInstructions", external.urlNewUserInstructions);
    }

    private void modelAddCaptchaAttributes(ModelAndView modelAndView) {
        modelAndView.addObject("captchaEnable", security.captchaEnable);
        modelAndView.addObject("captchaKey", security.captchaPublicKey);
    }
}
