package br.gov.datasus.authorization.repository.scpa;

import java.util.List;
import java.util.Optional;

import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.CrudRepository;
import org.springframework.data.repository.query.Param;

import br.gov.datasus.authorization.model.scpa.Role;
import br.gov.datasus.authorization.model.scpa.Usuario;

public interface UsuarioScpaRepository extends CrudRepository<Usuario, Long> {

    @Query(value = "SELECT us FROM Usuario us WHERE (us.email =:login OR us.cpf =:login OR us.emailSecundario = :login) AND us.senha=:senha")
    public Optional<List<Usuario>> findUsuarioByLoginSenha(@Param(value = "login") String login,
            @Param(value = "senha") String senha);

    @Query(value = "SELECT CASE WHEN count(us.id)> 0 THEN true ELSE false END FROM Usuario us WHERE (us.email =:login OR us.cpf =:login OR us.emailSecundario = :login) AND us.senha=:senha ")
    public Boolean autenticarUsuario(@Param(value = "login") String login, @Param(value = "senha") String senha);

    @Query(value = "SELECT us FROM Usuario us WHERE us.email =:email")
    public Optional<Usuario> findUsuarioByEmail(@Param(value = "email") String email);

    @Query(value = " SELECT DISTINCT " + "   new br.gov.datasus.authorization.model.scpa.Role( "
            + "     upe.usuarioPerfil.perfil.sistema.id, " + "     upe.usuarioPerfil.perfil.sistema.sigla, "
            + "     upe.usuarioPerfil.perfil.sigla, " + "     upe.usuarioPerfil.perfil.sistema.validaRH, "
            + "     upe.usuarioPerfil.perfil.sistema.validaDominios " + "   ) " + " FROM UsuarioPerfilEsfera upe "
            + " WHERE upe.usuarioPerfil.usuario.id = :idUsuario " + " AND upe.participacao = 'SIM' ")
    public List<Role> findByRolesPerfil(@Param(value = "idUsuario") Long idUsuario);

    @Query(value = "SELECT COUNT(1)  FROM  DBSIARH.VW_COLABORADOR_SERVIDOR servidor  "
            + " WHERE servidor.NU_CPF IS NOT NULL  " + " AND servidor.ST_REGISTRO_ATIVO = 'S' "
            + " AND servidor.NU_CPF = ?1  " + " AND servidor.DS_ENDERECO_ELETRONICO = ?2  "
            + " AND servidor.DT_INGRESSO_ORGAO = (SELECT MAX(DT_INGRESSO_ORGAO)  FROM DBSIARH.VW_COLABORADOR_SERVIDOR WHERE  servidor.NU_MATRICULA = NU_MATRICULA)", nativeQuery = true)
    public Integer findByRolesValidaRH(String cpf, String email);

    @Query(value = "SELECT  count(dominio.DS_DOMINIO_EMAIL)  FROM  DBSCODES.TB_ACL_SISTEMA sis  "
            + "  INNER JOIN DBSCODES.TB_ACL_DOMINIO_EMAIL dominio ON dominio.CO_SISTEMA = sis.CO_SEQ_SISTEMA  "
            + " WHERE sis.ST_VALIDA_DOMINIO_EMAIL_USUARI = 'S'  AND dominio.ST_REGISTRO_ATIVO ='S'"
            + " AND  dominio.DS_DOMINIO_EMAIL = ?1 and sis.CO_SEQ_SISTEMA = ?2", nativeQuery = true)
    public Integer findByRolesValidaDominio(String dominio, Long idSistema);

    @Query(value = "SELECT us FROM Usuario us WHERE us.cpf =:cpf")
    public List<Usuario> findByCpf(@Param(value = "cpf") String cpf);

}
