package br.gov.datasus.authorization.security.oauth2.provider;

import br.gov.datasus.authorization.configuration.cache.HazelcastComponent;
import br.gov.datasus.authorization.enums.CacheEnum;
import br.gov.datasus.authorization.enums.OauthFlowEnum;
import br.gov.datasus.authorization.security.oauth2.model.Client;
import br.gov.datasus.authorization.security.oauth2.model.UserAuthority;
import com.hazelcast.core.IMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.oauth2.provider.ClientDetails;
import org.springframework.security.oauth2.provider.ClientDetailsService;
import org.springframework.security.oauth2.provider.ClientRegistrationException;
import org.springframework.security.oauth2.provider.client.BaseClientDetails;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@Service
public class ClientDetailsProvider implements ClientDetailsService {

    private static final int ACESS_TOKEN_SECONDS = 0;

    private static final int REFRESH_TOKEN_SECONDS = 7200;

    @Autowired
    HazelcastComponent cacheComponent;

    @Autowired
    private BCryptPasswordEncoder passwordEncoder;

    @Override
    @SuppressWarnings("unchecked")
    public ClientDetails loadClientByClientId(String clientId) throws ClientRegistrationException {
        IMap<String, Client> clientMap = (IMap<String, Client>) cacheComponent.getCacheMap(CacheEnum.CLIENTS);
        if (clientId == null || !clientMap.containsKey(clientId)) {
            throw new ClientRegistrationException("Invalid Client");
        }
        Client client = clientMap.get(clientId);
        BaseClientDetails details = new BaseClientDetails();
        details.setClientId(client.getClientId());
        details.setClientSecret(passwordEncoder.encode(client.getClientSecret()));
        if (client.isClientCredentials()) {
            if (!client.getClientRoles().isEmpty()) {
                List<GrantedAuthority> authorities = new ArrayList<>();
                for (String role : client.getClientRoles()) {
                    authorities.add(new UserAuthority(role));
                }
                details.setAuthorities(authorities);
            }
            details.setAuthorizedGrantTypes(Arrays.asList(OauthFlowEnum.CLIENT_CREDENTIALS.getFlowName()));
        } else {
            details.setAuthorizedGrantTypes(Arrays.asList(OauthFlowEnum.AUTHORIZATION_CODE.getFlowName(),
                    OauthFlowEnum.REFRESH_TOKEN.getFlowName(), OauthFlowEnum.PASSWORD.getFlowName(),
                    OauthFlowEnum.IMPLICIT.getFlowName()));
        }
        details.setScope(client.getScopes());
        details.setRegisteredRedirectUri(client.getUrls());
        details.setAutoApproveScopes(client.getScopes());
        details.setAccessTokenValiditySeconds(ACESS_TOKEN_SECONDS);
        details.setRefreshTokenValiditySeconds(REFRESH_TOKEN_SECONDS);
        return details;
    }
}
