package br.gov.datasus.authorization.security.oauth2.provider;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.authentication.dao.AbstractUserDetailsAuthenticationProvider;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.web.authentication.WebAuthenticationDetails;
import org.springframework.stereotype.Service;

import br.gov.datasus.authorization.security.oauth2.model.User;
import br.gov.datasus.authorization.service.UsuarioScpaService;

@Service("userDetailsAuthenticationProvider")
public class UserDetailsAuthenticationProvider extends AbstractUserDetailsAuthenticationProvider {

	private static final String DEFAULT_IP = "0.0.0.0";

	@Autowired
	private UsuarioScpaService usuarioScpaService;

	@Autowired
	private UserLogProvider userLogProvider;

	@Override
	public Authentication authenticate(Authentication authentication) throws AuthenticationException {
		Authentication authenticate = super.authenticate(authentication);
		String remoteAddress = DEFAULT_IP;
		if (authenticate.getDetails() instanceof WebAuthenticationDetails) {
			final WebAuthenticationDetails details = (WebAuthenticationDetails) authenticate.getDetails();
			remoteAddress = details.getRemoteAddress();
		}
		User user = (User) authenticate.getPrincipal();
		userLogProvider.logUser(remoteAddress, user.getUserInfo().getKey());
		return authenticate;
	}

	@Override
	protected void additionalAuthenticationChecks(UserDetails userDetails,
			UsernamePasswordAuthenticationToken authentication) throws AuthenticationException {
	}

	@Override
	protected UserDetails retrieveUser(String username, UsernamePasswordAuthenticationToken authentication)
			throws AuthenticationException {
		return usuarioScpaService.loadUser(username, authentication.getCredentials().toString());
	}
}
