package br.gov.datasus.scodes;

import java.net.InetAddress;
import java.net.UnknownHostException;


import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.core.env.Environment;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;

@Slf4j
@SpringBootApplication
@EntityScan(basePackages = {"br.gov.datasus.scodes.model.entity"})
@EnableJpaRepositories(basePackages = { "br.gov.datasus.scodes.repository", "br.gov.datasus.api.core.dynamicquery.repository" })
@ComponentScan(value = { "br.gov.datasus" })
@EnableFeignClients
public class ApplicationBoot extends SpringBootServletInitializer {

    private static final String SWAGGER_UI_HTML = "/swagger-ui.html";
    private static final String SERVER_PORT = "server.port";
    private static final String SERVER_SERVLET_CONTEXT_PATH = "server.servlet.contextPath";

    public static void main(String[] args) {
        ConfigurableApplicationContext ctx = SpringApplication.run(ApplicationBoot.class, args);
        try {
            Environment env = ctx.getEnvironment();

            log.info("\n\n *** \n\n" + "\tAplicacao {} iniciada com sucesso!\n" + "\tDisponivel nos enderecos:\n"
                    + "\tLocal: http://localhost:{}\n" + "\tExterno: http://{}:{}\n" + "\tSwagger Url: http://{}:{}\n"
                    + "\tLocal Swagger Url: http://localhost:{}\n" + "\n *** \n\n",
                    env.getProperty("spring.application.name"),
                    env.getProperty(SERVER_PORT) + env.getProperty(SERVER_SERVLET_CONTEXT_PATH),
                    InetAddress.getLocalHost().getHostAddress(),
                    env.getProperty(SERVER_PORT) + env.getProperty(SERVER_SERVLET_CONTEXT_PATH),
                    InetAddress.getLocalHost().getHostAddress(),
                    env.getProperty(SERVER_PORT) + env.getProperty(SERVER_SERVLET_CONTEXT_PATH) + SWAGGER_UI_HTML,
                    env.getProperty(SERVER_PORT) + env.getProperty(SERVER_SERVLET_CONTEXT_PATH)
                            + SWAGGER_UI_HTML);

        } catch (UnknownHostException e) {
            log.error("Falha ao executar aplicacao: {}", e);
            ctx.close();
        }
    }
}
