package br.gov.datasus.scodes.controller;

import javax.validation.Valid;

import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.AcessoDTO;
import br.gov.datasus.scodes.model.dto.ArquivoBase64DTO;
import br.gov.datasus.scodes.model.dto.filter.AcessoFilterDTO;
import br.gov.datasus.scodes.model.dto.filter.RelatorioAcessoFilterDTO;
import br.gov.datasus.scodes.service.AcessoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

@Api(tags = "Acesso")
@RequestMapping(value = "/acesso")
@RequiredArgsConstructor
@RestController
public class AcessoController {
	
    private final AcessoService service;
    
    @ApiOperation(value = "Obter acesso por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<AcessoDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos acessos paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<AcessoDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<AcessoFilterDTO> pageableModel) {
		return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }
    
    @ApiOperation(value = "Gerar relatório de acessos")
    @PostMapping(value = "/relatorio", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ArquivoBase64DTO> gerarRelatorio(@Valid @RequestBody RelatorioAcessoFilterDTO filter) {
        return ResponseEntity.ok(service.gerarRelatorio(filter));
    }
}

