package br.gov.datasus.scodes.controller;

import java.io.IOException;
import java.util.Base64;
import java.util.List;

import javax.validation.Valid;

import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import br.gov.datasus.api.core.exception.InfraException;
import br.gov.datasus.scodes.model.dto.ArquivoDTO;
import br.gov.datasus.scodes.model.dto.DiretorioDTO;
import br.gov.datasus.scodes.service.ArquivoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

@Api(tags = "Arquivo")
@RequestMapping(value = "/arquivo")
@RequiredArgsConstructor
@RestController
public class ArquivoController {

    private final ArquivoService service;

    @ApiOperation(value = "Obter arquivo por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ArquivoDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter Arquivos Por Diretório")
    @PostMapping(value = "/arquivo-diretorio/{diretorioId}/{autorDemandaId}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<ArquivoDTO>> obterArquivosPorDiretorio(@PathVariable(name = "diretorioId") Long diretorioId, @PathVariable(name = "autorDemandaId") Long autorDemandaId) {
        return ResponseEntity.ok(service.obterArquivosPorDiretorioId(diretorioId, autorDemandaId));
    }

    @ApiOperation(value = "Obter Diretórios")
    @PostMapping(value = "/diretorios/{autorDemandaId}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DiretorioDTO>> obterDiretorios(@PathVariable(name = "autorDemandaId") Long autorDemandaId) {
        return ResponseEntity.ok(service.obterDiretorios(autorDemandaId));
    }

    @ApiOperation(value = "Incluir arquivo")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ArquivoDTO> incluir(@Valid @RequestBody ArquivoDTO dto) {
        //ArquivoDTO dto = new ArquivoDTO();
        /*try {
            dto.setArquivo(arquivo.getBytes());
        } catch (IOException e) {
            throw new InfraException(e);
        }*/

        dto.setArquivo(Base64.getDecoder().decode(dto.getArquivo64()));
        dto = service.incluir(dto);
        return new ResponseEntity<ArquivoDTO>(dto, HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar arquivo")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ArquivoDTO> alterar(@Valid @RequestBody ArquivoDTO dto, @PathVariable(name = "id") Long id) {
        dto.setId(id);
        dto = service.alterar(dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir arquivo por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }

}

