package br.gov.datasus.scodes.controller;

import br.gov.datasus.scodes.model.dto.filter.CidadeFilterDTO;
import br.gov.datasus.scodes.model.dto.CidadeDTO;
import br.gov.datasus.scodes.service.CidadeService;
import javax.validation.Valid;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import lombok.RequiredArgsConstructor;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Api(tags = "Cidade")
@RequestMapping(value = "/cidade")
@RequiredArgsConstructor
@RestController
public class CidadeController {

    private final CidadeService service;
    
    @ApiOperation(value = "Obter cidade por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<CidadeDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos cidade")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<CidadeDTO>> obterTodos() {
        List<CidadeDTO> lista = service.obterTodos();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos cidades paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<CidadeDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<CidadeFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos cidade como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        List<DominioItemModel> lista = service.obterDominio();
        return ResponseEntity.ok(lista);
    }
    
    @ApiOperation(value = "Obter cidades por UF")
    @GetMapping(value = "/uf/{id}",produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<CidadeDTO>> obterCidadesPorUf(@PathVariable(name = "id") String id) {
        List<CidadeDTO> lista = service.obterCidadesPorUf(id);
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter cidades por nome")
    @GetMapping(value = "/nome-cidade/{nome}/uf-cidade/{uf}",produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<CidadeDTO>> obterCidadesPorNome(@PathVariable(name = "nome") String nome, @PathVariable(name = "uf") String uf) {
        List<CidadeDTO> lista = service.obterCidadesPorNome(nome, uf);
        return ResponseEntity.ok(lista);
    }

}

