package br.gov.datasus.scodes.controller;

import br.gov.datasus.scodes.service.ClassificacaoCobrancaService;
import br.gov.datasus.scodes.model.dto.ClassificacaoCobrancaDTO;
import br.gov.datasus.scodes.model.dto.filter.ClassificacaoCobrancaFilterDTO;
import javax.validation.Valid;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import lombok.RequiredArgsConstructor;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import java.util.List;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Api(tags = "ClassificacaoCobranca")
@RequestMapping(value = "/classificacao-cobranca")
@RequiredArgsConstructor
@RestController
public class ClassificacaoCobrancaController {

    private final ClassificacaoCobrancaService service;
    
    @ApiOperation(value = "Obter classificacao-cobranca por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ClassificacaoCobrancaDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos classificacao-cobranca")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<ClassificacaoCobrancaDTO>> obterTodos() {
        List<ClassificacaoCobrancaDTO> lista = service.obterTodos();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos classificacao-cobrancas paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<ClassificacaoCobrancaDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<ClassificacaoCobrancaFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos classificacao-cobranca como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        List<DominioItemModel> lista = service.obterDominio();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Incluir classificacao-cobranca")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ClassificacaoCobrancaDTO> incluir(@Valid @RequestBody ClassificacaoCobrancaDTO dto) {
        dto = service.incluir(dto);
        return new ResponseEntity<ClassificacaoCobrancaDTO>(dto, HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar classificacao-cobranca")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ClassificacaoCobrancaDTO> alterar(@Valid @RequestBody ClassificacaoCobrancaDTO dto, @PathVariable(name = "id") Long id) {
        dto = service.alterar(id, dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir classificacao-cobranca por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }
}

