package br.gov.datasus.scodes.controller;

import java.util.List;

import javax.validation.Valid;

import br.gov.datasus.scodes.model.dto.DemandaDTO;
import br.gov.datasus.scodes.model.dto.UnidadeOrganizacionalDTO;
import br.gov.datasus.scodes.validation.DemandaServiceValidation;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import br.gov.datasus.scodes.model.dto.AutorDTO;
import br.gov.datasus.scodes.model.dto.AutorDemandaDTO;
import br.gov.datasus.scodes.model.dto.filter.DemandaFilterDTO;
import br.gov.datasus.scodes.service.AutorService;
import br.gov.datasus.scodes.service.DemandaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

@Api(tags = "Demanda")
@RequestMapping(value = "/demanda")
@RequiredArgsConstructor
@RestController
public class DemandaController {

    private final DemandaService service;
    private final AutorService autoService;
    private final DemandaServiceValidation serviceValidation;

    @ApiOperation(value = "Obter demanda por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<DemandaDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Incluir demanda")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<DemandaDTO> incluir(@Valid @RequestBody DemandaDTO dto) {
        dto = service.salvar(dto);
        return new ResponseEntity<DemandaDTO>(dto, HttpStatus.CREATED);
    }


    @ApiOperation(value = "Atualizar demanda")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<DemandaDTO> alterar(@Valid @RequestBody DemandaDTO dto, @PathVariable(name = "id") Long id) {
        dto.setId(id);
        dto = service.salvar(dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir demanda por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }

    @ApiOperation(value = "Pesquisar autor por CPF")
    @PostMapping(value = "/pesquisar-autor-cpf/{cpf}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<AutorDTO>> pesquisarPorCpf(@PathVariable(name = "cpf") String cpf) {
        return ResponseEntity.ok(autoService.pesquisarAutorPorCpf(cpf));
    }

}

