package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.EspecificacaoDTO;
import br.gov.datasus.scodes.model.dto.filter.EspecificacaoFilterDTO;
import br.gov.datasus.scodes.service.EspecificacaoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "Especificacao")
@RequestMapping(value = "/especificacao")
@RequiredArgsConstructor
@RestController
public class EspecificacaoController {

    private final EspecificacaoService service;

    @ApiOperation(value = "Obter especificação por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<EspecificacaoDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todas especificações")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<EspecificacaoDTO>> obterTodos() {
        return ResponseEntity.ok(service.obterTodos());
    }

    @ApiOperation(value = "Obter todas especificações paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<EspecificacaoDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<EspecificacaoFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos especificacao como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio(
        @RequestParam(name = "produto", required = false) Long idProduto
    ) {
        return ResponseEntity.ok(service.obterDominio(idProduto));
    }

    @ApiOperation(value = "Incluir especificacao")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<EspecificacaoDTO> incluir(@Valid @RequestBody EspecificacaoDTO dto) {
        return new ResponseEntity<>(service.incluir(dto), HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar especificacao")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<EspecificacaoDTO> alterar(@Valid @RequestBody EspecificacaoDTO dto, @PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.alterar(id, dto));
    }

    @ApiOperation(value = "Excluir especificacao por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}

