package br.gov.datasus.scodes.controller;

import br.gov.datasus.scodes.model.dto.EstoqueAuxiliarDTO;
import br.gov.datasus.scodes.service.EstoqueAuxiliarService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@Api(tags = "EstoqueAuxiliar")
@RequestMapping(value = "/estoque-auxiliar")
@RequiredArgsConstructor
@RestController
public class EstoqueAuxiliarController {

    private final EstoqueAuxiliarService service;

    @ApiOperation(value = "Obter estoque auxiliar por código do item e unidade dispensadora")
    @GetMapping(value = "/{idItem}/{idUnidadeDispensadora}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<EstoqueAuxiliarDTO> obterPorId(@PathVariable(name = "idItem") Long idItem,
                                                         @PathVariable(name = "idUnidadeDispensadora") Long idUnidadeDispensadora) {
        return ResponseEntity.ok(service.obterPorId(idItem, idUnidadeDispensadora));
    }

    @ApiOperation(value = "Obter quantidade em estoque por código do item e unidade dispensadora")
    @GetMapping(value = "/{idItem}/{idUnidadeDispensadora}/quantidade", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Long> obterQuantidade(@PathVariable(name = "idItem") Long idItem,
                                                @PathVariable(name = "idUnidadeDispensadora") Long idUnidadeDispensadora) {
        return ResponseEntity.ok(service.obterQuantidade(idItem, idUnidadeDispensadora));
    }

}
