package br.gov.datasus.scodes.controller;

import br.gov.datasus.scodes.model.dto.filter.GrupoFilterDTO;
import br.gov.datasus.scodes.model.dto.GrupoDTO;
import br.gov.datasus.scodes.service.GrupoService;
import javax.validation.Valid;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import lombok.RequiredArgsConstructor;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import java.util.List;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Api(tags = "Grupo")
@RequestMapping(value = "/grupo")
@RequiredArgsConstructor
@RestController
public class GrupoController {

    private final GrupoService service;
    
    @ApiOperation(value = "Obter grupo por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<GrupoDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos grupo")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<GrupoDTO>> obterTodos() {
        List<GrupoDTO> lista = service.obterTodos();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos grupos paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<GrupoDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<GrupoFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos grupo como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        List<DominioItemModel> lista = service.obterDominio();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Incluir grupo")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<GrupoDTO> incluir(@Valid @RequestBody GrupoDTO dto) {
        dto = service.incluir(dto);
        return new ResponseEntity<GrupoDTO>(dto, HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar grupo")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<GrupoDTO> alterar(@Valid @RequestBody GrupoDTO dto, @PathVariable(name = "id") Long id) {
        dto = service.alterar(id, dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir grupo por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }
}

