package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.InventarioItemDTO;
import br.gov.datasus.scodes.model.dto.filter.InventarioItemFilterDTO;
import br.gov.datasus.scodes.service.InventarioItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "InventarioItem")
@RequestMapping(value = "/inventario-item")
@RequiredArgsConstructor
@RestController
public class InventarioItemController {

    private final InventarioItemService service;

    @ApiOperation(value = "Obter item do inventário por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<InventarioItemDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos itens do inventarios paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<InventarioItemDTO>> obterTodosPaginado(
        @Valid @RequestBody PageableRequestModel<InventarioItemFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Salvar itens no inventário")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<InventarioItemDTO>> salvar(@Valid @RequestBody List<InventarioItemDTO> dtos) {
        return new ResponseEntity<>(service.salvar(dtos), HttpStatus.CREATED);
    }

}
