package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.ItemDTO;
import br.gov.datasus.scodes.model.dto.filter.ItemFilterDTO;
import br.gov.datasus.scodes.service.ItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;
import java.util.Set;

@Api(tags = "Item")
@RequestMapping(value = "/item")
@RequiredArgsConstructor
@RestController
public class ItemController {

    private final ItemService service;

    @ApiOperation(value = "Obter item por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ItemDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter autocomplete de item por código do item")
    @GetMapping(value = "/codigo/autocomplete", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterAutocompletePorCodigo(@RequestParam("codigo")  String codigo) {
        return ResponseEntity.ok(service.obterAutocompletePorCodigo(codigo));
    }

    @ApiOperation(value = "Obter todos items paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<ItemDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<ItemFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos item como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        return ResponseEntity.ok(service.obterDominio());
    }

    @ApiOperation(value = "Incluir item")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ItemDTO> incluir(@Valid @RequestBody ItemDTO dto) {
        return new ResponseEntity<>(service.incluir(dto), HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar item")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ItemDTO> alterar(@Valid @RequestBody ItemDTO dto, @PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.alterar(id, dto));
    }

    @ApiOperation(value = "Excluir item por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<>(HttpStatus.OK);
    }

    @ApiOperation(value = "Obter todos itens similares do item informado")
    @GetMapping(value = "/{id}/similares", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<ItemDTO>> similares(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterSimilares(id));
    }

    @ApiOperation(value = "Atualizar itens similares do item informado")
    @PutMapping(value = "/{id}/similares", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> similares(@Valid @RequestBody Set<Long> idSimilares, @PathVariable(name = "id") Long id) {
        service.alterarSimilares(id, idSimilares);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}

