package br.gov.datasus.scodes.controller;

import javax.validation.Valid;

import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.ModeloDTO;
import br.gov.datasus.scodes.model.dto.TipoModeloDTO;
import br.gov.datasus.scodes.model.dto.filter.ModeloFilterDTO;
import br.gov.datasus.scodes.model.dto.filter.TipoModeloFilterDTO;
import br.gov.datasus.scodes.model.enums.TipoModeloEnum;
import br.gov.datasus.scodes.service.ModeloService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

@Api(tags = "ModeloRelatorioTecnico")
@RequestMapping(value = "/modelo-relatorio-tecnico")
@RequiredArgsConstructor
@RestController
public class ModeloRelatorioTecnicoController {

    private final ModeloService service;
    private final TipoModeloFilterDTO tipoModeloFilterDTO = new TipoModeloFilterDTO(TipoModeloEnum.RELATORIO_TECNICO.getId());
    private final TipoModeloDTO tipoModeloDTO = new TipoModeloDTO(TipoModeloEnum.RELATORIO_TECNICO.getId());

    @ApiOperation(value = "Obter modelo de relatório técnico por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ModeloDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos modelos de relatório técnico paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<ModeloDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<ModeloFilterDTO> pageableModel) {
        pageableModel.getFilter().get().setTipoModelo(tipoModeloFilterDTO);
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Incluir modelo de relatório técnico")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ModeloDTO> incluir(@Valid @RequestBody ModeloDTO dto) {
        dto.setTipoModelo(tipoModeloDTO);
        dto = service.incluir(dto);
        return new ResponseEntity<ModeloDTO>(dto, HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar modelo de relatório técnico")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ModeloDTO> alterar(@Valid @RequestBody ModeloDTO dto, @PathVariable(name = "id") Long id) {
        dto = service.alterar(id, dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir modelo de relatório técnico por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }
}

