package br.gov.datasus.scodes.controller;

import javax.validation.Valid;

import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import br.gov.datasus.scodes.model.dto.ProcessualDTO;
import br.gov.datasus.scodes.service.ProcessualService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

@Api(tags = "Processual")
@RequestMapping(value = "/processual")
@RequiredArgsConstructor
@RestController
public class ProcessualController {

    private final ProcessualService service;

    @ApiOperation(value = "Obter processual por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ProcessualDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter processual por autor-demanda código")
    @GetMapping(value = "/autor-demanda/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ProcessualDTO> obterPorAutorDemandaId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorAutorDemandaId(id));
    }

    @ApiOperation(value = "Incluir processual")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ProcessualDTO> incluir(@Valid @RequestBody ProcessualDTO dto) {
        return new ResponseEntity<ProcessualDTO>(service.salvar(dto), HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar processual")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<ProcessualDTO> alterar(@Valid @RequestBody ProcessualDTO dto, @PathVariable(name = "id") Long id) {
        dto.setId(id);
        return ResponseEntity.ok(service.salvar(dto));
    }

    @ApiOperation(value = "Excluir processual por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }

}

