package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.SaidaEstoqueDTO;
import br.gov.datasus.scodes.service.SaidaEstoqueService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "SaidaEstoque")
@RequestMapping(value = "/saida-estoque")
@RequiredArgsConstructor
@RestController
public class SaidaEstoqueController {
	
    private final SaidaEstoqueService service;
    
    @ApiOperation(value = "Obter saida de estoque por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<SaidaEstoqueDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todas saidas de estoque paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<SaidaEstoqueDTO>> obterTodosPaginado(
        @Valid @RequestBody PageableRequestModel<Void> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Incluir entrada de estoque")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<SaidaEstoqueDTO> incluir(@Valid @RequestBody SaidaEstoqueDTO dto) {
        /* @todo buscar id do usuário logado */
        Long currentUserId = 1L;
        dto.setIdUsuario(currentUserId);
        /* ------------------------------------ */
        return new ResponseEntity<>(service.incluir(dto), HttpStatus.CREATED);
    }
}
