package br.gov.datasus.scodes.controller;

import java.util.List;

import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.scodes.model.dto.TipoDemandaDTO;
import br.gov.datasus.scodes.service.TipoDemandaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

@Api(tags = "TipoDemanda")
@RequestMapping(value = "/tipo-demanda")
@RequiredArgsConstructor
@RestController
public class TipoDemandaController {

    private final TipoDemandaService service;

    @ApiOperation(value = "Obter tipo-demanda por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<TipoDemandaDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos tipo-demanda como domínio codigo/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio(
        @RequestParam(name = "tipo-modelo", required = false) Long idTipoModelo
    ) {
        List<DominioItemModel> lista = service.obterDominio(idTipoModelo);
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos tipo-demanda como domínio id/descricao")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<TipoDemandaDTO>> obterTipoDemanda(
        @RequestParam(name = "tipo-modelo", required = false) Long idTipoModelo
    ) {
        List<TipoDemandaDTO> lista = service.obterTipoDemanda(idTipoModelo);
        return ResponseEntity.ok(lista);
    }
}

