package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.TipoMovimentacaoDTO;
import br.gov.datasus.scodes.model.enums.TipoMovimentacaoTipoEnum;
import br.gov.datasus.scodes.service.TipoMovimentacaoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "TipoMovimentacao")
@RequestMapping(value = "/tipo-movimentacao")
@RequiredArgsConstructor
@RestController
public class TipoMovimentacaoController {
	
    private final TipoMovimentacaoService service;

    @ApiOperation(value = "Obter tipo de movimentação por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<TipoMovimentacaoDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos tipos de movimentações")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<TipoMovimentacaoDTO>> obterTodos() {
        List<TipoMovimentacaoDTO> lista = service.obterTodos();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos tipos de movimentações paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<TipoMovimentacaoDTO>> obterTodosPaginado(
        @Valid @RequestBody PageableRequestModel<Void> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos tipos de movimentações como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        List<DominioItemModel> lista = service.obterDominio();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter tipos de movimentações do tipo informado como domínio id/descricao")
    @GetMapping(value = "/dominio/tipo/{tipo}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio(@PathVariable(name = "tipo") TipoMovimentacaoTipoEnum tipo) {
        List<DominioItemModel> lista = service.obterDominio(tipo);
        return ResponseEntity.ok(lista);
    }

}
