package br.gov.datasus.scodes.controller;

import br.gov.datasus.scodes.model.dto.UnidadeDispensadoraDTO;
import br.gov.datasus.scodes.service.UnidadeDispensadoraService;
import br.gov.datasus.scodes.model.dto.filter.UnidadeDispensadoraFilterDTO;
import javax.validation.Valid;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import lombok.RequiredArgsConstructor;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import java.util.List;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Api(tags = "UnidadeDispensadora")
@RequestMapping(value = "/unidade-dispensadora")
@RequiredArgsConstructor
@RestController
public class UnidadeDispensadoraController {

    private final UnidadeDispensadoraService service;
    
    @ApiOperation(value = "Obter unidade-dispensadora por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeDispensadoraDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos unidade-dispensadora")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<UnidadeDispensadoraDTO>> obterTodos() {
        List<UnidadeDispensadoraDTO> lista = service.obterTodos();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos unidade-dispensadoras paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<UnidadeDispensadoraDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<UnidadeDispensadoraFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos unidade-dispensadora como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        List<DominioItemModel> lista = service.obterDominio();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Incluir unidade-dispensadora")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeDispensadoraDTO> incluir(@Valid @RequestBody UnidadeDispensadoraDTO dto) {
        dto = service.incluir(dto);
        return new ResponseEntity<UnidadeDispensadoraDTO>(dto, HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar unidade-dispensadora")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeDispensadoraDTO> alterar(@Valid @RequestBody UnidadeDispensadoraDTO dto, @PathVariable(name = "id") Long id) {
        dto = service.alterar(id, dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir unidade-dispensadora por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }
}

