package br.gov.datasus.scodes.controller;

import br.gov.datasus.scodes.service.UnidadeOrganizacionalService;
import br.gov.datasus.scodes.model.dto.UnidadeOrganizacionalDTO;
import br.gov.datasus.scodes.model.dto.filter.UnidadeOrganizacionalFilterDTO;
import javax.validation.Valid;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import lombok.RequiredArgsConstructor;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import java.util.List;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Api(tags = "UnidadeOrganizacional")
@RequestMapping(value = "/unidade-organizacional")
@RequiredArgsConstructor
@RestController
public class UnidadeOrganizacionalController {

    private final UnidadeOrganizacionalService service;
    
    @ApiOperation(value = "Obter unidade-organizacional por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeOrganizacionalDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos unidade-organizacional")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<UnidadeOrganizacionalDTO>> obterTodos() {
        List<UnidadeOrganizacionalDTO> lista = service.obterTodos();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Obter todos unidade-organizacionals paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<UnidadeOrganizacionalDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<UnidadeOrganizacionalFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todos unidade-organizacional como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        List<DominioItemModel> lista = service.obterDominio();
        return ResponseEntity.ok(lista);
    }

    @ApiOperation(value = "Incluir unidade-organizacional")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeOrganizacionalDTO> incluir(@Valid @RequestBody UnidadeOrganizacionalDTO dto) {
        dto = service.incluir(dto);
        return new ResponseEntity<UnidadeOrganizacionalDTO>(dto, HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar unidade-organizacional")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeOrganizacionalDTO> alterar(@Valid @RequestBody UnidadeOrganizacionalDTO dto, @PathVariable(name = "id") Long id) {
        dto = service.alterar(id, dto);
        return ResponseEntity.ok(dto);
    }

    @ApiOperation(value = "Excluir unidade-organizacional por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<Void>(HttpStatus.OK);
    }
}

