package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.UnidadeTransferenciaDTO;
import br.gov.datasus.scodes.model.dto.filter.UnidadeTransferenciaFilterDTO;
import br.gov.datasus.scodes.service.UnidadeTransferenciaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "UnidadeTransferencia")
@RequestMapping(value = "/unidade-transferencia")
@RequiredArgsConstructor
@RestController
public class UnidadeTransferenciaController {

    private final UnidadeTransferenciaService service;
    
    @ApiOperation(value = "Obter unidade-transferencia por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeTransferenciaDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todas unidade de transferência")
    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<UnidadeTransferenciaDTO>> obterTodos() {
        return ResponseEntity.ok(service.obterTodos());
    }

    @ApiOperation(value = "Obter todas unidade de transferência paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<UnidadeTransferenciaDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<UnidadeTransferenciaFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

    @ApiOperation(value = "Obter todas unidade de transferência como domínio id/descricao")
    @GetMapping(value = "/dominio", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<List<DominioItemModel>> obterDominio() {
        return ResponseEntity.ok(service.obterDominio());
    }

    @ApiOperation(value = "Incluir unidade de transferência")
    @PostMapping(consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeTransferenciaDTO> incluir(@Valid @RequestBody UnidadeTransferenciaDTO dto) {
        return new ResponseEntity<>(service.incluir(dto), HttpStatus.CREATED);
    }

    @ApiOperation(value = "Atualizar unidade de transferência")
    @PutMapping(value = "/{id}", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UnidadeTransferenciaDTO> alterar(@Valid @RequestBody UnidadeTransferenciaDTO dto, @PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.alterar(id, dto));
    }

    @ApiOperation(value = "Excluir unidade de transferência por id")
    @DeleteMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<Void> excluir(@PathVariable(name = "id") Long id) {
        service.excluir(id);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}

