package br.gov.datasus.scodes.controller;

import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.UsuarioDTO;
import br.gov.datasus.scodes.model.dto.filter.UsuarioFilterDTO;
import br.gov.datasus.scodes.service.UsuarioService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@Api(tags = "Usuario")
@RequestMapping(value = "/usuario")
@RequiredArgsConstructor
@RestController
public class UsuarioController {

    private final UsuarioService service;
    
    @ApiOperation(value = "Obter usuário por código")
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<UsuarioDTO> obterPorId(@PathVariable(name = "id") Long id) {
        return ResponseEntity.ok(service.obterPorId(id));
    }

    @ApiOperation(value = "Obter todos usuários paginado")
    @PostMapping(value = "/paginado", produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<PageableResponseModel<UsuarioDTO>> obterTodosPaginado(
            @Valid @RequestBody PageableRequestModel<UsuarioFilterDTO> pageableModel) {
        return ResponseEntity.ok(service.obterTodosPaginado(pageableModel));
    }

}

