
package br.gov.datasus.scodes.model.entity;

import java.util.Date;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQuery;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_AUTOR_DEMANDA", schema = "DBSCODES")
@NamedQuery(
    name = AutorDemanda.PESQUISAR_PAGINADO,
    query = " SELECT autorDemanda FROM AutorDemanda autorDemanda"
        + " INNER JOIN FETCH autorDemanda.autores autor "
        + " WHERE 1 = 1 "
        + " AND (autorDemanda.demanda.protocolo = :protocolo) "
        + " AND (autorDemanda.demanda.processo = :processo) "
        + " AND (UPPER(autor.nome) LIKE UPPER(:nomeAutor)) "
        + " AND (UPPER(autor.nomeMae) LIKE UPPER(:nomeMae)) "
        + " AND (autor.rg = :documento OR autor.cpf = :documento OR autor.cns = :documento) "
        + " AND (autorDemanda.demanda.unidadeOrganizacional.id = :idUnidadeOrganizacional) "
        + " AND (autorDemanda.demanda.tipoDemanda.id = :idTipoDemanda) "
)
public class AutorDemanda extends BaseEntity<Long> {


    private static final long serialVersionUID = 1L;

    public static final String PESQUISAR_PAGINADO = "AutorDemanda.pesquisarPaginado";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_AUTORDEMANDA")
    @SequenceGenerator(name = "SEQ_GENERATOR_AUTORDEMANDA", sequenceName = "SQ_AUTORDEMANDA_COSEQAUTORDEMANDA", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_AUTOR_DEMANDA", nullable = false)
    private Long id;

    @ManyToMany(cascade = {CascadeType.MERGE})
    @JoinTable(name = "RL_AUTOR_AUTOR_DEMANDA", schema = "DBSCODES",
        joinColumns = { @JoinColumn(name = "CO_AUTOR_DEMANDA") },
        inverseJoinColumns = { @JoinColumn(name = "CO_AUTOR")})
    private Set<Autor> autores;

    @OneToOne(cascade = {CascadeType.MERGE, CascadeType.REMOVE})
    @JoinColumn(name = "CO_DEMANDA", nullable = false)
    private Demanda demanda;

    @ManyToOne
    @JoinColumn(name = "CO_STATUS")
    private Status status;

    @Column(name = "ST_ATENDIDO", nullable = false)
    private Boolean atendido;

    @Column(name = "ST_COBRANCA_JUDICIAL", nullable = false)
    private Boolean cobrancaJudicial = Boolean.FALSE;

    @Column(name = "DT_ENTRADA", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date dataEntrada;
}
