package br.gov.datasus.scodes.model.entity;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_CIDADE", schema = "DBSCODES")
@NamedQueries({
     @NamedQuery(name = Cidade.OBTER_TODOS_PAGINADO, query = "SELECT cidade FROM Cidade cidade")
    ,@NamedQuery(name = Cidade.OBTER_DOMINIO, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(cidade.idIbge, cidade.descricao) FROM Cidade cidade")
    ,@NamedQuery(name = Cidade.OBTER_CIDADES_POR_UF, query = "SELECT cidade FROM Cidade cidade WHERE cidade.uf.id = UPPER(:id)")
    ,@NamedQuery(name = Cidade.OBTER_CIDADES_POR_NOME, query = " SELECT cidade FROM Cidade cidade WHERE UPPER(cidade.descricao) LIKE UPPER(:nome) and cidade.uf.id = :uf")
    ,@NamedQuery(name = Cidade.PESQUISAR_CIDADE_VARA,
        query = " SELECT DISTINCT cidade FROM Cidade cidade"
            + " INNER JOIN cidade.varas vara "
            + " WHERE 1 = 1 "
            + " AND (vara.cidade.uf.id = :uf) "
            + " AND (UPPER(vara.cidade.descricao) LIKE UPPER(:nome)) ")
    ,
})
public class Cidade extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;
    public static final String OBTER_TODOS_PAGINADO = "Cidade.obterTodosPaginado";
    public static final String OBTER_DOMINIO = "Cidade.obterDominio";
    public static final String OBTER_CIDADES_POR_UF = "Cidade.obterCidadesPorUf";
    public static final String OBTER_CIDADES_POR_NOME = "Cidade.obterCidadesPorNome";
    public static final String PESQUISAR_CIDADE_VARA = "Vara.pesquisarCidadeVara";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_CIDADE")
    @SequenceGenerator(name = "SEQ_GENERATOR_CIDADE", sequenceName = "SQ_CIDADE_COSEQCIDADE", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_CIDADE")
    private Long id;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "CO_DRS")
    private Drs drs;

    @Column(name = "CO_IBGE_CIDADE")
    private Long idIbge;

    @Column(name = "DS_CIDADE", length = 80)
    private String descricao;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "SG_UF")
    private Uf uf;

    @OneToMany(mappedBy = "cidade")
    private List<Vara> varas = new ArrayList<>();

}
