package br.gov.datasus.scodes.model.entity;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import javax.persistence.*;
import java.util.Date;
import java.util.List;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_INVENTARIO", schema = "DBSCODES")
@NamedQuery(name = Inventario.OBTER_TODOS_PAGINADO, query = "SELECT i FROM Inventario i" +
    " INNER JOIN FETCH i.usuario u" +
    " INNER JOIN FETCH i.unidadeDispensadora ud" +
    " WHERE 1=1" +
    " AND (UPPER(i.descricao) LIKE UPPER(:descricao))" +
    " AND (i.unidadeDispensadora.id = :idUnidadeDispensadora)" +
    " AND (i.dataCadastro >= :dataInicio)" +
    " AND (i.dataCadastro < :dataFim)" +
    " AND (i.situacaoAtivo = :situacaoAtivo)")
@NamedQuery(name = Inventario.OBTER_DOMINIO, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(i.id, i.descricao) FROM Inventario i ORDER BY i.descricao ASC")
public class Inventario extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    public static final String OBTER_TODOS_PAGINADO = "Inventario.obterTodosPaginado";
    public static final String OBTER_DOMINIO = "Inventario.obterDominio";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_INVENTARIO")
    @SequenceGenerator(name = "SEQ_GENERATOR_INVENTARIO", sequenceName = "SQ_INVENTARIO_COSEQINVENTARIO", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_INVENTARIO", nullable = false)
    private Long id;

    @Column(name = "DS_INVENTARIO", length = 60, nullable = false)
    private String descricao;

    @Column(name = "DT_CADASTRO", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    @Setter(AccessLevel.NONE)
    private Date dataCadastro;

    @ManyToOne
    @JoinColumn(name = "CO_USUARIO", nullable = false)
    private Usuario usuario;

    @ManyToOne
    @JoinColumn(name = "CO_UNIDADE_DISPENSADORA", nullable = false)
    private UnidadeDispensadora unidadeDispensadora;

    @Column(name = "ST_ATIVO", nullable = false)
    private Boolean situacaoAtivo;

    @OneToMany(mappedBy = "inventario")
    private List<InventarioItem> itens;

    @PrePersist
    public void prePersist() {
        if (situacaoAtivo == null) {
            situacaoAtivo = true;
        }
        this.dataCadastro = new Date();
    }
}
