package br.gov.datasus.scodes.model.entity;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import javax.persistence.*;
import java.math.BigDecimal;
import java.util.Date;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_INVENTARIO_ITEM", schema = "DBSCODES")
public class InventarioItem extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_INVENTARIO_ITEM")
    @SequenceGenerator(name = "SEQ_GENERATOR_INVENTARIO_ITEM", sequenceName = "SQ_INVENTITEM_COSEQINVENTITEM", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_INVENTARIO_ITEM", nullable = false)
    private Long id;

    @ManyToOne
    @JoinColumn(name = "CO_INVENTARIO", nullable = false)
    private Inventario inventario;

    @ManyToOne
    @JoinColumn(name = "CO_ITEM", nullable = false)
    private Item item;

    @Column(name = "QT_INVENTARIO_ITEM", nullable = false)
    private Long quantidadeFisica;

    @Column(name = "DT_CONTAGEM", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date dataContagem;

    @Column(name = "ST_ALTERADO", nullable = false)
    @Setter(AccessLevel.NONE)
    private Boolean situacaoAlterado;

    @Column(name = "QT_COMPRA_ENTRADA")
    private Long quantidadeCompraEntrada;

    @Column(name = "QT_OUTRA_ENTRADA")
    private Long quantidadeOutraEntrada;

    @Column(name = "QT_PERDA_SAIDA")
    private Long quantidadePerdaSaida;

    @Column(name = "QT_TRANSFERENCIA_SAIDA")
    private Long quantidadeTransferenciaSaida;

    @Column(name = "QT_DISPENSACAO_SAIDA")
    private Long quantidadeDispensacaoSaida;

    @Column(name = "QT_ESTORNO_ENTRADA")
    private Long quantidadeEstornoEntrada;

    @Column(name = "QT_RECIBO_INVALIDADO_ENTRADA")
    private Long quantidadeReciboInvalidadoEntrada;

    @Column(name = "QT_OUTRA_SAIDA")
    private Long quantidadeOutraSaida;

    @Column(name = "QT_PERDA_VENCIMENTO_SAIDA")
    private Long quantidadePerdaVencimentoSaida;

    @Column(name = "QT_QUEBRA_SAIDA")
    private Long quantidadeQuebraSaida;

    @Column(name = "QT_AJUSTE_SAIDA")
    private Long quantidadeAjusteSaida;

    @Column(name = "QT_ESTOQUE_DATA_CONTAGEM")
    private Long quantidadeEstoqueDataContagem;

    @Column(name = "QT_ITEM_POS_CALCULOS")
    private Long quantidadeItemPosCalculos;

    @Column(name = "QT_ITEM_DIFERENCA")
    private Long quantidadeItemDiferenca;

    @Column(name = "VL_ITEM")
    private BigDecimal valorItem;

    public UnidadeDispensadora getUnidadeDispensadora() {
        return this.inventario != null ? this.inventario.getUnidadeDispensadora() : null;
    }

    @PrePersist
    public void prePersist() {
        this.situacaoAlterado = false;
    }

    @PreUpdate
    public void preUpdate() {
        this.situacaoAlterado = true;
    }
}
