package br.gov.datasus.scodes.model.entity;

import java.util.List;

import javax.persistence.*;

import br.gov.datasus.api.core.model.entity.BaseEntity;

import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_PERFIL", schema = "DBSCODES")
@NamedQueries({
    @NamedQuery(name = Perfil.OBTER_TODOS_PAGINADO, query = "SELECT p FROM Perfil p"
    		+ " INNER JOIN FETCH p.area a"
    		+ " WHERE 1=1"
    		+ " AND (UPPER(p.nome) LIKE UPPER(:nome))"),
    @NamedQuery(name = Perfil.OBTER_DOMINIO, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(p.id, p.nome) FROM Perfil p ORDER BY p.nome ASC"),
    @NamedQuery(name = Perfil.OBTER_DOMINIO_ADMINISTRATIVO_POR_AREA, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(p.id, p.nome) FROM Perfil p" +
        " WHERE p.demandaAdministrativa = true AND (p.area.id=:idArea) ORDER BY p.nome ASC"),
    @NamedQuery(name = Perfil.OBTER_DOMINIO_JUDICIAL_POR_AREA, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(p.id, p.nome) FROM Perfil p" +
        " WHERE p.demandaJudicial = true AND (p.area.id=:idArea) ORDER BY p.nome ASC")
})
public class Perfil extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    public static final String OBTER_TODOS_PAGINADO = "Perfil.obterTodosPaginado";
    public static final String OBTER_DOMINIO = "Perfil.obterDominio";
    public static final String OBTER_DOMINIO_ADMINISTRATIVO_POR_AREA = "Perfil.obterDominioDemandaAdmPorArea";
    public static final String OBTER_DOMINIO_JUDICIAL_POR_AREA = "Perfil.obterDominioDemandaJudicialPorArea";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_PERFIL")
    @SequenceGenerator(name = "SEQ_GENERATOR_PERFIL", sequenceName = "SQ_PERFIL_COSEQPERFIL", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_PERFIL", nullable = false)
    private Long id;

    @Column(name = "NO_PERFIL", length = 20, nullable = false)
    private String nome;

    @Column(name = "DS_PERFIL", length = 50, nullable = false)
    private String descricao;

    @Column(name = "ST_ATIVO", nullable = false)
    private Boolean situacaoAtivo;

    @ManyToOne
	@JoinColumn(name = "CO_AREA", nullable = false)
    private Area area;

    @Column(name = "ST_DEMANDA_ADMINISTRATIVA", nullable = false)
    private Boolean demandaAdministrativa;

    @Column(name = "ST_DEMANDA_JUDICIAL", nullable = false)
    private Boolean demandaJudicial;

    @OneToMany(mappedBy = "id.perfil", cascade = CascadeType.ALL)
    private List<PerfilFuncionalidade> perfilFuncionalidades;

}