package br.gov.datasus.scodes.model.entity;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import br.gov.datasus.scodes.model.converter.TipoAcaoContraEnumConverter;
import br.gov.datasus.scodes.model.converter.TipoStatusProcessualEnumConverter;
import br.gov.datasus.scodes.model.enums.TipoAcaoContraEnum;
import br.gov.datasus.scodes.model.enums.TipoStatusProcessualEnum;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_PROCESSUAL", schema = "DBSCODES")
public class Processual extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_PROCESSUAL")
    @SequenceGenerator(name = "SEQ_GENERATOR_PROCESSUAL", sequenceName = "SQ_PROCESSUAL_COSEQPROCESSUAL", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_PROCESSUAL", nullable = false)
    private Long id;

    @Column(name = "ST_SEGREDO", nullable = false)
    private Boolean segredo;

    @Column(name = "TP_ACAO_CONTRA", nullable = false)
    @Convert(converter = TipoAcaoContraEnumConverter.class)
    private TipoAcaoContraEnum tipoAcaoContra;

    @ManyToOne
    @JoinColumn(name = "CO_PRAZO", nullable = false)
    private Prazo prazo;

    @ManyToOne
    @JoinColumn(name = "CO_VARA", nullable = false)
    private Vara vara;

    @ManyToOne
    @JoinColumn(name = "CO_AUTOR_DEMANDA", nullable = false)
    private AutorDemanda autorDemanda;

    @Column(name = "ST_DOC_COMPLETA")
    private Boolean docCompleta;

    @Column(name = "DT_NAO_COBRANCA_JUD")
    @Temporal(TemporalType.TIMESTAMP)
    private Date dataNaoCobrancaJud;

    @Column(name = "TP_STATUS", nullable = false)
    @Convert(converter = TipoStatusProcessualEnumConverter.class)
    private TipoStatusProcessualEnum status;

    @ManyToOne
    @JoinColumn(name = "CO_PROFISSIONAL")
    private Profissional profissional;

    @ManyToOne
    @JoinColumn(name = "CO_TIPO_PROFISSAO")
    private TipoProfissao tipoProfissao;

    @ManyToOne
    @JoinColumn(name = "CO_TIPO_ACAO")
    private TipoAcao tipoAcao;

    @ManyToOne
    @JoinColumn(name = "CO_CIDADE")
    private Cidade cidade;

}
