package br.gov.datasus.scodes.model.entity;

import java.util.List;

import javax.persistence.*;

import br.gov.datasus.api.core.model.entity.BaseEntity;

import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_PRODUTO", schema = "DBSCODES")
@NamedQuery(
    name = Produto.OBTER_TODOS_PAGINADO,
    query = "SELECT prod FROM Produto prod" +
        " INNER JOIN FETCH prod.categoria cat" +
        " INNER JOIN FETCH prod.tipoControlado tipoc" +
        " WHERE 1 = 1" +
        " AND (prod.id = :id)" +
        " AND (UPPER(prod.nome) LIKE UPPER(:nome))" +
        " AND (prod.categoria.id = :idCategoria)" +
        " AND (prod IN (SELECT t1.produto FROM Especificacao t1 WHERE t1.id = :idEspecificacao))" +
        " AND (prod IN (SELECT DISTINCT t1.produto FROM Especificacao t1 WHERE t1.grupoEspecificacao.id = :idGrupoEspecificacao))" +
        " AND (prod IN (SELECT DISTINCT t1.produto FROM Especificacao t1 INNER JOIN t1.itens t2 WHERE UPPER(t2.codigo) LIKE UPPER(:codigoItem)))"
)
@NamedQuery(name = Produto.OBTER_DOMINIO, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(prod.id, prod.nome) FROM Produto prod ORDER BY nome ASC")
public class Produto extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    public static final String OBTER_TODOS_PAGINADO = "Produto.obterTodosPaginado";
    public static final String OBTER_DOMINIO = "Produto.obterDominio";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_PRODUTO")
    @SequenceGenerator(name = "SEQ_GENERATOR_PRODUTO", sequenceName = "SQ_PRODUTO_COSEQPRODUTO", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_PRODUTO", nullable = false)
    private Long id;

    @ManyToOne
    @JoinColumn(name = "CO_CATEGORIA", nullable = false)
    private Categoria categoria;

    @ManyToOne
    @JoinColumn(name = "CO_TIPO_CONTROLADO", nullable = false)
    private TipoControlado tipoControlado;

    @Column(name = "NO_PRODUTO", length = 200, nullable = false)
    private String nome;

    @OneToMany(mappedBy = "produto")
    private List<Especificacao> especificacoes;

}
