package br.gov.datasus.scodes.model.entity;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import br.gov.datasus.scodes.model.converter.TipoMovimentacaoTipoEnumConverter;
import br.gov.datasus.scodes.model.enums.TipoMovimentacaoEnum;
import br.gov.datasus.scodes.model.enums.TipoMovimentacaoTipoEnum;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import javax.persistence.*;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Table(name = "TB_TIPO_MOVIMENTACAO", schema = "DBSCODES")
@NamedQuery(name = TipoMovimentacao.OBTER_TODOS_PAGINADO, query = "SELECT tm FROM TipoMovimentacao tm")
@NamedQuery(name = TipoMovimentacao.OBTER_DOMINIO, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(tm.id, tm.descricao) FROM TipoMovimentacao tm ORDER BY tm.descricao ASC")
@NamedQuery(name = TipoMovimentacao.OBTER_DOMINIO_POR_TIPO, query = "SELECT new br.gov.datasus.api.core.model.dto.DominioItemModel(tm.id, tm.descricao) FROM TipoMovimentacao tm WHERE tm.tipo = :tipo ORDER BY tm.descricao ASC")
public class TipoMovimentacao extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    public static final String OBTER_TODOS_PAGINADO = "TipoMovimentacao.obterTodosPaginado";
    public static final String OBTER_DOMINIO = "TipoMovimentacao.obterDominio";
    public static final String OBTER_DOMINIO_POR_TIPO = "TipoMovimentacao.obterDominioPorTipo";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_TIPO_MOVIMENTACAO")
    @SequenceGenerator(name = "SEQ_GENERATOR_TIPO_MOVIMENTACAO", sequenceName = "SQ_TIPOMOV_COSEQTIPOMOV", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_TIPO_MOVIMENTACAO", nullable = false)
    private Long id;

    @Column(name = "DS_TIPO_MOVIMENTACAO", length = 80, nullable = false)
    private String descricao;

    @Convert(converter = TipoMovimentacaoTipoEnumConverter.class)
    @Column(name = "TP_TIPO_MOVIMENTACAO", length = 1, nullable = false)
    private TipoMovimentacaoTipoEnum tipo;

    public static TipoMovimentacao of(TipoMovimentacaoEnum tipoMovimentacaoEnum) {
        TipoMovimentacao newInstance = new TipoMovimentacao();
        newInstance.setId(tipoMovimentacaoEnum.getCodigo());
        newInstance.setDescricao(tipoMovimentacaoEnum.getDescricao());
        newInstance.setTipo(tipoMovimentacaoEnum.getTipo());
        return newInstance;
    }
}
