package br.gov.datasus.scodes.model.entity;

import br.gov.datasus.api.core.model.entity.BaseEntity;
import br.gov.datasus.scodes.service.UsuarioLocalService;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import javax.persistence.*;
import java.util.Date;
import java.util.Set;

@Getter
@Setter
@NoArgsConstructor
@Entity
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "TB_USUARIO", schema = "DBSCODES")
@NamedQuery(name = Usuario.OBTER_TODOS_PAGINADO, query = "SELECT u FROM Usuario u " +
    "WHERE 1=1 " +
    "AND (UPPER(u.nomeLogin) LIKE UPPER(:nomeLogin))"
)
public class Usuario extends BaseEntity<Long> {

    private static final long serialVersionUID = 1L;

    public static final String OBTER_TODOS_PAGINADO = "Usuario.obterTodosPaginado";

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQ_GENERATOR_USUARIO")
    @SequenceGenerator(name = "SEQ_GENERATOR_USUARIO", sequenceName = "SQ_USUARIO_COSEQUSUARIO", initialValue = 1, allocationSize = 1, schema = "DBSCODES")
    @Column(name = "CO_SEQ_USUARIO", nullable = false)
    private Long id;

    @Column(name = "NO_LOGIN", length = 12, nullable = false)
    private String nomeLogin;

    @Column(name = "DS_SENHA", length = 32, nullable = false)
    private String descricaoSenha;

    @Column(name = "DS_EMAIL", length = 50, nullable = false)
    private String descricaoEmail;

    @Column(name = "ST_ATIVO", nullable = false)
    private Boolean situacaoAtivo;

    @Column(name = "ST_TRAVADO", nullable = false)
    private Boolean situacaoTravado;

    @Column(name = "NU_TENTATIVAS", nullable = false)
    private Long numeroTentativas;

    @Column(name = "DS_FALTA_ACESSO", length = 255)
    private String descricaoFaltaAcesso;

    @Column(name = "DT_CADASTRO", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    @Setter(AccessLevel.NONE)
    private Date dataCadastro;

    @Column(name = "DT_ULTIMO_ACESSO")
    @Temporal(TemporalType.TIMESTAMP)
    private Date dataUltimoAcesso;

    @ManyToMany
    @JoinTable(name = "RL_PERFIL_USUARIO", schema = "DBSCODES",
        joinColumns = {@JoinColumn(name = "CO_USUARIO")},
        inverseJoinColumns = {@JoinColumn(name = "CO_PERFIL"),
    })
    private Set<Perfil> perfis;

    @PrePersist
    public void prePersist() {
        this.dataCadastro = new Date();
        this.situacaoTravado = false;
        this.numeroTentativas = 0L;
    }

    public void setDescricaoSenha(String descricaoSenha) {
        this.descricaoSenha = UsuarioLocalService.hashPassword(descricaoSenha);
    }
}
