package br.gov.datasus.scodes.model.enums;

import java.util.Arrays;
import java.util.List;
import java.util.Optional;
import java.util.stream.Stream;

import com.fasterxml.jackson.annotation.JsonValue;

import lombok.Getter;

public enum TipoAcaoContraEnum {
    
    ESTADO("E","Estado"),
    MUNICIPIO("M","Município"),
    ESTADO_MUNICIPIO("EM","Estado + Município"),
    ESTADO_MUNICIPIO_UNIAO("UEM","Estado + Município + União"),
    ESTADO_UNIAO("UE","Estado + União"),
    MUNICIPIO_UNIAO("UM","Município + União");
    
    private TipoAcaoContraEnum(String id, String descricao) {
        this.id = id;
        this.descricao = descricao;
    }

    @JsonValue
    @Getter
    private String id;

    @Getter
    private String descricao;
    
    @Override
    public String toString() {
        return this.descricao;
    }

    public static Optional<TipoAcaoContraEnum> obterPorId(final String id) {
        return TipoAcaoContraEnum.stream().filter(e -> e.getId().equals(id)).findFirst();
    }

    public static Optional<TipoAcaoContraEnum> obterPorDescricao(final String descricao) {
        return TipoAcaoContraEnum.stream().filter(e -> e.getDescricao().equals(descricao)).findFirst();
    }

    public static Stream<TipoAcaoContraEnum> stream() {
        return Stream.of(TipoAcaoContraEnum.values());
    }

    public static List<TipoAcaoContraEnum> list() {
        return Arrays.asList(TipoAcaoContraEnum.values());
    }
}
