package br.gov.datasus.scodes.model.enums;

import java.util.Arrays;
import java.util.List;
import java.util.Optional;
import java.util.stream.Stream;

import com.fasterxml.jackson.annotation.JsonValue;

import lombok.Getter;

public enum TipoStatusProcessualEnum {
    
    VIGENTE("V","Vigente"),
    PENDENTE("P","Pendente"),
    SUBSTITUIDA("S","Substituida"),
    NENHUM("N","Nenhum");
    
    private TipoStatusProcessualEnum(String id, String descricao) {
        this.id = id;
        this.descricao = descricao;
    }

    @JsonValue
    @Getter
    private String id;

    @Getter
    private String descricao;
    
    @Override
    public String toString() {
        return this.descricao;
    }

    public static Optional<TipoStatusProcessualEnum> obterPorId(final String id) {
        return TipoStatusProcessualEnum.stream().filter(e -> e.getId().equals(id)).findFirst();
    }

    public static Optional<TipoStatusProcessualEnum> obterPorDescricao(final String descricao) {
        return TipoStatusProcessualEnum.stream().filter(e -> e.getDescricao().equals(descricao)).findFirst();
    }

    public static Stream<TipoStatusProcessualEnum> stream() {
        return Stream.of(TipoStatusProcessualEnum.values());
    }

    public static List<TipoStatusProcessualEnum> list() {
        return Arrays.asList(TipoStatusProcessualEnum.values());
    }
}
