package br.gov.datasus.scodes.model.enums;

import br.gov.datasus.api.core.model.annotations.Dominio;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.io.Serializable;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;
import java.util.stream.Stream;

@Dominio("Tipo de Transferência")
@AllArgsConstructor
public enum TipoTransferenciaEnum implements Serializable {
    ENTRADA(1, "Entrada"),
    SAIDA(2, "Saída");

    @JsonValue
    @Getter
    private final Integer codigo;

    @Getter
    private final String descricao;

    @Override
    public String toString() {
        return this.codigo.toString();
    }

    public static Optional<TipoTransferenciaEnum> obterPorCodigo(final Integer codigo) {
        return TipoTransferenciaEnum.stream().filter(e -> e.getCodigo().equals(codigo)).findFirst();
    }

    public static Optional<TipoTransferenciaEnum> obterPorDescricao(final String descricao) {
        return TipoTransferenciaEnum.stream().filter(e -> e.getDescricao().equals(descricao)).findFirst();
    }

    public static Stream<TipoTransferenciaEnum> stream() {
        return Stream.of(TipoTransferenciaEnum.values());
    }

    public static List<TipoTransferenciaEnum> list() {
        return Arrays.asList(TipoTransferenciaEnum.values());
    }
}
