package br.gov.datasus.scodes.model.mapper;

import br.gov.datasus.api.core.model.mapper.BaseMapper;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.InventarioItemDTO;
import br.gov.datasus.scodes.model.entity.InventarioItem;
import org.mapstruct.*;

import java.util.List;

@Mapper(componentModel = "spring", unmappedTargetPolicy = ReportingPolicy.IGNORE)
public interface InventarioItemMapper extends BaseMapper<InventarioItem, InventarioItemDTO> {

    @Named("toDto")
    @Mappings({
        @Mapping(source = "inventario.id", target = "idInventario"),
        @Mapping(source = "item.id", target = "idItem"),
        @Mapping(source = "item.codigo", target = "codigoItem"),
        @Mapping(source = "item.descricao", target = "descricaoItem"),
        @Mapping(source = "item.especificacao.nome", target = "unidadeMedida"),
    })
	InventarioItemDTO toDto(InventarioItem entity);

    @IterableMapping(qualifiedByName = "toDto")
	List<InventarioItemDTO> toDto(List<InventarioItem> entities);

    @IterableMapping(qualifiedByName = "toDto")
	List<InventarioItemDTO> toDto(Iterable<InventarioItem> entities);

    @IterableMapping(qualifiedByName = "toDto")
    PageableResponseModel<InventarioItemDTO> toDtoPageableResponse(PageableResponseModel<InventarioItem> pageableResponseModel);

    @Named("toEntity")
    @Mappings({
        @Mapping(source = "idInventario", target = "inventario.id"),
        @Mapping(source = "idItem", target = "item.id"),
    })
    InventarioItem toEntity(InventarioItemDTO dto);

    @IterableMapping(qualifiedByName = "toEntity")
	List<InventarioItem> toEntity(List<InventarioItemDTO> dtos);

    @InheritConfiguration(name = "toEntity")
	void fromDto(InventarioItemDTO dto, @MappingTarget InventarioItem entity);
}
