package br.gov.datasus.scodes.model.mapper;

import java.util.List;

import org.mapstruct.*;

import br.gov.datasus.api.core.model.mapper.BaseMapper;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.AreaDTO;
import br.gov.datasus.scodes.model.dto.PerfilDTO;
import br.gov.datasus.scodes.model.dto.PerfilFuncionalidadeDTO;
import br.gov.datasus.scodes.model.entity.Area;
import br.gov.datasus.scodes.model.entity.Perfil;
import br.gov.datasus.scodes.model.entity.PerfilFuncionalidade;

@Mapper(componentModel = "spring", unmappedTargetPolicy = ReportingPolicy.IGNORE)
public interface PerfilMapper extends BaseMapper<Perfil, PerfilDTO> {
	PerfilDTO toDto(Perfil entity);
	
	@IterableMapping(qualifiedByName="toDtoWithoutFuncionalidades")
	List<PerfilDTO> toDto(List<Perfil> entities);
	
	@IterableMapping(qualifiedByName="toDtoWithoutFuncionalidades")
	List<PerfilDTO> toDto(Iterable<Perfil> entities);
	
	@IterableMapping(qualifiedByName="toDtoWithoutFuncionalidades")
	PageableResponseModel<PerfilDTO> toDtoPageableResponse(PageableResponseModel<Perfil> pageableResponseModel);

	Perfil toEntity(PerfilDTO dto);

	List<Perfil> toEntity(List<PerfilDTO> dtos);

	@InheritInverseConfiguration(name = "toDto")
	void fromDto(PerfilDTO dto, @MappingTarget Perfil entity);
	
	@Named("toDtoWithoutFuncionalidades")
    @Mapping(target = "perfilFuncionalidades", ignore = true)
	PerfilDTO toDtoWithoutFuncionalidades(Perfil entity);
	
	AreaDTO areaToDto(Area entity);

	Area areaFromDto(AreaDTO dto);
	
	@Mapping(source = "id.funcionalidade", target = "funcionalidade")
	PerfilFuncionalidadeDTO perfilFuncionalidadeToDto(PerfilFuncionalidade entity);
	
	@InheritInverseConfiguration(name = "perfilFuncionalidadeToDto")
	PerfilFuncionalidade perfilFuncionalidadeFromDto(PerfilFuncionalidadeDTO dto);
	
	@AfterMapping
    default void afterMapEntity(@MappingTarget Perfil perfil) {
		List<PerfilFuncionalidade> perfilFuncionalidades = perfil.getPerfilFuncionalidades();
		if (perfilFuncionalidades != null) {
			perfilFuncionalidades.forEach(perfilFuncionalidade -> perfilFuncionalidade.getId().setPerfil(perfil));
		}
    }
}