package br.gov.datasus.scodes.model.mapper;

import br.gov.datasus.api.core.model.mapper.BaseMapper;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.*;
import br.gov.datasus.scodes.model.entity.*;
import org.mapstruct.*;

import java.util.List;

@Mapper(componentModel = "spring", unmappedTargetPolicy = ReportingPolicy.IGNORE)
public interface UsuarioLocalMapper extends BaseMapper<UsuarioLocal, UsuarioLocalDTO> {

    UsuarioLocalDTO toDto(UsuarioLocal entity);

    @Named("toSimpleDto")
    @InheritConfiguration(name = "toDto")
    @Mappings({
        @Mapping(target = "perfil", ignore = true),
        @Mapping(target = "perfis", ignore = true),
        @Mapping(target = "unidadesDispensadoras", ignore = true),
        @Mapping(target = "unidadeOrganizacional", ignore = true),
        @Mapping(target = "tipoProfissao", ignore = true),
        @Mapping(target = "numeroConselho", ignore = true),
    })
    UsuarioLocalDTO toSimpleDto(UsuarioLocal entity);

    @IterableMapping(qualifiedByName = "toSimpleDto")
    List<UsuarioLocalDTO> toDto(List<UsuarioLocal> entities);

    @IterableMapping(qualifiedByName = "toSimpleDto")
    List<UsuarioLocalDTO> toDto(Iterable<UsuarioLocal> entities);

    @IterableMapping(qualifiedByName = "toSimpleDto")
    PageableResponseModel<UsuarioLocalDTO> toDtoPageableResponse(PageableResponseModel<UsuarioLocal> pageableResponseModel);

    @InheritInverseConfiguration(name = "toDto")
    @Mappings({
        @Mapping(target = "descricaoSenha", ignore = true),
        @Mapping(target = "numeroTentativas", ignore = true),
        @Mapping(target = "situacaoTravado", ignore = true),
        @Mapping(target = "descricaoFaltaAcesso", ignore = true),
        @Mapping(target = "dataCadastro", ignore = true),
        @Mapping(target = "dataUltimoAcesso", ignore = true),
    })
    UsuarioLocal toEntity(UsuarioLocalDTO dto);

    List<UsuarioLocal> toEntity(List<UsuarioLocalDTO> dtos);

    @InheritConfiguration(name = "toEntity")
    void fromDto(UsuarioLocalDTO dto, @MappingTarget UsuarioLocal entity);

    @Mapping(target = "descricaoSenha", source = "novaSenha")
    void fromDto(UsuarioLocalSenhaDTO dto, @MappingTarget UsuarioLocal entity);

    @Mapping(target = "descricaoEmail", source = "email")
    void fromDto(UsuarioLocalCadastroDTO dto, @MappingTarget UsuarioLocal entity);

    @Mapping(target = "perfilFuncionalidades", source = "perfilFuncionalidades", ignore = true)
    PerfilDTO perfilToDto(Perfil entity);

    @InheritInverseConfiguration(name = "perfilToDto")
    Perfil perfilToEntity(PerfilDTO dto);

    TipoProfissaoDTO tipoProfissaoToDto(TipoProfissao entity);

    TipoProfissao tipoProfissaoToEntity(TipoProfissaoDTO dto);

    UnidadeOrganizacionalDTO unidadeOrganizacionalToDto(UnidadeOrganizacional entity);

    UnidadeOrganizacional unidadeOrganizacionalToEntity(UnidadeOrganizacionalDTO dto);

    UnidadeDispensadoraDTO unidadeDispensadoraToDto(UnidadeDispensadora entity);

    UnidadeDispensadora unidadeDispensadoraToEntity(UnidadeDispensadoraDTO dto);

    @AfterMapping
    default void afterMapping(UsuarioLocalDTO dto, @MappingTarget UsuarioLocal entity) {
        if (dto.getDescricaoSenha() != null) {
            entity.setDescricaoSenha(dto.getDescricaoSenha());
        }
    }
}
