package br.gov.datasus.scodes.report.builder;

import br.gov.datasus.scodes.model.dto.ArquivoBase64DTO;
import br.gov.datasus.scodes.model.dto.ResultadoRelatorioDataRetornoDemandaDTO;
import br.gov.datasus.scodes.model.entity.AlteracaoDataRetorno;
import br.gov.datasus.scodes.service.ReportService;
import lombok.RequiredArgsConstructor;
import net.sf.jasperreports.engine.data.JRBeanCollectionDataSource;
import org.springframework.stereotype.Component;
import org.thymeleaf.TemplateEngine;
import org.thymeleaf.context.Context;

import java.io.ByteArrayOutputStream;
import java.nio.charset.StandardCharsets;
import java.util.*;
import java.util.stream.Collectors;

import static br.gov.datasus.scodes.report.builder.util.ConstantsJasper.*;

@Component
@RequiredArgsConstructor
public class AlteracaoDataRetornoReportBuilder {

    private static final String RELATORIO_DATA_RETORNO_AUTOR_DEMANDA = "relatorio_data_retorno_autor_demanda";
    private static final String TXT = ".txt";
    private static final String CSV = ".csv";

    private final ReportService reportService;
    private final TemplateEngine templateEngine;

    public ArquivoBase64DTO gerarRelatorioPdf(String reportName, AlteracaoDataRetorno entity, List<?> itens) {

        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put(PARAM_ADR_TITULO, entity.getTitulo());
        parameters.put(PARAM_ADR_DATA_RETORNO, entity.getNovaDataRetorno());
        parameters.put(PARAM_ADR_STATUS, entity.getStatus().getDescricao());
        parameters.put(PARAM_ADR_DATA_IMPRESSAO, new Date());

        ByteArrayOutputStream outputStream = reportService.exportToPDF(
            "classpath:/jasperreports/" + reportName + ".jasper",
            parameters,
            new JRBeanCollectionDataSource(itens)
        );

        return new ArquivoBase64DTO(
            Base64.getEncoder().encodeToString(outputStream.toByteArray()),
            reportName + ".pdf",
            "application/pdf"
        );
    }

    public ArquivoBase64DTO gerarRelatorioCsv(List<ResultadoRelatorioDataRetornoDemandaDTO> resultados) {
        List<Map<String, Object>> itens = resultados.stream()
                                            .map(this::parseItem).collect(Collectors.toList());
        Context ctx = new Context(Locale.getDefault());
        ctx.setVariable("itens", itens);
        String csv = this.templateEngine.process(new StringBuilder().append(RELATORIO_DATA_RETORNO_AUTOR_DEMANDA).append(TXT).toString(), ctx);
        String base64 = Base64.getEncoder().encodeToString(csv.getBytes(StandardCharsets.UTF_8));
        return new ArquivoBase64DTO(base64, new StringBuilder().append(RELATORIO_DATA_RETORNO_AUTOR_DEMANDA).append(CSV).toString(), "text/csv");
    }

    private Map<String, Object> parseItem(ResultadoRelatorioDataRetornoDemandaDTO r) {
        Map<String, Object> item = new HashMap<>();
        item.put("tipoDemanda", r.getTipoDemanda());
        item.put("dataCadastro", r.getDataCadastro());
        item.put("codigoDemanda", r.getCodigoDemanda());
        item.put("autor", r.getAutor());
        item.put("protocolo", r.getProtocolo());
        item.put("processo", r.getProcesso());
        item.put("descricaoUnidadeDispensadora", r.getDescricaoUnidadeDispensadora());
        item.put("descricaoCategoria", r.getDescricaoCategoria());
        item.put("codigoProduto", r.getCodigoProduto());
        item.put("descricaoItem", r.getDescricaoItem());
        item.put("quantidadeProduto", r.getQuantidadeProduto());
        item.put("dataRetornoAnterior", r.getDataRetornoAnterior());
        item.put("dataRetornoAtual", r.getDataRetornoAtual());
        return item;
    }
}
