package br.gov.datasus.scodes.service;

import java.util.*;
import java.util.stream.Collectors;

import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.scodes.model.dto.AlteracaoDataRetornoDTO;
import br.gov.datasus.scodes.model.dto.StatusAlteracaoDataRetornoDTO;
import br.gov.datasus.scodes.model.entity.AlteracaoDataRetorno;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.scodes.model.dto.AutorDTO;
import br.gov.datasus.scodes.model.entity.Autor;
import br.gov.datasus.scodes.model.mapper.AutorMapper;
import br.gov.datasus.scodes.repository.AutorRepository;
import lombok.RequiredArgsConstructor;

import static java.util.Objects.nonNull;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class AutorService {

    private final AutorRepository repository;
    private final AutorMapper mapper;

    public List<AutorDTO> pesquisarAutorPorCpf(String cpf) {
        DynamicParameters parameters = DynamicParameters.get();
        parameters.append("cpf", cpf+"%");
        List<Autor> lista = repository.findAll(Autor.PESQUISAR_POR_CPF, parameters, Autor.class);
        return mapper.toDto(lista);
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public Set<AutorDTO> salvar(final Set<AutorDTO> autoresDTO) {
        return autoresDTO
                .stream()
                .map(this::parseAlterarOuIncluir)
                .collect(Collectors.toSet());
    }

    private AutorDTO parseAlterarOuIncluir(final AutorDTO dto) {
        return nonNull(dto.getId()) ? alterar(dto) : incluir(dto);
    }


    private AutorDTO incluir(final AutorDTO dto) {
        Autor entity = mapper.toEntity(dto);
        return mapper.toDto(repository.save(entity));
    }

    private AutorDTO alterar(final AutorDTO dto) {
        Autor entity = obterEntityPorId(dto.getId());
        dto.setId(dto.getId());
        mapper.fromDto(dto, entity);
        return mapper.toDto(repository.save(entity));
    }

    public AutorDTO buscarPorId(Long id) {
        return mapper.toDto(obterEntityPorId(id));
    }

    private Autor obterEntityPorId(Long id) {
        Optional<Autor> one = repository.findById(id);
        return one.orElseThrow(ResourceNotFoundException::new);
    }

}
