package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.entity.Categoria;
import br.gov.datasus.scodes.model.dto.CategoriaDTO;
import br.gov.datasus.scodes.model.dto.filter.CategoriaFilterDTO;
import br.gov.datasus.scodes.model.mapper.CategoriaMapper;
import br.gov.datasus.scodes.repository.CategoriaRepository;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class CategoriaService {

    private final CategoriaRepository repository;
    private final CategoriaMapper mapper;
    public CategoriaDTO obterPorId(Long id) {
        Optional<Categoria> one = repository.findById(id);
        Categoria entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<CategoriaDTO> obterTodos() {
        Iterable<Categoria> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<CategoriaDTO> obterTodosPaginado(PageableRequestModel<CategoriaFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "categoria");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<Categoria> pageableResponseModel = repository.findAll(Categoria.OBTER_TODOS_PAGINADO, parameters, pagination, Categoria.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

}
