package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.repository.CidadeRepository;
import br.gov.datasus.scodes.model.dto.filter.CidadeFilterDTO;
import br.gov.datasus.scodes.model.entity.Cidade;
import br.gov.datasus.scodes.model.dto.CidadeDTO;
import br.gov.datasus.scodes.model.mapper.CidadeMapper;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class CidadeService {

    private final CidadeRepository repository;
    private final CidadeMapper mapper;
    public CidadeDTO obterPorId(Long id) {
        Optional<Cidade> one = repository.findById(id);
        Cidade entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<CidadeDTO> obterTodos() {
        Iterable<Cidade> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<CidadeDTO> obterTodosPaginado(PageableRequestModel<CidadeFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "cidade");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<Cidade> pageableResponseModel = repository.findAll(Cidade.OBTER_TODOS_PAGINADO, parameters, pagination, Cidade.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

    public List<CidadeDTO> obterCidadesPorUf(String id) {
        DynamicParameters parameters = DynamicParameters.get();
        parameters.append("id", id);
        Iterable<Cidade> itens = repository.findAll(Cidade.OBTER_CIDADES_POR_UF, parameters, Cidade.class);
        return mapper.toDto(itens);
    }

    public List<CidadeDTO> obterCidadesPorNome(String nome, String uf) {
        DynamicParameters parameters = DynamicParameters.get();
        parameters.appendLike("nome", nome);
        parameters.append("uf", uf);
        Iterable<Cidade> itens = repository.findAll(Cidade.OBTER_CIDADES_POR_NOME, parameters, Cidade.class);
        return mapper.toDto(itens);
    }

}
