package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.CompraModalidadeDTO;
import br.gov.datasus.scodes.model.entity.CompraModalidade;
import br.gov.datasus.scodes.model.mapper.CompraModalidadeMapper;
import br.gov.datasus.scodes.repository.CompraModalidadeRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
@RequiredArgsConstructor
@Transactional(propagation = Propagation.SUPPORTS)
public class CompraModalidadeService {

	private final CompraModalidadeRepository repository;
	private final CompraModalidadeMapper mapper;

	public CompraModalidadeDTO obterPorId(Long id) {
		CompraModalidade entity = repository.findById(id).orElseThrow(ResourceNotFoundException::new);
		return mapper.toDto(entity);
	}

	public List<CompraModalidadeDTO> obterTodos() {
		Iterable<CompraModalidade> itens = repository.findAll();
		return mapper.toDto(itens);
	}

    public PageableResponseModel<CompraModalidadeDTO> obterTodosPaginado(PageableRequestModel<Void> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "cm");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<CompraModalidade> pageableResponseModel = repository.findAll(CompraModalidade.OBTER_TODOS_PAGINADO,
            parameters, pagination, CompraModalidade.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }
	
	public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }
}
