package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.exception.BusinessException;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.scodes.configuration.properties.MessageProperty;
import br.gov.datasus.scodes.model.dto.EstoqueAuxiliarDTO;
import br.gov.datasus.scodes.model.entity.*;
import br.gov.datasus.scodes.model.entity.Id.EstoqueAuxiliarId;
import br.gov.datasus.scodes.model.mapper.EstoqueAuxiliarMapper;
import br.gov.datasus.scodes.repository.EstoqueAuxiliarRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

@Service
@RequiredArgsConstructor
@Transactional(propagation = Propagation.SUPPORTS)
public class EstoqueAuxiliarService {

	private final EstoqueAuxiliarRepository repository;
	private final EstoqueAuxiliarMapper mapper;

    public EstoqueAuxiliarDTO obterPorId(EstoqueAuxiliarId id) {
        EstoqueAuxiliar entity = repository.findById(id).orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

	public EstoqueAuxiliarDTO obterPorId(Long idItem, Long idUnidadeDispensadora) {
        return obterPorId(EstoqueAuxiliarId.of(idItem, idUnidadeDispensadora));
    }

    public EstoqueAuxiliarDTO obterPorId(Item item, UnidadeDispensadora unidadeDispensadora) {
        return obterPorId(EstoqueAuxiliarId.of(item, unidadeDispensadora));
    }

	public Long obterQuantidade(EstoqueAuxiliarId id) {
        return repository.findQuantidadeEstoque(id).orElse(0L);
    }

    public Long obterQuantidade(Item item, UnidadeDispensadora unidadeDispensadora) {
        return obterQuantidade(EstoqueAuxiliarId.of(item, unidadeDispensadora));
    }

	public Long obterQuantidade(Long idItem, Long idUnidadeDispensadora) {
	    return obterQuantidade(EstoqueAuxiliarId.of(idItem, idUnidadeDispensadora));
    }

    @Transactional(propagation = Propagation.REQUIRED)
	public Long adicionarEstoque(EntradaEstoqueItem entradaItem) {
        EstoqueAuxiliarId id = EstoqueAuxiliarId.of(entradaItem.getItem(), entradaItem.getUnidadeDispensadora());
        findOrCreate(id);
        repository.adicionarEstoque(id, entradaItem.getQuantidadeFinal());
        return obterQuantidade(id);
    }

    @Transactional(propagation = Propagation.REQUIRED)
    public Long removerEstoque(SaidaEstoqueItem saidaItem) {
        EstoqueAuxiliarId id = EstoqueAuxiliarId.of(saidaItem.getItem(), saidaItem.getUnidadeDispensadora());
        EstoqueAuxiliar entity = findOrCreate(id);
        if (saidaItem.getQuantidade() > entity.getQuantidadeItem()) {
            throw new BusinessException(MessageProperty.QTD_SAIDA_ESTOQUE);
        }
        repository.removerEstoque(id, saidaItem.getQuantidade());
        return obterQuantidade(id);
    }

    private EstoqueAuxiliar findOrCreate(EstoqueAuxiliarId id) {
        return repository.findById(id).orElseGet(() -> {
            EstoqueAuxiliar entity = new EstoqueAuxiliar();
            entity.setId(id);
            entity.setQuantidadeItem(0L);
            repository.save(entity);
            return entity;
        });
    }

}
