package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.dto.FeriadoDTO;
import br.gov.datasus.scodes.model.entity.Feriado;
import br.gov.datasus.scodes.model.mapper.FeriadoMapper;
import br.gov.datasus.scodes.repository.FeriadoRepository;
import br.gov.datasus.scodes.util.DataUtil;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Optional;

@Service
@RequiredArgsConstructor
@Transactional(propagation = Propagation.SUPPORTS)
public class FeriadoService {

    private final FeriadoRepository repository;
    private final FeriadoMapper mapper;
    private final DataUtil dataUtil;

    public FeriadoDTO buscarPorDataFeriado(String date) {
        LocalDate localDate = LocalDate.parse(date);
        return buscarPorDataFeriado(dataUtil.convertToDate(localDate));
    }

    public FeriadoDTO buscarPorDataFeriado(Date dataFeriado) {

        Feriado entity = repository.findByDataFeriado(dataFeriado);
        if (Objects.isNull(entity)) {
            return new FeriadoDTO();
        }
        return mapper.toDto(entity);
    }

    public List<FeriadoDTO> obterTodos() {
        Iterable<Feriado> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public Boolean isDataRetornoFeriado(Date dataRetorno) {
        FeriadoDTO dto = buscarPorDataFeriado(dataRetorno);
        Date date = Optional.ofNullable(dto.getDataFeriado()).orElse(null);
        return dataRetorno.equals(date) ? Boolean.TRUE : Boolean.FALSE;
    }
}
