package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.FornecedorDTO;
import br.gov.datasus.scodes.model.entity.Fornecedor;
import br.gov.datasus.scodes.model.mapper.FornecedorMapper;
import br.gov.datasus.scodes.repository.FornecedorRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
@RequiredArgsConstructor
@Transactional(propagation = Propagation.SUPPORTS)
public class FornecedorService {

	private final FornecedorRepository repository;
	private final FornecedorMapper mapper;

	public FornecedorDTO obterPorId(Long id) {
		Fornecedor entity = repository.findById(id).orElseThrow(ResourceNotFoundException::new);
		return mapper.toDto(entity);
	}

	public List<FornecedorDTO> obterTodos() {
		Iterable<Fornecedor> itens = repository.findAll();
		return mapper.toDto(itens);
	}

    public PageableResponseModel<FornecedorDTO> obterTodosPaginado(PageableRequestModel<Void> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "fo");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<Fornecedor> pageableResponseModel = repository.findAll(Fornecedor.OBTER_TODOS_PAGINADO,
            parameters, pagination, Fornecedor.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }
	
	public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }
}
