package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.dto.MarcaDTO;
import br.gov.datasus.scodes.model.dto.filter.MarcaFilterDTO;
import br.gov.datasus.scodes.model.entity.Marca;
import br.gov.datasus.scodes.repository.MarcaRepository;
import br.gov.datasus.scodes.model.mapper.MarcaMapper;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class MarcaService {

    private final MarcaRepository repository;
    private final MarcaMapper mapper;
    public MarcaDTO obterPorId(Long id) {
        Optional<Marca> one = repository.findById(id);
        Marca entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<MarcaDTO> obterTodos() {
        Iterable<Marca> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<MarcaDTO> obterTodosPaginado(PageableRequestModel<MarcaFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "marca");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<Marca> pageableResponseModel = repository.findAll(Marca.OBTER_TODOS_PAGINADO, parameters, pagination, Marca.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

}
