package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.scodes.model.dto.ProdutoDTO;
import br.gov.datasus.scodes.model.dto.ProgramaDTO;
import br.gov.datasus.scodes.model.dto.ReciboOrdemProdutoDTO;
import br.gov.datasus.scodes.model.entity.AlteracaoDataRetorno;
import br.gov.datasus.scodes.model.entity.Produto;
import br.gov.datasus.scodes.model.entity.Programa;
import br.gov.datasus.scodes.model.entity.ReciboOrdemProduto;
import br.gov.datasus.scodes.model.mapper.ReciboOrdemProdutoMapper;
import br.gov.datasus.scodes.repository.ReciboOrdemProdutoRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Optional;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class ReciboOrdemProdutoService {

    private final ReciboOrdemProdutoRepository repository;
    private final ReciboOrdemProdutoMapper mapper;

    public ReciboOrdemProdutoDTO obterPorId(Long id) {
        ReciboOrdemProduto entity = obterEntityPorId(id);
        return mapper.toDto(entity);
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public ReciboOrdemProdutoDTO alterar(Long id, ReciboOrdemProdutoDTO dto) {
        ReciboOrdemProduto entity = obterEntityPorId(id);
        dto.setId(id);
        mapper.fromDto(dto, entity);
        return mapper.toDto(repository.save(entity));
    }

    private ReciboOrdemProduto obterEntityPorId(Long id) {
        Optional<ReciboOrdemProduto> one = repository.findById(id);
        return one.orElseThrow(ResourceNotFoundException::new);
    }
}
