package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.exception.InfraException;
import lombok.RequiredArgsConstructor;
import net.sf.jasperreports.engine.JRDataSource;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.export.JRPdfExporter;
import net.sf.jasperreports.engine.export.ooxml.JRXlsxExporter;
import net.sf.jasperreports.export.SimpleExporterInput;
import net.sf.jasperreports.export.SimpleOutputStreamExporterOutput;
import net.sf.jasperreports.renderers.ResourceRenderer;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Map;

@Service
@RequiredArgsConstructor
@Transactional(propagation = Propagation.SUPPORTS)
public class ReportService {

	private final ApplicationContext applicationContext;

    public ByteArrayOutputStream exportToPDF(String path, Map<String, Object> parameters, JRDataSource dataSource) {
        JasperPrint print = fillReport(path, parameters, dataSource);

        ByteArrayOutputStream output = new ByteArrayOutputStream();
        try {
            JRPdfExporter exporter = new JRPdfExporter();
            exporter.setExporterInput(new SimpleExporterInput(print));
            exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(output));
            exporter.exportReport();
        } catch (JRException e) {
            throw new InfraException(e);
        }

        return output;
    }

    public ByteArrayOutputStream exportToXLSX(String path, Map<String, Object> parameters, JRDataSource dataSource) {
        JasperPrint print = fillReport(path, parameters, dataSource);

        ByteArrayOutputStream output = new ByteArrayOutputStream();
        try {
            JRXlsxExporter exporter = new JRXlsxExporter();
            exporter.setExporterInput(new SimpleExporterInput(print));
            exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(output));
            exporter.exportReport();
        } catch (JRException e) {
            throw new InfraException(e);
        }

        return output;
    }

    private JasperPrint fillReport(String path, Map<String, Object> parameters, JRDataSource dataSource) {
        if (!parameters.containsKey("REPORT_DIR")) {
            parameters.put("REPORT_DIR", "classpath:/jasperreports/");
        }
        try (InputStream input = applicationContext.getResource(path).getInputStream()) {
            return JasperFillManager.fillReport(input, parameters, dataSource);
        } catch (IOException | JRException e) {
            throw new InfraException(e);
        }
    }
    
}
