package br.gov.datasus.scodes.service;

import java.util.List;
import java.util.Optional;

import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.TipoAcaoDTO;
import br.gov.datasus.scodes.model.dto.filter.TipoAcaoFilterDTO;
import br.gov.datasus.scodes.model.entity.TipoAcao;
import br.gov.datasus.scodes.model.mapper.TipoAcaoMapper;
import br.gov.datasus.scodes.repository.TipoAcaoRepository;
import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoAcaoService {

    private final TipoAcaoRepository repository;
    private final TipoAcaoMapper mapper;
    public TipoAcaoDTO obterPorId(Long id) {
        Optional<TipoAcao> one = repository.findById(id);
        TipoAcao entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<TipoAcaoDTO> obterTodos() {
        Iterable<TipoAcao> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<TipoAcaoDTO> obterTodosPaginado(PageableRequestModel<TipoAcaoFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "tipoAcao");
        DynamicParameters parameters = DynamicParameters.get();
        Optional<TipoAcaoFilterDTO> optionalFilter = pageableModel.getFilter();
        if (optionalFilter.isPresent()) {
            TipoAcaoFilterDTO filter = optionalFilter.get();
            if (filter.getDescricao() != null) {
                parameters.appendLike("descricao", filter.getDescricao(), "¿");
            }
        }
        PageableResponseModel<TipoAcao> pageableResponseModel = repository.findAll(TipoAcao.OBTER_TODOS_PAGINADO, parameters, pagination, TipoAcao.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public TipoAcaoDTO incluir(TipoAcaoDTO dto) {
        TipoAcao entity = mapper.toEntity(dto);
        return mapper.toDto(repository.save(entity));
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public TipoAcaoDTO alterar(Long id, TipoAcaoDTO dto) {
        Optional<TipoAcao> one = repository.findById(id);
        TipoAcao entity = one.orElseThrow(() -> new ResourceNotFoundException());
        dto.setId(id);
        mapper.fromDto(dto, entity);
        repository.save(entity);
        return mapper.toDto(entity);
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public void excluir(Long id) {
        Optional<TipoAcao> one = repository.findById(id);
        TipoAcao entity = one.orElseThrow(() -> new ResourceNotFoundException());
        repository.delete(entity);
    }
}
