package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.TipoCobrancaDTO;
import br.gov.datasus.scodes.model.dto.filter.TipoCobrancaFilterDTO;
import br.gov.datasus.scodes.model.entity.TipoCobranca;
import br.gov.datasus.scodes.model.mapper.TipoCobrancaMapper;
import br.gov.datasus.scodes.repository.TipoCobrancaRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Optional;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoCobrancaService {

    private final TipoCobrancaRepository repository;
    private final TipoCobrancaMapper mapper;
    public TipoCobrancaDTO obterPorId(Long id) {
        Optional<TipoCobranca> one = repository.findById(id);
        TipoCobranca entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<TipoCobrancaDTO> obterTodos() {
        Iterable<TipoCobranca> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<TipoCobrancaDTO> obterTodosPaginado(PageableRequestModel<TipoCobrancaFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "tipoCobranca");
        DynamicParameters parameters = DynamicParameters.get();
        parameters.appendLike("descricao", pageableModel.getFilter().get().getDescricao());
        PageableResponseModel<TipoCobranca> pageableResponseModel = repository.findAll(TipoCobranca.OBTER_TODOS_PAGINADO, parameters, pagination, TipoCobranca.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public TipoCobrancaDTO incluir(TipoCobrancaDTO dto) {
        TipoCobranca entity = mapper.toEntity(dto);
        return mapper.toDto(repository.save(entity));
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public TipoCobrancaDTO alterar(Long id, TipoCobrancaDTO dto) {
        Optional<TipoCobranca> one = repository.findById(id);
        TipoCobranca entity = one.orElseThrow(() -> new ResourceNotFoundException());
        dto.setId(id);
        mapper.fromDto(dto, entity);
        repository.save(entity);
        return mapper.toDto(entity);
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public void excluir(Long id) {
        Optional<TipoCobranca> one = repository.findById(id);
        TipoCobranca entity = one.orElseThrow(() -> new ResourceNotFoundException());
        repository.delete(entity);
    }
}
