package br.gov.datasus.scodes.service;

import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import br.gov.datasus.api.core.exception.BusinessException;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.scodes.configuration.properties.MessageProperty;
import br.gov.datasus.scodes.model.dto.TipoDemandaDTO;
import br.gov.datasus.scodes.model.entity.TipoDemanda;
import br.gov.datasus.scodes.model.mapper.TipoDemandaMapper;
import br.gov.datasus.scodes.repository.TipoDemandaRepository;
import br.gov.datasus.scodes.repository.TipoModeloRepository;
import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoDemandaService {

    private final TipoModeloRepository tipoModeloRepository;
    private final TipoDemandaRepository repository;
    private final TipoDemandaMapper mapper;

    public TipoDemandaDTO obterPorId(Long id) {
        Optional<TipoDemanda> one = repository.findById(id);
        TipoDemanda entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<DominioItemModel> obterDominio(Long idTipoModelo) {
        if (idTipoModelo == null) {
            return repository.obterDominio();
        } else {
            return tipoModeloRepository
                .findById(idTipoModelo)
                .map(tipoModelo -> tipoModelo.getTipoDemandas())
                .orElseThrow(() -> new BusinessException(MessageProperty.TIPO_MODELO_NAO_ENCONTRADO))
                .stream()
                .map(tipoDemanda -> new DominioItemModel(tipoDemanda.getId(), tipoDemanda.getDescricao()))
                .collect(Collectors.toList());
        }
    }

    public List<TipoDemandaDTO> obterTipoDemanda(Long idTipoModelo) {
        if (idTipoModelo == null) {
            return mapper.toDto(repository.findAll());
        } else {
            List<TipoDemanda> list = tipoModeloRepository
                .findById(idTipoModelo)
                .map(tipoModelo -> tipoModelo.getTipoDemandas())
                .orElseThrow(() -> new BusinessException(MessageProperty.TIPO_MODELO_NAO_ENCONTRADO))
                .stream()
                .map(tipoDemanda -> tipoDemanda)
                .collect(Collectors.toList());
            return mapper.toDto(list);
        }
    }
}
