package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.dto.TipoDispensacaoDTO;
import br.gov.datasus.scodes.model.mapper.TipoDispensacaoMapper;
import br.gov.datasus.scodes.repository.TipoDispensacaoRepository;
import br.gov.datasus.scodes.model.entity.TipoDispensacao;
import br.gov.datasus.scodes.model.dto.filter.TipoDispensacaoFilterDTO;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoDispensacaoService {

    private final TipoDispensacaoRepository repository;
    private final TipoDispensacaoMapper mapper;
    public TipoDispensacaoDTO obterPorId(Long id) {
        Optional<TipoDispensacao> one = repository.findById(id);
        TipoDispensacao entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<TipoDispensacaoDTO> obterTodos() {
        Iterable<TipoDispensacao> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<TipoDispensacaoDTO> obterTodosPaginado(PageableRequestModel<TipoDispensacaoFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "tipoDispensacao");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<TipoDispensacao> pageableResponseModel = repository.findAll(TipoDispensacao.OBTER_TODOS_PAGINADO, parameters, pagination, TipoDispensacao.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

}
