package br.gov.datasus.scodes.service;

import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.model.dto.DominioItemModel;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.scodes.model.dto.TipoDocumentoDTO;
import br.gov.datasus.scodes.model.dto.filter.TipoDocumentoFilterDTO;
import br.gov.datasus.scodes.model.entity.TipoDocumento;
import br.gov.datasus.scodes.model.mapper.TipoDocumentoMapper;
import br.gov.datasus.scodes.repository.TipoDocumentoRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Optional;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoDocumentoService {

    private final TipoDocumentoRepository repository;
    private final TipoDocumentoMapper mapper;
    public TipoDocumentoDTO obterPorId(Long id) {
        Optional<TipoDocumento> one = repository.findById(id);
        TipoDocumento entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<TipoDocumentoDTO> obterTodos() {
        Iterable<TipoDocumento> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<TipoDocumentoDTO> obterTodosPaginado(PageableRequestModel<TipoDocumentoFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "descricao");
        DynamicParameters parameters = DynamicParameters.get();
        parameters.appendLike("descricao", pageableModel.getFilter().get().getDescricao());
        PageableResponseModel<TipoDocumento> pageableResponseModel = repository.findAll(TipoDocumento.OBTER_TODOS_PAGINADO, parameters, pagination, TipoDocumento.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public TipoDocumentoDTO incluir(TipoDocumentoDTO dto) {
        TipoDocumento entity = mapper.toEntity(dto);
        return mapper.toDto(repository.save(entity));
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public TipoDocumentoDTO alterar(Long id, TipoDocumentoDTO dto) {
        Optional<TipoDocumento> one = repository.findById(id);
        TipoDocumento entity = one.orElseThrow(() -> new ResourceNotFoundException());
        dto.setId(id);
        mapper.fromDto(dto, entity);
        repository.save(entity);
        return mapper.toDto(entity);
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public void excluir(Long id) {
        Optional<TipoDocumento> one = repository.findById(id);
        TipoDocumento entity = one.orElseThrow(() -> new ResourceNotFoundException());
        repository.delete(entity);
    }
}
