package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.dto.filter.TipoModeloFilterDTO;
import br.gov.datasus.scodes.model.dto.TipoModeloDTO;
import br.gov.datasus.scodes.model.entity.TipoModelo;
import br.gov.datasus.scodes.model.mapper.TipoModeloMapper;
import br.gov.datasus.scodes.repository.TipoModeloRepository;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoModeloService {

    private final TipoModeloRepository repository;
    private final TipoModeloMapper mapper;
    public TipoModeloDTO obterPorId(Long id) {
        Optional<TipoModelo> one = repository.findById(id);
        TipoModelo entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<TipoModeloDTO> obterTodos() {
        Iterable<TipoModelo> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<TipoModeloDTO> obterTodosPaginado(PageableRequestModel<TipoModeloFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "tipoModelo");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<TipoModelo> pageableResponseModel = repository.findAll(TipoModelo.OBTER_TODOS_PAGINADO, parameters, pagination, TipoModelo.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

}
