package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.mapper.TipoProfissaoMapper;
import br.gov.datasus.scodes.model.dto.TipoProfissaoDTO;
import br.gov.datasus.scodes.repository.TipoProfissaoRepository;
import br.gov.datasus.scodes.model.entity.TipoProfissao;
import br.gov.datasus.scodes.model.dto.filter.TipoProfissaoFilterDTO;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;

import java.util.Arrays;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

import static br.gov.datasus.scodes.model.enums.TipoProfissaoEnum.*;
import static br.gov.datasus.scodes.model.enums.TipoProfissaoEnum.JEC;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class TipoProfissaoService {

    private final TipoProfissaoRepository repository;
    private final TipoProfissaoMapper mapper;
    public TipoProfissaoDTO obterPorId(Long id) {
        Optional<TipoProfissao> one = repository.findById(id);
        TipoProfissao entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<TipoProfissaoDTO> obterTodos() {
        Iterable<TipoProfissao> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<TipoProfissaoDTO> obterTodosPaginado(PageableRequestModel<TipoProfissaoFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "tipoProfissao");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<TipoProfissao> pageableResponseModel = repository.findAll(TipoProfissao.OBTER_TODOS_PAGINADO, parameters, pagination, TipoProfissao.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

    public final List<Long> getTiposProfissionalProtocoloIds() {
        return Arrays.asList(
            ADVOGADO.getId(),
            DEFENSOR_PUBLICO.getId(),
            PROCURADOR.getId(),
            PROMOTOR.getId(),
            JEFAZ.getId(),
            JEC.getId()
        );
    }

}
