package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.model.mapper.UfMapper;
import br.gov.datasus.scodes.model.dto.UfDTO;
import br.gov.datasus.scodes.repository.UfRepository;
import br.gov.datasus.scodes.model.dto.filter.UfFilterDTO;
import br.gov.datasus.scodes.model.entity.Uf;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class UfService {

    private final UfRepository repository;
    private final UfMapper mapper;
    public UfDTO obterPorId(String id) {
        Optional<Uf> one = repository.findById(id);
        Uf entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<UfDTO> obterTodos() {
        Iterable<Uf> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<UfDTO> obterTodosPaginado(PageableRequestModel<UfFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "uf");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<Uf> pageableResponseModel = repository.findAll(Uf.OBTER_TODOS_PAGINADO, parameters, pagination, Uf.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

}
