package br.gov.datasus.scodes.service;

import br.gov.datasus.scodes.repository.UnidadeOrganizacionalRepository;
import br.gov.datasus.scodes.model.mapper.UnidadeOrganizacionalMapper;
import br.gov.datasus.scodes.model.dto.UnidadeOrganizacionalDTO;
import br.gov.datasus.scodes.model.dto.filter.UnidadeOrganizacionalFilterDTO;
import br.gov.datasus.scodes.model.entity.UnidadeOrganizacional;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.annotation.Propagation;
import lombok.RequiredArgsConstructor;
import java.util.List;
import java.util.Optional;
import org.springframework.data.domain.Pageable;
import br.gov.datasus.api.core.exception.ResourceNotFoundException;
import br.gov.datasus.api.core.helper.PaginationHelper;
import br.gov.datasus.api.core.dynamicquery.parameters.DynamicParameters;
import br.gov.datasus.api.core.pagination.PageableRequestModel;
import br.gov.datasus.api.core.pagination.PageableResponseModel;
import br.gov.datasus.api.core.model.dto.DominioItemModel;

@Service
@RequiredArgsConstructor
@Transactional(propagation= Propagation.SUPPORTS)
public class UnidadeOrganizacionalService {

    private final UnidadeOrganizacionalRepository repository;
    private final UnidadeOrganizacionalMapper mapper;
    public UnidadeOrganizacionalDTO obterPorId(Long id) {
        Optional<UnidadeOrganizacional> one = repository.findById(id);
        UnidadeOrganizacional entity = one.orElseThrow(ResourceNotFoundException::new);
        return mapper.toDto(entity);
    }

    public List<UnidadeOrganizacionalDTO> obterTodos() {
        Iterable<UnidadeOrganizacional> itens = repository.findAll();
        return mapper.toDto(itens);
    }

    public PageableResponseModel<UnidadeOrganizacionalDTO> obterTodosPaginado(PageableRequestModel<UnidadeOrganizacionalFilterDTO> pageableModel) {
        Pageable pagination = PaginationHelper.toPageable(pageableModel, "unidadeOrganizacional");
        DynamicParameters parameters = DynamicParameters.get();
        PageableResponseModel<UnidadeOrganizacional> pageableResponseModel = repository.findAll(UnidadeOrganizacional.OBTER_TODOS_PAGINADO, parameters, pagination, UnidadeOrganizacional.class);
        return mapper.toDtoPageableResponse(pageableResponseModel);
    }

    public List<DominioItemModel> obterDominio() {
        return repository.obterDominio();
    }

    @Transactional(propagation= Propagation.REQUIRED)    
    public UnidadeOrganizacionalDTO incluir(UnidadeOrganizacionalDTO dto) {
        UnidadeOrganizacional entity = mapper.toEntity(dto);
        return mapper.toDto(repository.save(entity));
    }

    @Transactional(propagation= Propagation.REQUIRED)    
    public UnidadeOrganizacionalDTO alterar(Long id, UnidadeOrganizacionalDTO dto) {
        Optional<UnidadeOrganizacional> one = repository.findById(id);
        UnidadeOrganizacional entity = one.orElseThrow(() -> new ResourceNotFoundException());
        dto.setId(id);
        mapper.fromDto(dto, entity);
        repository.save(entity);
        return mapper.toDto(entity);
    }

    @Transactional(propagation= Propagation.REQUIRED)
    public void excluir(Long id) {
        Optional<UnidadeOrganizacional> one = repository.findById(id);
        UnidadeOrganizacional entity = one.orElseThrow(() -> new ResourceNotFoundException());
        repository.delete(entity);
    }
}
