package br.gov.datasus.scodes.test.builder;

import br.gov.datasus.scodes.model.dto.*;
import br.gov.datasus.scodes.model.enums.TipoAcaoContraEnum;
import br.gov.datasus.scodes.model.enums.TipoProcessoEnum;
import br.gov.datasus.scodes.model.enums.TipoSexoEnum;
import br.gov.datasus.scodes.model.enums.TipoStatusProcessualEnum;

import java.util.*;

public class AutorDemandaBuilder {

    public static AutorDemandaDTO buildAutorDemanda() {
        AutorDemandaDTO dto = new AutorDemandaDTO();
        dto.setId(1L);
        dto.setAutores(buildAutores());
        dto.setDemanda(buildDemanda());
        dto.setAtendido(Boolean.FALSE);
        dto.setStatus(buildStatus());
        dto.setProcessual(buildProcessual());
        return dto;
    }

    private static Set<AutorDTO> buildAutores() {
        Set<AutorDTO> list =  new HashSet<>();
        list.add(buildAutor());
        return list;
    }

    private static AutorDTO buildAutor() {
        AutorDTO dto = new AutorDTO();
        dto.setId(1L);
        dto.setNome("Henrique");
        dto.setDataNascimento(new Date());
        dto.setSexo(TipoSexoEnum.MASCULINO);
        dto.setRg("2222221");
        dto.setCpf("96972293090");
        dto.setCns("123654789");
        dto.setEmail("teste@gmail.com");
        dto.setCidade(buildCidade());
        return dto;
    }

    private static CidadeDTO buildCidade() {
        CidadeDTO dto = new CidadeDTO();
        dto.setId(1L);
        dto.setDescricao("Distrito Federeal");
        dto.setUf(new UfDTO());
        return  dto;
    }

    private static DemandaDTO buildDemanda() {
        DemandaDTO dto = new DemandaDTO();
        dto.setId(1L);
        dto.setUnidadeOrganizacional(buildUnidadeOrganizacional());
        dto.setDataEntrada(new Date());
        dto.setDataInclusao(new Date());
        dto.setProtocolo("111111");
        dto.setProcesso("999999");
        dto.setSenhaProcesso("xpto@123");
        dto.setTipoDemanda(buildTipoDemanda());
        dto.setTipoProcesso(TipoProcessoEnum.ESTADO);
        dto.setRelatorioTecnico(new RelatorioTecnicoDTO());
        dto.setCidade(new CidadeDTO());
        return dto;
    }

    private static TipoDemandaDTO buildTipoDemanda() {
        TipoDemandaDTO dto = new TipoDemandaDTO();
        dto.setId(1L);
        dto.setDescricao("tipo demanda xpto");
        return dto;
    }

    private static UnidadeOrganizacionalDTO buildUnidadeOrganizacional() {
        UnidadeOrganizacionalDTO dto = new UnidadeOrganizacionalDTO();
        dto.setId(1L);
        dto.setDescricao("unidade organizacional xpto");
        return dto;
    }

    private static StatusDTO buildStatus() {
        StatusDTO dto = new StatusDTO();
        dto.setId(1L);
        return dto;
    }

    private static ProcessualDTO buildProcessual() {
        ProcessualDTO dto = new ProcessualDTO();
        dto.setId(1L);
        dto.setSegredo(Boolean.FALSE);
        dto.setTipoAcaoContra(TipoAcaoContraEnum.ESTADO);
        dto.setPrazo(new PrazoDTO());
        dto.setVara(new VaraDTO());
        dto.setAutorDemanda(new AutorDemandaDTO());
        dto.setStatus(TipoStatusProcessualEnum.PENDENTE);
        dto.setDocCompleta(Boolean.FALSE);
        dto.setDataNaoCobrancaJud(new Date());
        dto.setProfissional(new ProfissionalDTO());
        dto.setTipoProfissao(new TipoProfissaoDTO());
        dto.setTipoAcao(new TipoAcaoDTO());
        dto.setCidade(new CidadeDTO());
        return dto;
    }
}
