package br.gov.datasus.scodes.test.validation;

import br.gov.datasus.api.core.exception.BusinessException;
import br.gov.datasus.scodes.service.FeriadoService;
import br.gov.datasus.scodes.validation.FeriadoServiceValidation;
import br.gov.datasus.scodes.util.DataUtil;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.boot.test.context.SpringBootTest;

import java.time.LocalDate;
import java.util.Date;

import static org.junit.Assert.assertEquals;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
@SpringBootTest(classes = {FeriadoServiceValidation.class})
public class FeriadoValidationTest {

    @InjectMocks
    private FeriadoServiceValidation feriadoServiceValidation;

    @Mock
    private FeriadoService feriadoService;

    private DataUtil dataUtil;

    private Date dataRetornoFeriado;

    @Before
    public void setUp() {
        dataUtil = new DataUtil();
        dataRetornoFeriado = getDataRetornoFeriado();
    }

    @Test(expected = BusinessException.class)
    public void deveLancarBusinessExceptionSeADataDeFeriadoForIgualDataDeFeriado() {
        when(feriadoService.isDataRetornoFeriado(dataRetornoFeriado)).thenReturn(Boolean.TRUE);
        feriadoServiceValidation.validate(dataRetornoFeriado);
    }


    @Test
    public void deveRetornarTrueSeADataDeFeriadoPassadaForIgualDataDeFeriado() {
        when(feriadoService.isDataRetornoFeriado(dataRetornoFeriado)).thenReturn(Boolean.TRUE);

        Boolean feriado = feriadoService.isDataRetornoFeriado(dataRetornoFeriado);

        verify(feriadoService).isDataRetornoFeriado(dataRetornoFeriado);

        assertEquals(Boolean.TRUE, feriado);
    }

    private Date getDataRetornoFeriado() {
        return dataUtil.convertToDate(LocalDate.of(2020, 04, 23));
    }
}
