import { Injectable } from '@angular/core';
import { v4 as uuidv4 } from 'uuid';
import { FuncionalidadeModel } from '../models/funcionalidade.model';
import { FuncionalidadeNodeModel } from '../models/funcionalidade-node.model';
import { PerfilFuncionalidadeModel } from '../models/perfil-funcionalidade.model';

@Injectable()
export class TreeFuncionalidadeService {

  public buildTree(funcionalidades: FuncionalidadeModel[],
                   perfilFuncionalidades: PerfilFuncionalidadeModel[]): FuncionalidadeNodeModel[] {
    const tree: FuncionalidadeNodeModel[] = [];

    funcionalidades.forEach(funcionalidade => {
      const parentNode = funcionalidade.idPai ? this.findNodeByFuncionalidade(tree, funcionalidade.idPai) : null;

      let perfilFuncionalidade = perfilFuncionalidades.find(v => v.funcionalidade.id === funcionalidade.id);
      if (!perfilFuncionalidade) {
        perfilFuncionalidade = {
          funcionalidade: funcionalidade,
          situacaoPesquisar: false,
          situacaoCriar: false,
          situacaoAlterar: false,
          situacaoExcluir: false,
          situacaoImprimir: false,
        } as PerfilFuncionalidadeModel;
      }

      const node = {
        id: uuidv4(),
        funcionalidade: funcionalidade,
        perfilFuncionalidade: perfilFuncionalidade,
        isVisible: true,
        isExpanded: true,
        depth: parentNode ? parentNode.depth + 1 : 0,
        parent: parentNode,
        children: [],
      } as FuncionalidadeNodeModel;

      (parentNode) ? parentNode.children.push(node) : tree.push(node);
    });

    return tree;
  }

  public toTreeTable(nodes: FuncionalidadeNodeModel[]): FuncionalidadeNodeModel[] {
    const treeTable: FuncionalidadeNodeModel[] = [];
    this.walkInTree(nodes, node => treeTable.push(node));
    return treeTable;
  }

  public findNodeByFuncionalidade(nodes: FuncionalidadeNodeModel[], funcionalidadeId: number): FuncionalidadeNodeModel|null {
    let found = null;
    nodes.find(node => {
      if (node.funcionalidade.id === funcionalidadeId) {
        found = node;
      } else if (node.children && node.children.length > 0) {
        found = this.findNodeByFuncionalidade(node.children, funcionalidadeId);
      }
      return !!found;
    });
    return found;
  }

  public walkInTree(nodes: FuncionalidadeNodeModel[], f: (node: FuncionalidadeNodeModel) => void) {
    nodes.forEach(node => {
      f(node);
      if (node.children && node.children.length > 0) {
        this.walkInTree(node.children, f);
      }
    });
  }

  public walkToRoot(node: FuncionalidadeNodeModel, f: (node: FuncionalidadeNodeModel) => void) {
    f(node);
    if (node.parent) {
      this.walkToRoot(node.parent, f);
    }
  }
}
