import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { FlexLayoutModule } from '@angular/flex-layout';
import { MaterialFileInputModule } from 'ngx-material-file-input';

import { DemandasRoutingModule } from './demandas-routing.module';
import { MaterialModule } from 'src/material/material.module';
import { DatasusModule } from 'src/datasus/datasus.module';
import { SharedModule } from '../shared/shared.module';
import { DemandasListComponent } from './pages/demandas-list/demandas-list.component';
import { DemandasService } from './services/demandas.service';
import { DemandaResolver } from './resolvers/demanda.resolver';
import { NgxMaskModule } from 'ngx-mask';
import { ProtocoloFormComponent } from './pages/protocolo-form/protocolo-form.component';
import { MenuHearderComponent } from './components/menu-hearder/menu-hearder.component';
import { DialogAdicionarArquivoComponent } from './components/dialog-adicionar-arquivo/dialog-adicionar-arquivo.component';
import { AutorComponent } from './components/autor/autor.component';
import { DialogAutorComponent } from './components/dialog-autor/dialog-autor.component';
import { AutorService } from './services/autor.service';
import { ProcessualFormComponent } from './pages/processual-form/processual-form.component';
import { TecnicoFormComponent } from './pages/tecnico-form/tecnico-form.component';
import { AtendimentoFormComponent } from './pages/atendimento-form/atendimento-form.component';
import { DispensacaoFormComponent } from './pages/dispensacao-form/dispensacao-form.component';
import { HistoricoFormComponent } from './pages/historico-form/historico-form.component';
import { ProntuarioFormComponent } from './pages/prontuario-form/prontuario-form.component';
import { CardHearderComponent } from './components/card-hearder/card-hearder.component';
import { TipoAcaoService } from '../rotina/tabela/tipo-acao/services/tipo-acao.service';

@NgModule({

  imports: [
    // Angular
    CommonModule,
    FormsModule,
    ReactiveFormsModule,
    // Angular Flex Layout
    FlexLayoutModule,
    // Angular Material
    MaterialModule,
    // Datasus
    DatasusModule,
    // App
    SharedModule,
     // JSDADDY Ngx Mask
     NgxMaskModule.forChild({ dropSpecialCharacters: true }),
    // Demanda
    DemandasRoutingModule,
    // input-file
    MaterialFileInputModule,
  ],
  declarations: [
    DemandasListComponent,
    ProtocoloFormComponent,
    MenuHearderComponent,
    DialogAdicionarArquivoComponent,
    AutorComponent,
    DialogAutorComponent,
    ProcessualFormComponent,
    TecnicoFormComponent,
    AtendimentoFormComponent,
    DispensacaoFormComponent,
    HistoricoFormComponent,
    ProntuarioFormComponent,
    CardHearderComponent
  ],
  providers: [
    DemandasService,
    DemandaResolver,
    AutorService,
    TipoAcaoService
  ],
  entryComponents: [
    DialogAdicionarArquivoComponent,
    DialogAutorComponent,
  ]
})
export class DemandasModule { }
