import { ArquivoBase64Model } from './../../../shared/models/arquivo-base64.model';
import { RelatorioDataRetornoAutorDemandaFilterModel } from './../models/relatorio-data-retorno-autor-demanda-filter.model.';
import { ResultadoPesquisaDRAutorDemandaReciboOrdemProdutoModel } from './../models/resultado-pesquisa-dr-autor-demanda-recibo-ordem-produto.model';
import { SalvarAlteracaoDataRetornoModel } from './../models/salvar-alteracao-data-retorno.model';
import { ResultadoPesquisaAutorDemandaModel } from './../models/resultado-pesquisa-autor-demanda.model';
import { PesquisaDRAutorDemandaReciboFilterModel } from '../models/pesquisa-dr-autor-demanda-recibo-filter.model';
import { AlteracaoDataRetornoFilterModel } from './../models/alteracao-data-retorno-filter.model';
import { AlteracaoDataRetornoModel } from './../models/alteracao-data-retorno.model';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';

import { BaseService, DominioItemModel, PageableRequestModel, PageableResponseModel } from '@datasus/core';
import { StatusAlteracaoDataRetornoModel } from '../models/status-alteracao-data-retorno.model';
import { ValidarAlteracaoNovaDataRetornoFilterModel } from '../models/validar-alteracao-nova-data-retorno-filter.model';

@Injectable({
  providedIn: 'root'
})
export class AlteracaoDataRetornoService extends BaseService {

  private baseUrl = '/alteracao-data-retorno';
  private baseStatusUrl = '/status-alteracao-data-retorno';

  obterPorId(id: number): Observable<AlteracaoDataRetornoModel> {
    return this.baseGet<AlteracaoDataRetornoModel>(`${this.baseUrl}/${id}`);
  }

  obterTodos(): Observable<AlteracaoDataRetornoModel[]> {
    return this.baseGet<AlteracaoDataRetornoModel[]>(this.baseUrl);
  }

  obterStatus(): Observable<StatusAlteracaoDataRetornoModel[]> {
    return this.baseGet<StatusAlteracaoDataRetornoModel[]>(this.baseStatusUrl);
  }

  obterTodosPaginado(body: PageableRequestModel<AlteracaoDataRetornoFilterModel>): 
      Observable<PageableResponseModel<AlteracaoDataRetornoModel>> {
    return this.basePost<PageableResponseModel<AlteracaoDataRetornoModel>>(`${this.baseUrl}/paginado`, body);
  }

  pesquisaDRAutorDemandaReciboPaginado(body: PageableRequestModel<PesquisaDRAutorDemandaReciboFilterModel>):
      Observable<PageableResponseModel<ResultadoPesquisaAutorDemandaModel>> {
    return this.basePost<PageableResponseModel<ResultadoPesquisaAutorDemandaModel>>
      (`${this.baseUrl}/pesquisa-autor-demanda/paginado`, body);
  }

  pesquisaDRAutorDemandaADRPorCodigo(codigoAlteracaoDataRetorno: number): 
              Observable<ResultadoPesquisaDRAutorDemandaReciboOrdemProdutoModel[]> {
    return this.baseGet<ResultadoPesquisaDRAutorDemandaReciboOrdemProdutoModel[]>
      (`${this.baseUrl}/pesquisa-autor-demanda-adr/${codigoAlteracaoDataRetorno}`);
  }


  obterDominio(): Observable<DominioItemModel[]> {
    return this.baseGet<DominioItemModel[]>(`${this.baseUrl}/dominio`);
  }

  
  obterAutocompleteDominio(idCategoria: string, termo: string): Observable<DominioItemModel[]> {
    return this.baseGet<DominioItemModel[]>(`/produto/autocomplete?categoria=${idCategoria}&termo=${termo}`);
  }

  incluir(body: SalvarAlteracaoDataRetornoModel): Observable<SalvarAlteracaoDataRetornoModel> {
    return this.basePost<SalvarAlteracaoDataRetornoModel>(this.baseUrl, body);
  }

  alterar(body: SalvarAlteracaoDataRetornoModel, id: number): Observable<SalvarAlteracaoDataRetornoModel> {
    return this.basePut<SalvarAlteracaoDataRetornoModel>(`${this.baseUrl}/${id}`, body);
  }

  excluir(id: number): Observable<void> {
    return this.baseDelete<void>(`${this.baseUrl}/${id}`);
  }

  relatorioCsv(body: RelatorioDataRetornoAutorDemandaFilterModel): Observable<ArquivoBase64Model> {
    return this.basePost<ArquivoBase64Model>(`${this.baseUrl}/relatorio-csv`, body);
  }

  relatorioPdf(codigoAlteracaoDataRetorno: number): Observable<ArquivoBase64Model> {
    return this.baseGet<ArquivoBase64Model>(`${this.baseUrl}/${codigoAlteracaoDataRetorno}/relatorio-pdf`);
  }

  validarNovaDataRetorno(body: ValidarAlteracaoNovaDataRetornoFilterModel):
    Observable<void> {
    return this.basePost<void>(`${this.baseUrl}/validar-nova-data-retorno`, body);
  }

  validarNovaDataRetornoEditar(codigoAlteracaoDataRetorno: number, body: ValidarAlteracaoNovaDataRetornoFilterModel):
    Observable<void> {
      return this.basePost<void>(`${this.baseUrl}/validar-nova-data-retorno-editar/${codigoAlteracaoDataRetorno}`, body);
  }

}
