import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { FlexLayoutModule } from '@angular/flex-layout';

import { NgxCurrencyModule } from 'ngx-currency';

import { MaterialModule } from '../../../material/material.module';
import { DatasusModule } from '../../../datasus/datasus.module';
import { SharedModule } from '../../shared/shared.module';

import { GestaoEstoqueRoutingModule } from './gestao-estoque.routing.module';
import { GestaoEstoqueComponent } from './pages/gestao-estoque/gestao-estoque.component';
import { EntradaEstoqueComponent } from './pages/entrada-estoque/entrada-estoque.component';
import { SaidaEstoqueComponent } from './pages/saida-estoque/saida-estoque.component';
import { UnidadeDispensadoraResolver } from './resolvers/unidade-dispensadora.resolver';

import { EntradaEstoqueService } from './services/entrada-estoque.service';
import { CompraModalidadeService } from './services/compra-modalidade.service';
import { SaidaEstoqueService } from './services/saida-estoque.service';

@NgModule({
  imports: [
    // Angular
    CommonModule,
    FormsModule,
    ReactiveFormsModule,
    // Angular Flex Layout
    FlexLayoutModule,
    // Angular Material
    MaterialModule,
    // Ngx Currency
    NgxCurrencyModule,
    // Datasus
    DatasusModule,
    // App
    SharedModule,
    // Gestão Estoque
    GestaoEstoqueRoutingModule
  ],
  declarations: [
    GestaoEstoqueComponent,
    EntradaEstoqueComponent,
    SaidaEstoqueComponent,
  ],
  providers: [
    EntradaEstoqueService,
    SaidaEstoqueService,
    CompraModalidadeService,
    UnidadeDispensadoraResolver,
  ],
})
export class GestaoEstoqueModule { }
