import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';

import { BaseService, DominioItemModel, PageableRequestModel, PageableResponseModel } from '@datasus/core';

import { ClassificacaoCobrancaModel } from '../models/classificacao-cobranca.model';
import { ClassificacaoCobrancaFilterModel } from '../models/classificacao-cobranca-filter.model';

@Injectable()
export class ClassificacaoCobrancaService extends BaseService {

  obterPorId(id: number): Observable<ClassificacaoCobrancaModel> {
    return this.baseGet<ClassificacaoCobrancaModel>(`/classificacao-cobranca/${id}`);
  }

  obterTodos(): Observable<ClassificacaoCobrancaModel[]> {
    return this.baseGet<ClassificacaoCobrancaModel[]>('/classificacao-cobranca');
  }

  // tslint:disable-next-line: max-line-length
  obterTodosPaginado(body: PageableRequestModel<ClassificacaoCobrancaFilterModel>): Observable<PageableResponseModel<ClassificacaoCobrancaModel>> {
    return this.basePost<PageableResponseModel<ClassificacaoCobrancaModel>>('/classificacao-cobranca/paginado', body);
  }

  obterDominio(): Observable<DominioItemModel[]> {
    return this.baseGet<DominioItemModel[]>('/classificacao-cobranca/dominio');
  }

  incluir(body: ClassificacaoCobrancaModel): Observable<ClassificacaoCobrancaModel> {
    return this.basePost<ClassificacaoCobrancaModel>('/classificacao-cobranca', body);
  }

  alterar(body: ClassificacaoCobrancaModel, id: number): Observable<ClassificacaoCobrancaModel> {
    return this.basePut<ClassificacaoCobrancaModel>(`/classificacao-cobranca/${id}`, body);
  }

  excluir(id: number): Observable<void> {
    return this.baseDelete<void>(`/classificacao-cobranca/${id}`);
  }

}
