import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';

import { BaseService, DominioItemModel, PageableResponseModel, PageableRequestModel } from '@datasus/core';

import { EspecificacaoModel } from '../models/especificacao.model';

@Injectable()
export class EspecificacaoService extends BaseService {


  obterPorId(id: number): Observable<EspecificacaoModel> {
    return this.baseGet<EspecificacaoModel>(`/especificacao/${id}`);
  }

  obterTodos(): Observable<EspecificacaoModel[]> {
    return this.baseGet<EspecificacaoModel[]>('/especificacao');
  }

  obterTodosPaginado(body: PageableRequestModel<EspecificacaoModel>): Observable<PageableResponseModel<EspecificacaoModel>> {
    return this.basePost<PageableResponseModel<EspecificacaoModel>>('/especificacao/paginado', body);
  }

  obterDominio(idProduto?: string): Observable<DominioItemModel[]> {
    if (idProduto) {
      return this.baseGet<DominioItemModel[]>(`/especificacao/dominio?produto=${idProduto}`);
    }
    return this.baseGet<DominioItemModel[]>('/especificacao/dominio');
  }

  incluir(body: EspecificacaoModel): Observable<EspecificacaoModel> {
    return this.basePost<EspecificacaoModel>('/especificacao', body);
  }

  alterar(body: EspecificacaoModel, id: number): Observable<EspecificacaoModel> {
    return this.basePut<EspecificacaoModel>(`/especificacao/${id}`, body);
  }

  excluir(id: number): Observable<void> {
    return this.baseDelete<void>(`/especificacao/${id}`);
  }


}
