import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';

import { BaseService, DominioItemModel, PageableRequestModel, PageableResponseModel } from '@datasus/core';

import { TipoCobrancaModel } from '../models/tipo-cobranca.model';
import { TipoCobrancaFilterModel } from '../models/tipo-cobranca-filter.model';

@Injectable()
export class TipoCobrancaService extends BaseService {

  obterPorId(id: number): Observable<TipoCobrancaModel> {
    return this.baseGet<TipoCobrancaModel>(`/tipo-cobranca/${id}`);
  }

  obterTodos(): Observable<TipoCobrancaModel[]> {
    return this.baseGet<TipoCobrancaModel[]>('/tipo-cobranca');
  }

  obterTodosPaginado(body: PageableRequestModel<TipoCobrancaFilterModel>): Observable<PageableResponseModel<TipoCobrancaModel>> {
    return this.basePost<PageableResponseModel<TipoCobrancaModel>>('/tipo-cobranca/paginado', body);
  }

  obterDominio(): Observable<DominioItemModel[]> {
    return this.baseGet<DominioItemModel[]>('/tipo-cobranca/dominio');
  }

  incluir(body: TipoCobrancaModel): Observable<TipoCobrancaModel> {
    return this.basePost<TipoCobrancaModel>('/tipo-cobranca', body);
  }

  alterar(body: TipoCobrancaModel, id: number): Observable<TipoCobrancaModel> {
    return this.basePut<TipoCobrancaModel>(`/tipo-cobranca/${id}`, body);
  }

  excluir(id: number): Observable<void> {
    return this.baseDelete<void>(`/tipo-cobranca/${id}`);
  }

}
